import re
import unittest
import ir_datasets
from ir_datasets.datasets.kilt import KiltDoc, KiltDocAnchor
from ir_datasets.datasets.codec import CodecQuery
from ir_datasets.formats import TrecQrel
from .base import DatasetIntegrationTest

class TestKilt(DatasetIntegrationTest):
    def test_docs(self):
        self._test_docs('kilt', count=5903530, items={
            0: KiltDoc('290', 'A', re.compile('^A\nA \\(named , plural "As", "A\'s", "a"s, "a\'s" or "aes"\\) is the first letter and the first vowel of th.{9615}ably derives from old Italic A\n\\- : Gothic letter aza/asks\nExternal links\\.\n\\- History of the Alphabet\n$', flags=48), ('A\n', 'A (named , plural "As", "A\'s", "a"s, "a\'s" or "aes") is the first letter and the first vowel of the modern English alphabet and the ISO basic Latin alphabet. It is similar to the Ancient Greek letter alpha, from which it derives. The uppercase version consists of the two slanting sides of a triangle, crossed in the middle by a horizontal bar. The lowercase version can be written in two forms: the double-storey a and single-storey ɑ. The latter is commonly used in handwriting and fonts based on it, especially fonts intended to be read by children, and is also found in italic type.\n', 'In the English grammar, "a", and its variant "an", is an indefinite article.\n', 'Section::::History.\n', 'The earliest certain ancestor of "A" is aleph (also written \'aleph), the first letter of the Phoenician alphabet, which consisted entirely of consonants (for that reason, it is also called an abjad to distinguish it from a true alphabet). In turn, the ancestor of aleph may have been a pictogram of an ox head in proto-Sinaitic script influenced by Egyptian hieroglyphs, styled as a triangular head with two horns extended.\n', 'By 1600 BC, the Phoenician alphabet letter had a linear form that served as the base for some later forms. Its name is thought to have corresponded closely to the Paleo-Hebrew or Arabic aleph.\n', 'When the ancient Greeks adopted the alphabet, they had no use for a letter to represent the glottal stop—the consonant sound that the letter denoted in Phoenician and other Semitic languages, and that was the first phoneme of the Phoenician pronunciation of the letter—so they used their version of the sign to represent the vowel , and called it by the similar name of alpha. In the earliest Greek inscriptions after the Greek Dark Ages, dating to the 8th century BC, the letter rests upon its side, but in the Greek alphabet of later times it generally resembles the modern capital letter, although many local varieties can be distinguished by the shortening of one leg, or by the angle at which the cross line is set.\n', 'The Etruscans brought the Greek alphabet to their civilization in the Italian Peninsula and left the letter unchanged. The Romans later adopted the Etruscan alphabet to write the Latin language, and the resulting letter was preserved in the Latin alphabet that would come to be used to write many languages, including English.\n', 'Section::::History.:Typographic variants.\n', 'During Roman times, there were many variant forms of the letter "A". First was the monumental or lapidary style, which was used when inscribing on stone or other "permanent" media. There was also a cursive style used for everyday or utilitarian writing, which was done on more perishable surfaces. Due to the "perishable" nature of these surfaces, there are not as many examples of this style as there are of the monumental, but there are still many surviving examples of different types of cursive, such as majuscule cursive, minuscule cursive, and semicursive minuscule. Variants also existed that were intermediate between the monumental and cursive styles. The known variants include the early semi-uncial, the uncial, and the later semi-uncial.\n', 'At the end of the Roman Empire (5th century AD), several variants of the cursive minuscule developed through Western Europe. Among these were the semicursive minuscule of Italy, the Merovingian script in France, the Visigothic script in Spain, and the Insular or Anglo-Irish semi-uncial or Anglo-Saxon majuscule of Great Britain. By the 9th century, the Caroline script, which was very similar to the present-day form, was the principal form used in book-making, before the advent of the printing press. This form was derived through a combining of prior forms.\n', '15th-century Italy saw the formation of the two main variants that are known today. These variants, the "Italic" and "Roman" forms, were derived from the Caroline Script version. The Italic form, also called "script a," is used in most current handwriting and consists of a circle and vertical stroke. This slowly developed from the fifth-century form resembling the Greek letter tau in the hands of medieval Irish and English writers. The Roman form is used in most printed material; it consists of a small loop with an arc over it ("a"). Both derive from the majuscule (capital) form. In Greek handwriting, it was common to join the left leg and horizontal stroke into a single loop, as demonstrated by the uncial version shown. Many fonts then made the right leg vertical. In some of these, the serif that began the right leg stroke developed into an arc, resulting in the printed form, while in others it was dropped, resulting in the modern handwritten form.\n', 'Italic type is commonly used to mark emphasis or more generally to distinguish one part of a text from the rest (set in Roman type). There are some other cases aside from italic type where "script a" ("ɑ"), also called Latin alpha, is used in contrast with Latin "a" (such as in the International Phonetic Alphabet).\n', 'Section::::Use in writing systems.\n', 'Section::::Use in writing systems.:English.\n', 'In modern English orthography, the letter represents at least seven different vowel sounds:\n', 'BULLET::::- the near-open front unrounded vowel as in "pad";\n', 'BULLET::::- the open back unrounded vowel as in "father", which is closer to its original Latin and Greek sound;\n', 'BULLET::::- the diphthong as in "ace" and "major" (usually when is followed by one, or occasionally two, consonants and then another vowel letter) – this results from Middle English lengthening followed by the Great Vowel Shift;\n', 'BULLET::::- the modified form of the above sound that occurs before, as in "square" and "Mary";\n', 'BULLET::::- the rounded vowel of "water";\n', 'BULLET::::- the shorter rounded vowel (not present in General American) in "was" and "what";\n', 'BULLET::::- a schwa, in many unstressed syllables, as in "about", "comma", "solar".\n', 'The double sequence does not occur in native English words, but is found in some words derived from foreign languages such as "Aaron" and "aardvark". However, occurs in many common digraphs, all with their own sound or sounds, particularly , , , , and .\n', 'Section::::Use in writing systems.:Other languages.\n', 'In most languages that use the Latin alphabet, denotes an open unrounded vowel, such as , , or . An exception is Saanich, in which (and the glyph Á) stands for a close-mid front unrounded vowel .\n', 'Section::::Use in writing systems.:Other systems.\n', 'In phonetic and phonemic notation:\n', 'BULLET::::- in the International Phonetic Alphabet, is used for the open front unrounded vowel, is used for the open central unrounded vowel, and is used for the open back unrounded vowel.\n', 'BULLET::::- in X-SAMPA, is used for the open front unrounded vowel and is used for the open back unrounded vowel.\n', 'Section::::Other uses.\n', 'In algebra, the letter "a" along with other letters at the beginning of the alphabet is used to represent known quantities, whereas the letters at the end of the alphabet ("x", "y", "z") are used to denote unknown quantities.\n', 'In geometry, capital A, B, C etc. are used to denote segments, lines, rays, etc. A capital A is also typically used as one of the letters to represent an angle in a triangle, the lowercase a representing the side opposite angle A.\n', '"A" is often used to denote something or someone of a better or more prestigious quality or status: A-, A or A+, the best grade that can be assigned by teachers for students\' schoolwork; "A grade" for clean restaurants; A-list celebrities, etc. Such associations can have a motivating effect, as exposure to the letter A has been found to improve performance, when compared with other letters.\n', '"A" is used as a prefix on some words, such as asymmetry, to mean "not" or "without" (from Greek).\n', 'In English grammar, "a", and its variant "an", is an indefinite article.\n', 'Finally, the letter A is used to denote size, as in a narrow size shoe, or a small cup size in a brassiere.\n', 'Section::::Related characters.\n', 'Section::::Related characters.:Descendants and related characters in the Latin alphabet.\n', 'BULLET::::- Æ æ : Latin "AE" ligature\n', 'BULLET::::- A with diacritics: Å å Ǻ ǻ Ḁ ḁ ẚ Ă ă Ặ ặ Ắ ắ Ằ ằ Ẳ ẳ Ẵ ẵ Ȃ ȃ Â â Ậ ậ Ấ ấ Ầ ầ Ẫ ẫ Ẩ ẩ Ả ả Ǎ ǎ Ⱥ ⱥ Ȧ ȧ Ǡ ǡ Ạ ạ Ä ä Ǟ ǟ À à Ȁ ȁ Á á Ā ā Ā̀ ā̀ Ã ã Ą ą Ą́ ą́ Ą̃ ą̃ A̲ a̲ ᶏ\n', 'BULLET::::- Phonetic alphabet symbols related to A (the International Phonetic Alphabet only uses lowercase, but uppercase forms are used in some other writing systems):\n', 'BULLET::::- Ɑ ɑ : Latin letter alpha / script A, which represents an open back unrounded vowel in the IPA\n', 'BULLET::::- ᶐ : Latin small letter alpha with retroflex hook\n', 'BULLET::::- Ɐ ɐ : Turned A, which represents a near-open central vowel in the IPA\n', 'BULLET::::- Λ ʌ : Turned V (also called a wedge, a caret, or a hat), which represents an open-mid back unrounded vowel in the IPA\n', 'BULLET::::- Ɒ ɒ : Turned alpha / script A, which represents an open back rounded vowel in the IPA\n', 'BULLET::::- ᶛ : Modifier letter small turned alpha\n', 'BULLET::::- ᴀ : Small capital A, an obsolete or non-standard symbol in the International Phonetic Alphabet used to represent various sounds (mainly open vowels)\n', 'BULLET::::- ᴬ ᵃ ᵄ : Modifier letters are used in the Uralic Phonetic Alphabet (UPA)\n', 'BULLET::::- ₐ : Subscript small a is used in Indo-European studies\n', 'BULLET::::- ꬱ : Small letter a reversed-schwa is used in the Teuthonista phonetic transcription system\n', 'BULLET::::- Ꞻ ꞻ : Glottal A, used in the transliteration of Ugaritic\n', 'Section::::Related characters.:Derived signs, symbols and abbreviations.\n', 'BULLET::::- ª : an ordinal indicator\n', 'BULLET::::- Å : Ångström sign\n', 'BULLET::::- ∀ : a turned capital letter A, used in predicate logic to specify universal quantification ("for all")\n', 'BULLET::::- @ : At sign\n', 'BULLET::::- ₳ : Argentine austral\n', 'Section::::Related characters.:Ancestors and siblings in other alphabets.\n', 'BULLET::::- 𐤀 : Semitic letter Aleph, from which the following symbols originally derive\n', 'BULLET::::- Α α : Greek letter Alpha, from which the following letters derive\n', 'BULLET::::- А а : Cyrillic letter A\n', 'BULLET::::- : Coptic letter Alpha\n', 'BULLET::::- 𐌀 : Old Italic A, which is the ancestor of modern Latin A\n', 'BULLET::::- : Runic letter ansuz, which probably derives from old Italic A\n', 'BULLET::::- : Gothic letter aza/asks\n', 'Section::::External links.\n', 'BULLET::::- History of the Alphabet\n'), (KiltDocAnchor(text='named', href='English%20alphabet%23Letter%20names', paragraph_id=1, start=3, end=8), KiltDocAnchor(text='letter', href='Letter%20%28alphabet%29', paragraph_id=1, start=66, end=72), KiltDocAnchor(text='vowel', href='vowel', paragraph_id=1, start=87, end=92), KiltDocAnchor(text='modern English alphabet', href='English%20alphabet', paragraph_id=1, start=100, end=123), KiltDocAnchor(text='ISO basic Latin alphabet', href='ISO%20basic%20Latin%20alphabet', paragraph_id=1, start=132, end=156), KiltDocAnchor(text='Ancient Greek letter', href='Greek_alphabet%23History', paragraph_id=1, start=179, end=199), KiltDocAnchor(text='alpha', href='alpha', paragraph_id=1, start=200, end=205), KiltDocAnchor(text='italic type', href='italic%20type', paragraph_id=1, start=574, end=585), KiltDocAnchor(text='indefinite article', href='Article%20%28grammar%29%23Indefinite%20article', paragraph_id=2, start=57, end=75), KiltDocAnchor(text='aleph', href='aleph', paragraph_id=4, start=40, end=45), KiltDocAnchor(text='Phoenician alphabet', href='Phoenician%20alphabet', paragraph_id=4, start=93, end=112), KiltDocAnchor(text='consonant', href='consonant', paragraph_id=4, start=142, end=151), KiltDocAnchor(text='abjad', href='abjad', paragraph_id=4, start=192, end=197), KiltDocAnchor(text='alphabet', href='alphabet', paragraph_id=4, start=228, end=236), KiltDocAnchor(text='pictogram', href='pictogram', paragraph_id=4, start=286, end=295), KiltDocAnchor(text='proto-Sinaitic script', href='proto-Sinaitic%20script', paragraph_id=4, start=313, end=334), KiltDocAnchor(text='Egyptian hieroglyphs', href='Egyptian%20hieroglyphs', paragraph_id=4, start=349, end=369), KiltDocAnchor(text='Paleo-Hebrew', href='Paleo-Hebrew%20alphabet', paragraph_id=5, start=163, end=175), KiltDocAnchor(text='Arabic', href='Arabic%20script', paragraph_id=5, start=179, end=185), KiltDocAnchor(text='aleph', href='aleph', paragraph_id=5, start=186, end=191), KiltDocAnchor(text='ancient Greeks', href='Ancient%20Greece', paragraph_id=6, start=9, end=23), KiltDocAnchor(text='glottal stop', href='glottal%20stop', paragraph_id=6, start=92, end=104), KiltDocAnchor(text='Phoenician', href='Phoenician%20language', paragraph_id=6, start=152, end=162), KiltDocAnchor(text='Semitic languages', href='Semitic%20languages', paragraph_id=6, start=173, end=190), KiltDocAnchor(text='phoneme', href='phoneme', paragraph_id=6, start=215, end=222), KiltDocAnchor(text='alpha', href='alpha', paragraph_id=6, start=370, end=375), KiltDocAnchor(text='Greek Dark Ages', href='Greek%20Dark%20Ages', paragraph_id=6, start=422, end=437), KiltDocAnchor(text='Greek alphabet', href='Greek%20alphabet', paragraph_id=6, start=512, end=526), KiltDocAnchor(text='Etruscans', href='Etruscan%20civilization', paragraph_id=7, start=4, end=13), KiltDocAnchor(text='Italian Peninsula', href='Italian%20Peninsula', paragraph_id=7, start=70, end=87), KiltDocAnchor(text='Etruscan alphabet', href='Old%20Italic%20script', paragraph_id=7, start=148, end=165), KiltDocAnchor(text='Latin language', href='Latin', paragraph_id=7, start=179, end=193), KiltDocAnchor(text='Latin alphabet', href='Latin%20script', paragraph_id=7, start=241, end=255), KiltDocAnchor(text='cursive', href='cursive', paragraph_id=9, start=198, end=205), KiltDocAnchor(text='majuscule', href='letter%20case', paragraph_id=9, start=508, end=517), KiltDocAnchor(text='minuscule', href='letter%20case', paragraph_id=9, start=527, end=536), KiltDocAnchor(text='semi-uncial', href='Uncial%20script%23Half-uncial', paragraph_id=9, start=698, end=709), KiltDocAnchor(text='Roman Empire', href='Roman%20Empire', paragraph_id=10, start=18, end=30), KiltDocAnchor(text='Italy', href='Italy', paragraph_id=10, start=171, end=176), KiltDocAnchor(text='Merovingian script', href='Merovingian%20script', paragraph_id=10, start=182, end=200), KiltDocAnchor(text='Visigothic script', href='Visigothic%20script', paragraph_id=10, start=216, end=233), KiltDocAnchor(text='Insular', href='Insular%20script', paragraph_id=10, start=252, end=259), KiltDocAnchor(text='Caroline script', href='Carolingian%20minuscule', paragraph_id=10, start=354, end=369), KiltDocAnchor(text='handwriting', href='handwriting', paragraph_id=11, start=244, end=255), KiltDocAnchor(text='tau', href='tau', paragraph_id=11, start=380, end=383), KiltDocAnchor(text='serif', href='serif', paragraph_id=11, start=798, end=803), KiltDocAnchor(text='Italic type', href='Italic%20type', paragraph_id=12, start=0, end=11), KiltDocAnchor(text='Latin alpha', href='Latin%20alpha', paragraph_id=12, start=219, end=230), KiltDocAnchor(text='International Phonetic Alphabet', href='International%20Phonetic%20Alphabet', paragraph_id=12, start=283, end=314), KiltDocAnchor(text='English orthography', href='English%20orthography', paragraph_id=15, start=10, end=29), KiltDocAnchor(text='near-open front unrounded vowel', href='near-open%20front%20unrounded%20vowel', paragraph_id=16, start=16, end=47), KiltDocAnchor(text='open back unrounded vowel', href='open%20back%20unrounded%20vowel', paragraph_id=17, start=16, end=41), KiltDocAnchor(text='diphthong', href='diphthong', paragraph_id=18, start=16, end=25), KiltDocAnchor(text='Middle English lengthening', href='Middle%20English%20lengthening', paragraph_id=18, start=167, end=193), KiltDocAnchor(text='Great Vowel Shift', href='Great%20Vowel%20Shift', paragraph_id=18, start=210, end=227), KiltDocAnchor(text='before', href='English-language%20vowel%20changes%20before%20historic%20/r/', paragraph_id=19, start=61, end=67), KiltDocAnchor(text='General American', href='General%20American', paragraph_id=21, start=54, end=70), KiltDocAnchor(text='schwa', href='schwa', paragraph_id=22, start=14, end=19), KiltDocAnchor(text='aardvark', href='aardvark', paragraph_id=23, start=139, end=147), KiltDocAnchor(text='many common digraphs', href='List%20of%20Latin-script%20digraphs', paragraph_id=23, start=169, end=189), KiltDocAnchor(text='Saanich', href='Saanich%20dialect', paragraph_id=25, start=113, end=120), KiltDocAnchor(text='Á', href='%C3%81', paragraph_id=25, start=146, end=147), KiltDocAnchor(text='close-mid front unrounded vowel', href='close-mid%20front%20unrounded%20vowel', paragraph_id=25, start=162, end=193), KiltDocAnchor(text='International Phonetic Alphabet', href='International%20Phonetic%20Alphabet', paragraph_id=28, start=19, end=50), KiltDocAnchor(text='open front unrounded vowel', href='open%20front%20unrounded%20vowel', paragraph_id=28, start=68, end=94), KiltDocAnchor(text='open central unrounded vowel', href='open%20central%20unrounded%20vowel', paragraph_id=28, start=112, end=140), KiltDocAnchor(text='open back unrounded vowel', href='open%20back%20unrounded%20vowel', paragraph_id=28, start=162, end=187), KiltDocAnchor(text='X-SAMPA', href='X-SAMPA', paragraph_id=29, start=15, end=22), KiltDocAnchor(text='open front unrounded vowel', href='open%20front%20unrounded%20vowel', paragraph_id=29, start=40, end=66), KiltDocAnchor(text='open back unrounded vowel', href='open%20back%20unrounded%20vowel', paragraph_id=29, start=87, end=112), KiltDocAnchor(text='algebra', href='algebra', paragraph_id=31, start=3, end=10), KiltDocAnchor(text='geometry', href='geometry', paragraph_id=32, start=3, end=11), KiltDocAnchor(text='segment', href='Line%20segment', paragraph_id=32, start=53, end=60), KiltDocAnchor(text='line', href='line%20%28geometry%29', paragraph_id=32, start=63, end=67), KiltDocAnchor(text='rays', href='Line%20%28geometry%29%23Ray', paragraph_id=32, start=70, end=74), KiltDocAnchor(text='triangle', href='triangle', paragraph_id=32, start=165, end=173), KiltDocAnchor(text='A-list', href='A-list', paragraph_id=33, start=220, end=226), KiltDocAnchor(text='motivating', href='motivation', paragraph_id=33, start=274, end=284), KiltDocAnchor(text='asymmetry', href='asymmetry', paragraph_id=34, start=47, end=56), KiltDocAnchor(text='indefinite article', href='Article%20%28grammar%29%23Indefinite%20article', paragraph_id=35, start=53, end=71), KiltDocAnchor(text='brassiere', href='brassiere', paragraph_id=36, start=97, end=106), KiltDocAnchor(text='Latin "AE"', href='%C3%86', paragraph_id=39, start=18, end=28), KiltDocAnchor(text='diacritic', href='diacritic', paragraph_id=40, start=19, end=28), KiltDocAnchor(text='Å å', href='%C3%85', paragraph_id=40, start=31, end=34), KiltDocAnchor(text='Ǻ ǻ', href='%C7%BA', paragraph_id=40, start=35, end=38), KiltDocAnchor(text='Ḁ ḁ', href='Ring%20%28diacritic%29', paragraph_id=40, start=39, end=42), KiltDocAnchor(text='ẚ', href='%E1%BA%9A', paragraph_id=40, start=43, end=44), KiltDocAnchor(text='Ă ă', href='%C4%82', paragraph_id=40, start=45, end=48), KiltDocAnchor(text='Ặ ặ', href='%E1%BA%B6', paragraph_id=40, start=49, end=52), KiltDocAnchor(text='Ắ ắ', href='%E1%BA%AE', paragraph_id=40, start=53, end=56), KiltDocAnchor(text='Ằ ằ', href='%E1%BA%B0', paragraph_id=40, start=57, end=60), KiltDocAnchor(text='Ẳ ẳ', href='%E1%BA%B2', paragraph_id=40, start=61, end=64), KiltDocAnchor(text='Ẵ ẵ', href='%E1%BA%B4', paragraph_id=40, start=65, end=68), KiltDocAnchor(text='Ȃ ȃ', href='%C8%82', paragraph_id=40, start=69, end=72), KiltDocAnchor(text='Â â', href='%C3%82', paragraph_id=40, start=73, end=76), KiltDocAnchor(text='Ậ ậ', href='%E1%BA%AC', paragraph_id=40, start=77, end=80), KiltDocAnchor(text='Ấ ấ', href='%E1%BA%A4', paragraph_id=40, start=81, end=84), KiltDocAnchor(text='Ầ ầ', href='%E1%BA%A6', paragraph_id=40, start=85, end=88), KiltDocAnchor(text='Ẫ ẫ', href='%E1%BA%AA', paragraph_id=40, start=89, end=92), KiltDocAnchor(text='Ẩ ẩ', href='%E1%BA%A8', paragraph_id=40, start=93, end=96), KiltDocAnchor(text='Ả ả', href='%E1%BA%A2', paragraph_id=40, start=97, end=100), KiltDocAnchor(text='Ǎ ǎ', href='Caron', paragraph_id=40, start=101, end=104), KiltDocAnchor(text='Ⱥ ⱥ', href='Bar%20%28diacritic%29', paragraph_id=40, start=105, end=108), KiltDocAnchor(text='Ȧ ȧ', href='Dot%20%28diacritic%29', paragraph_id=40, start=109, end=112), KiltDocAnchor(text='Ǡ ǡ', href='%C7%A0', paragraph_id=40, start=113, end=116), KiltDocAnchor(text='Ạ ạ', href='Dot%20%28diacritic%29', paragraph_id=40, start=117, end=120), KiltDocAnchor(text='Ä ä', href='%C3%84', paragraph_id=40, start=121, end=124), KiltDocAnchor(text='Ǟ ǟ', href='%C7%9E', paragraph_id=40, start=125, end=128), KiltDocAnchor(text='À à', href='%C3%80', paragraph_id=40, start=129, end=132), KiltDocAnchor(text='Ȁ ȁ', href='%C8%80', paragraph_id=40, start=133, end=136), KiltDocAnchor(text='Á á', href='%C3%81', paragraph_id=40, start=137, end=140), KiltDocAnchor(text='Ā ā', href='%C4%80', paragraph_id=40, start=141, end=144), KiltDocAnchor(text='Ã ã', href='%C3%83', paragraph_id=40, start=151, end=154), KiltDocAnchor(text='Ą ą', href='%C4%84', paragraph_id=40, start=155, end=158), KiltDocAnchor(text='ᶏ', href='%E1%B6%8F', paragraph_id=40, start=177, end=178), KiltDocAnchor(text='Phonetic alphabet', href='Phonetic%20transcription%23Alphabetic', paragraph_id=41, start=12, end=29), KiltDocAnchor(text='International Phonetic Alphabet', href='International%20Phonetic%20Alphabet', paragraph_id=41, start=56, end=87), KiltDocAnchor(text='Latin letter alpha / script A', href='Latin%20alpha', paragraph_id=42, start=18, end=47), KiltDocAnchor(text='open back unrounded vowel', href='open%20back%20unrounded%20vowel', paragraph_id=42, start=69, end=94), KiltDocAnchor(text='Turned A', href='Turned%20A', paragraph_id=44, start=18, end=26), KiltDocAnchor(text='near-open central vowel', href='near-open%20central%20vowel', paragraph_id=44, start=47, end=70), KiltDocAnchor(text='Turned V', href='Turned%20V', paragraph_id=45, start=18, end=26), KiltDocAnchor(text='open-mid back unrounded vowel', href='open-mid%20back%20unrounded%20vowel', paragraph_id=45, start=89, end=118), KiltDocAnchor(text='open back rounded vowel', href='open%20back%20rounded%20vowel', paragraph_id=46, start=63, end=86), KiltDocAnchor(text='obsolete or non-standard symbol in the International Phonetic Alphabet', href='Obsolete%20and%20nonstandard%20symbols%20in%20the%20International%20Phonetic%20Alphabet', paragraph_id=48, start=36, end=106), KiltDocAnchor(text='Uralic Phonetic Alphabet', href='Uralic%20Phonetic%20Alphabet', paragraph_id=49, start=53, end=77), KiltDocAnchor(text='Indo-European studies', href='Indo-European%20studies', paragraph_id=50, start=45, end=66), KiltDocAnchor(text='Teuthonista', href='Teuthonista', paragraph_id=51, start=61, end=72), KiltDocAnchor(text='Ugaritic', href='Ugaritic', paragraph_id=52, start=60, end=68), KiltDocAnchor(text='ordinal indicator', href='ordinal%20indicator', paragraph_id=54, start=19, end=36), KiltDocAnchor(text='Ångström', href='%C3%85ngstr%C3%B6m', paragraph_id=55, start=16, end=24), KiltDocAnchor(text='predicate logic', href='predicate%20logic', paragraph_id=56, start=51, end=66), KiltDocAnchor(text='universal quantification', href='universal%20quantification', paragraph_id=56, start=78, end=102), KiltDocAnchor(text='At sign', href='At%20sign', paragraph_id=57, start=16, end=23), KiltDocAnchor(text='Argentine austral', href='Argentine%20austral', paragraph_id=58, start=16, end=33), KiltDocAnchor(text='Semitic', href='Phoenician%20alphabet', paragraph_id=60, start=16, end=23), KiltDocAnchor(text='Aleph', href='Aleph', paragraph_id=60, start=31, end=36), KiltDocAnchor(text='Greek', href='Greek%20alphabet', paragraph_id=61, start=18, end=23), KiltDocAnchor(text='Alpha', href='Alpha', paragraph_id=61, start=31, end=36), KiltDocAnchor(text='Cyrillic', href='Cyrillic', paragraph_id=62, start=18, end=26), KiltDocAnchor(text='A', href='A%20%28Cyrillic%29', paragraph_id=62, start=34, end=35), KiltDocAnchor(text='Coptic', href='Coptic%20alphabet', paragraph_id=63, start=14, end=20), KiltDocAnchor(text='Old Italic', href='Old%20Italic%20script', paragraph_id=64, start=16, end=26), KiltDocAnchor(text='Runic', href='Runes', paragraph_id=65, start=14, end=19), KiltDocAnchor(text='ansuz', href='Ansuz%20%28rune%29', paragraph_id=65, start=27, end=32), KiltDocAnchor(text='Gothic', href='Gothic%20alphabet', paragraph_id=66, start=14, end=20)), ('ISO basic Latin letters',), 'Q9659', '907008348', '2019-07-19T20:25:53Z', '906725792', '290', 'https://en.wikipedia.org/w/index.php?title=A&oldid=907008348'),
            9: KiltDoc('25', 'Autism', re.compile('^Autism\nAutism is a developmental disorder characterized by difficulties with social interaction and .{46982} job market\\. Some studies also find decreased earning among parents who care for autistic children\\.\n$', flags=48), ('Autism\n', "Autism is a developmental disorder characterized by difficulties with social interaction and communication, and by restricted and repetitive behavior. Parents usually notice signs during the first three years of their child's life. These signs often develop gradually, though some children with autism reach their developmental milestones at a normal pace before worsening.\n", 'Autism is associated with a combination of genetic and environmental factors. Risk factors during pregnancy include certain infections, such as rubella, toxins including valproic acid, alcohol, cocaine, pesticides and air pollution, fetal growth restriction, and autoimmune diseases. Controversies surround other proposed environmental causes; for example, the vaccine hypothesis, which has been disproven. Autism affects information processing in the brain by altering connections and organization of nerve cells and their synapses. How this occurs is not well understood. In the DSM-5, autism and less severe forms of the condition, including Asperger syndrome and pervasive developmental disorder not otherwise specified (PDD-NOS), have been combined into the diagnosis of autism spectrum disorder (ASD).\n', 'Early behavioral interventions or speech therapy can help children with autism gain self-care, social, and communication skills. Although there is no known cure, there have been cases of children who recovered. Not many children with autism live independently after reaching adulthood, though some are successful. An autistic culture has developed, with some individuals seeking a cure and others believing autism should be accepted as a difference and not treated as a disorder.\n', 'Globally, autism is estimated to affect 24.8 million people . In the 2000s, the number of people affected was estimated at 1–2 per 1,000 people worldwide. In the developed countries, about 1.5% of children are diagnosed with ASD , from 0.7% in 2000 in the United States. It occurs four-to-five times more often in males than females. The number of people diagnosed has increased dramatically since the 1960s, which may be partly due to changes in diagnostic practice. The question of whether actual rates have increased is unresolved.\n', 'Section::::Characteristics.\n', 'Autism is a highly variable, neurodevelopmental disorder whose symptoms first appears during infancy or childhood, and generally follows a steady course without remission. People with autism may be severely impaired in some respects but normal, or even superior, in others. Overt symptoms gradually begin after the age of six months, become established by age two or three years and tend to continue through adulthood, although often in more muted form. It is distinguished not by a single symptom but by a characteristic triad of symptoms: impairments in social interaction; impairments in communication; and restricted interests and repetitive behavior. Other aspects, such as atypical eating, are also common but are not essential for diagnosis. Individual symptoms of autism occur in the general population and appear not to associate highly, without a sharp line separating pathologically severe from common traits.\n', 'Section::::Characteristics.:Social development.\n', 'Social deficits distinguish autism and the related autism spectrum disorders (ASD; see Classification) from other developmental disorders. People with autism have social impairments and often lack the intuition about others that many people take for granted. Noted autistic Temple Grandin described her inability to understand the social communication of neurotypicals, or people with normal neural development, as leaving her feeling "like an anthropologist on Mars".\n', "Unusual social development becomes apparent early in childhood. Autistic infants show less attention to social stimuli, smile and look at others less often, and respond less to their own name. Autistic toddlers differ more strikingly from social norms; for example, they have less eye contact and turn-taking, and do not have the ability to use simple movements to express themselves, such as pointing at things. Three- to five-year-old children with autism are less likely to exhibit social understanding, approach others spontaneously, imitate and respond to emotions, communicate nonverbally, and take turns with others. However, they do form attachments to their primary caregivers. Most children with autism display moderately less attachment security than neurotypical children, although this difference disappears in children with higher mental development or less severe ASD. Older children and adults with ASD perform worse on tests of face and emotion recognition although this may be partly due to a lower ability to define a person's own emotions.\n", 'Children with high-functioning autism suffer from more intense and frequent loneliness compared to non-autistic peers, despite the common belief that children with autism prefer to be alone. Making and maintaining friendships often proves to be difficult for those with autism. For them, the quality of friendships, not the number of friends, predicts how lonely they feel. Functional friendships, such as those resulting in invitations to parties, may affect the quality of life more deeply.\n', 'There are many anecdotal reports, but few systematic studies, of aggression and violence in individuals with ASD. The limited data suggest that, in children with intellectual disability, autism is associated with aggression, destruction of property, and meltdowns.\n', 'Section::::Characteristics.:Communication.\n', "About a third to a half of individuals with autism do not develop enough natural speech to meet their daily communication needs. Differences in communication may be present from the first year of life, and may include delayed onset of babbling, unusual gestures, diminished responsiveness, and vocal patterns that are not synchronized with the caregiver. In the second and third years, children with autism have less frequent and less diverse babbling, consonants, words, and word combinations; their gestures are less often integrated with words. Children with autism are less likely to make requests or share experiences, and are more likely to simply repeat others' words (echolalia) or reverse pronouns. Joint attention seems to be necessary for functional speech, and deficits in joint attention seem to distinguish infants with ASD. For example, they may look at a pointing hand instead of the pointed-at object, and they consistently fail to point at objects in order to comment on or share an experience. Children with autism may have difficulty with imaginative play and with developing symbols into language.\n", 'In a pair of studies, high-functioning children with autism aged 8–15 performed equally well as, and as adults better than, individually matched controls at basic language tasks involving vocabulary and spelling. Both autistic groups performed worse than controls at complex language tasks such as figurative language, comprehension and inference. As people are often sized up initially from their basic language skills, these studies suggest that people speaking to autistic individuals are more likely to overestimate what their audience comprehends.\n', 'Section::::Characteristics.:Repetitive behavior.\n', 'Autistic individuals can display many forms of repetitive or restricted behavior, which the Repetitive Behavior Scale-Revised (RBS-R) categorizes as follows.\n', 'BULLET::::- Stereotyped behaviors: Repetitive movements, such as hand flapping, head rolling, or body rocking.\n', 'BULLET::::- Compulsive behaviors: Time-consuming behaviors intended to reduce anxiety that an individual feels compelled to perform repeatedly or according to rigid rules, such as placing objects in a specific order, checking things, or hand washing.\n', 'BULLET::::- Sameness: Resistance to change; for example, insisting that the furniture not be moved or refusing to be interrupted.\n', 'BULLET::::- Ritualistic behavior: Unvarying pattern of daily activities, such as an unchanging menu or a dressing ritual. This is closely associated with sameness and an independent validation has suggested combining the two factors.\n', 'BULLET::::- Restricted interests: Interests or fixations that are abnormal in theme or intensity of focus, such as preoccupation with a single television program, toy, or game.\n', 'BULLET::::- Self-injury: Behaviors such as eye-poking, skin-picking, hand-biting and head-banging.\n', 'No single repetitive or self-injurious behavior seems to be specific to autism, but autism appears to have an elevated pattern of occurrence and severity of these behaviors.\n', 'Section::::Characteristics.:Other symptoms.\n', 'Autistic individuals may have symptoms that are independent of the diagnosis, but that can affect the individual or the family.\n', 'An estimated 0.5% to 10% of individuals with ASD show unusual abilities, ranging from splinter skills such as the memorization of trivia to the extraordinarily rare talents of prodigious autistic savants. Many individuals with ASD show superior skills in perception and attention, relative to the general population. Sensory abnormalities are found in over 90% of those with autism, and are considered core features by some, although there is no good evidence that sensory symptoms differentiate autism from other developmental disorders. Differences are greater for under-responsivity (for example, walking into things) than for over-responsivity (for example, distress from loud noises) or for sensation seeking (for example, rhythmic movements). An estimated 60–80% of autistic people have motor signs that include poor muscle tone, poor motor planning, and toe walking; deficits in motor coordination are pervasive across ASD and are greater in autism proper. Unusual eating behavior occurs in about three-quarters of children with ASD, to the extent that it was formerly a diagnostic indicator. Selectivity is the most common problem, although eating rituals and food refusal also occur.\n', 'Parents of children with ASD have higher levels of stress. Siblings of children with ASD report greater admiration of and less conflict with the affected sibling than siblings of unaffected children and were similar to siblings of children with Down syndrome in these aspects of the sibling relationship. However, they reported lower levels of closeness and intimacy than siblings of children with Down syndrome; siblings of individuals with ASD have greater risk of negative well-being and poorer sibling relationships as adults. There is tentative evidence that autism occurs more frequently in people with gender dysphoria.\n', 'Gastrointestinal problems are one of the most commonly associated medical disorders in people with autism. These are linked to greater social impairment, irritability, behavior and sleep problems, language impairments and mood changes.\n', 'Section::::Causes.\n', "It has long been presumed that there is a common cause at the genetic, cognitive, and neural levels for autism's characteristic triad of symptoms. However, there is increasing suspicion that autism is instead a complex disorder whose core aspects have distinct causes that often co-occur.\n", 'Autism has a strong genetic basis, although the genetics of autism are complex and it is unclear whether ASD is explained more by rare mutations with major effects, or by rare multigene interactions of common genetic variants. Complexity arises due to interactions among multiple genes, the environment, and epigenetic factors which do not change DNA sequencing but are heritable and influence gene expression. Many genes have been associated with autism through sequencing the genomes of affected individuals and their parents. Studies of twins suggest that heritability is 0.7 for autism and as high as 0.9 for ASD, and siblings of those with autism are about 25 times more likely to be autistic than the general population. However, most of the mutations that increase autism risk have not been identified. Typically, autism cannot be traced to a Mendelian (single-gene) mutation or to a single chromosome abnormality, and none of the genetic syndromes associated with ASDs have been shown to selectively cause ASD. Numerous candidate genes have been located, with only small effects attributable to any particular gene. Most loci individually explain less than 1% of cases of autism. The large number of autistic individuals with unaffected family members may result from spontaneous structural variation\xa0— such as deletions, duplications or inversions in genetic material during meiosis. Hence, a substantial fraction of autism cases may be traceable to genetic causes that are highly heritable but not inherited: that is, the mutation that causes the autism is not present in the parental genome. Autism may be underdiagnosed in women and girls due to an assumption that it is primarily a male condition.\n', 'Maternal nutrition and inflammation during preconception and pregnancy influences fetal neurodevelopment. Intrauterine growth restriction is associated with ASD, in both term and preterm infants. Maternal inflammatory and autoimmune diseases may damage fetal tissues, aggravating a genetic problem or damaging the nervous system.\n', 'Exposure to air pollution during pregnancy, especially heavy metals and particulates, may increase the risk of autism. Environmental factors that have been claimed without evidence to contribute to or exacerbate autism include certain foods, infectious diseases, solvents, PCBs, phthalates and phenols used in plastic products, pesticides, brominated flame retardants, alcohol, smoking, illicit drugs, vaccines, and prenatal stress. Some, such as the MMR vaccine, have been completely disproven.\n', 'Parents may first become aware of autistic symptoms in their child around the time of a routine vaccination. This has led to unsupported theories blaming vaccine "overload", a vaccine preservative, or the MMR vaccine for causing autism. The latter theory was supported by a litigation-funded study that has since been shown to have been "an elaborate fraud". Although these theories lack convincing scientific evidence and are biologically implausible, parental concern about a potential vaccine link with autism has led to lower rates of childhood immunizations, outbreaks of previously controlled childhood diseases in some countries, and the preventable deaths of several children.\n', 'Section::::Mechanism.\n', "Autism's symptoms result from maturation-related changes in various systems of the brain. How autism occurs is not well understood. Its mechanism can be divided into two areas: the pathophysiology of brain structures and processes associated with autism, and the neuropsychological linkages between brain structures and behaviors. The behaviors appear to have multiple pathophysiologies.\n", 'There is evidence that gut–brain axis abnormalities may be involved. A 2015 review proposed that immune dysregulation, gastrointestinal inflammation, malfunction of the autonomic nervous system, gut flora alterations, and food metabolites may cause brain neuroinflammation and dysfunction. A 2016 review concludes that enteric nervous system abnormalities might play a role in neurological disorders such as autism. Neural connections and the immune system are a pathway that may allow diseases originated in the intestine to spread to the brain.\n', 'Several lines of evidence point to synaptic dysfunction as a cause of autism. Some rare mutations may lead to autism by disrupting some synaptic pathways, such as those involved with cell adhesion. Gene replacement studies in mice suggest that autistic symptoms are closely related to later developmental steps that depend on activity in synapses and on activity-dependent changes. All known teratogens (agents that cause birth defects) related to the risk of autism appear to act during the first eight weeks from conception, and though this does not exclude the possibility that autism can be initiated or affected later, there is strong evidence that autism arises very early in development.\n', 'Section::::Diagnosis.\n', 'Diagnosis is based on behavior, not cause or mechanism. Under the DSM-5, autism is characterized by persistent deficits in social communication and interaction across multiple contexts, as well as restricted, repetitive patterns of behavior, interests, or activities. These deficits are present in early childhood, typically before age three, and lead to clinically significant functional impairment. Sample symptoms include lack of social or emotional reciprocity, stereotyped and repetitive use of language or idiosyncratic language, and persistent preoccupation with unusual objects. The disturbance must not be better accounted for by Rett syndrome, intellectual disability or global developmental delay. ICD-10 uses essentially the same definition.\n', 'Several diagnostic instruments are available. Two are commonly used in autism research: the Autism Diagnostic Interview-Revised (ADI-R) is a semistructured parent interview, and the Autism Diagnostic Observation Schedule (ADOS) uses observation and interaction with the child. The Childhood Autism Rating Scale (CARS) is used widely in clinical environments to assess severity of autism based on observation of children. The Diagnostic interview for social and communication disorders (DISCO) may also be used.\n', 'A pediatrician commonly performs a preliminary investigation by taking developmental history and physically examining the child. If warranted, diagnosis and evaluations are conducted with help from ASD specialists, observing and assessing cognitive, communication, family, and other factors using standardized tools, and taking into account any associated medical conditions. A pediatric neuropsychologist is often asked to assess behavior and cognitive skills, both to aid diagnosis and to help recommend educational interventions. A differential diagnosis for ASD at this stage might also consider intellectual disability, hearing impairment, and a specific language impairment such as Landau–Kleffner syndrome. The presence of autism can make it harder to diagnose coexisting psychiatric disorders such as depression.\n', "Clinical genetics evaluations are often done once ASD is diagnosed, particularly when other symptoms already suggest a genetic cause. Although genetic technology allows clinical geneticists to link an estimated 40% of cases to genetic causes, consensus guidelines in the US and UK are limited to high-resolution chromosome and fragile X testing. A genotype-first model of diagnosis has been proposed, which would routinely assess the genome's copy number variations. As new genetic tests are developed several ethical, legal, and social issues will emerge. Commercial availability of tests may precede adequate understanding of how to use test results, given the complexity of autism's genetics. Metabolic and neuroimaging tests are sometimes helpful, but are not routine.\n", 'ASD can sometimes be diagnosed by age 14 months, although diagnosis becomes increasingly stable over the first three years of life: for example, a one-year-old who meets diagnostic criteria for ASD is less likely than a three-year-old to continue to do so a few years later. In the UK the National Autism Plan for Children recommends at most 30 weeks from first concern to completed diagnosis and assessment, though few cases are handled that quickly in practice. Although the symptoms of autism and ASD begin early in childhood, they are sometimes missed; years later, adults may seek diagnoses to help them or their friends and family understand themselves, to help their employers make adjustments, or in some locations to claim disability living allowances or other benefits. Girls are often diagnosed later than boys.\n', 'Underdiagnosis and overdiagnosis are problems in marginal cases, and much of the recent increase in the number of reported ASD cases is likely due to changes in diagnostic practices. The increasing popularity of drug treatment options and the expansion of benefits has given providers incentives to diagnose ASD, resulting in some overdiagnosis of children with uncertain symptoms. Conversely, the cost of screening and diagnosis and the challenge of obtaining payment can inhibit or delay diagnosis. It is particularly hard to diagnose autism among the visually impaired, partly because some of its diagnostic criteria depend on vision, and partly because autistic symptoms overlap with those of common blindness syndromes or blindisms.\n', 'Section::::Diagnosis.:Classification.\n', 'Autism is one of the five pervasive developmental disorders (PDD), which are characterized by widespread abnormalities of social interactions and communication, and severely restricted interests and highly repetitive behavior. These symptoms do not imply sickness, fragility, or emotional disturbance.\n', 'Of the five PDD forms, Asperger syndrome is closest to autism in signs and likely causes; Rett syndrome and childhood disintegrative disorder share several signs with autism, but may have unrelated causes; PDD not otherwise specified (PDD-NOS; also called "atypical autism") is diagnosed when the criteria are not met for a more specific disorder. Unlike with autism, people with Asperger syndrome have no substantial delay in language development. The terminology of autism can be bewildering, with autism, Asperger syndrome and PDD-NOS often called the "autism spectrum disorders" (ASD) or sometimes the "autistic disorders", whereas autism itself is often called "autistic disorder", "childhood autism", or "infantile autism". In this article, "autism" refers to the classic autistic disorder; in clinical practice, though, "autism", "ASD", and "PDD" are often used interchangeably. ASD, in turn, is a subset of the broader autism phenotype, which describes individuals who may not have ASD but do have autistic-like traits, such as avoiding eye contact.\n', 'The manifestations of autism cover a wide spectrum, ranging from individuals with severe impairments—who may be silent, developmentally disabled, and locked into hand flapping and rocking—to high functioning individuals who may have active but distinctly odd social approaches, narrowly focused interests, and verbose, pedantic communication. Because the behavior spectrum is continuous, boundaries between diagnostic categories are necessarily somewhat arbitrary. Sometimes the syndrome is divided into low-, medium- or high-functioning autism (LFA, MFA, and HFA), based on IQ thresholds, or on how much support the individual requires in daily life; these subdivisions are not standardized and are controversial. Autism can also be divided into syndromal and non-syndromal autism; the syndromal autism is associated with severe or profound intellectual disability or a congenital syndrome with physical symptoms, such as tuberous sclerosis. Although individuals with Asperger syndrome tend to perform better cognitively than those with autism, the extent of the overlap between Asperger syndrome, HFA, and non-syndromal autism is unclear.\n', 'Some studies have reported diagnoses of autism in children due to a loss of language or social skills, as opposed to a failure to make progress, typically from 15 to 30 months of age. The validity of this distinction remains controversial; it is possible that regressive autism is a specific subtype, or that there is a continuum of behaviors between autism with and without regression.\n', 'Research into causes has been hampered by the inability to identify biologically meaningful subgroups within the autistic population and by the traditional boundaries between the disciplines of psychiatry, psychology, neurology and pediatrics. Newer technologies such as fMRI and diffusion tensor imaging can help identify biologically relevant phenotypes (observable traits) that can be viewed on brain scans, to help further neurogenetic studies of autism; one example is lowered activity in the fusiform face area of the brain, which is associated with impaired perception of people versus objects. It has been proposed to classify autism using genetics as well as behavior.\n', 'Section::::Screening.\n', 'About half of parents of children with ASD notice their child\'s unusual behaviors by age 18 months, and about four-fifths notice by age 24 months. According to an article, failure to meet any of the following milestones "is an absolute indication to proceed with further evaluations. Delay in referral for such testing may delay early diagnosis and treatment and affect the long-term outcome".\n', 'BULLET::::- No babbling by 12 months.\n', 'BULLET::::- No gesturing (pointing, waving, etc.) by 12 months.\n', 'BULLET::::- No single words by 16 months.\n', 'BULLET::::- No two-word (spontaneous, not just echolalic) phrases by 24 months.\n', 'BULLET::::- Loss of any language or social skills, at any age.\n', "The United States Preventive Services Task Force in 2016 found it was unclear if screening was beneficial or harmful among children in whom there is no concerns. The Japanese practice is to screen all children for ASD at 18 and 24 months, using autism-specific formal screening tests. In contrast, in the UK, children whose families or doctors recognize possible signs of autism are screened. It is not known which approach is more effective. Screening tools include the Modified Checklist for Autism in Toddlers (M-CHAT), the Early Screening of Autistic Traits Questionnaire, and the First Year Inventory; initial data on M-CHAT and its predecessor, the Checklist for Autism in Toddlers (CHAT), on children aged 18–30 months suggests that it is best used in a clinical setting and that it has low sensitivity (many false-negatives) but good specificity (few false-positives). It may be more accurate to precede these tests with a broadband screener that does not distinguish ASD from other developmental disorders. Screening tools designed for one culture's norms for behaviors like eye contact may be inappropriate for a different culture. Although genetic screening for autism is generally still impractical, it can be considered in some cases, such as children with neurological symptoms and dysmorphic features.\n", 'Section::::Prevention.\n', 'While infection with rubella during pregnancy causes fewer than 1% of cases of autism, vaccination against rubella can prevent many of those cases.\n', 'Section::::Management.\n', "The main goals when treating children with autism are to lessen associated deficits and family distress, and to increase quality of life and functional independence. In general, higher IQs are correlated with greater responsiveness to treatment and improved treatment outcomes. No single treatment is best and treatment is typically tailored to the child's needs. Families and the educational system are the main resources for treatment. Services should be carried out by behavior analysts, special education teachers, speech pathologists, and licensed psychologists. Studies of interventions have methodological problems that prevent definitive conclusions about efficacy. However, the development of evidence-based interventions has advanced in recent years. Although many psychosocial interventions have some positive evidence, suggesting that some form of treatment is preferable to no treatment, the methodological quality of systematic reviews of these studies has generally been poor, their clinical results are mostly tentative, and there is little evidence for the relative effectiveness of treatment options. Intensive, sustained special education programs and behavior therapy early in life can help children acquire self-care, communication, and job skills, and often improve functioning and decrease symptom severity and maladaptive behaviors; claims that intervention by around age three years is crucial are not substantiated. While medications have not been found to help with core symptoms, they may be used for associated symptoms, such as irritability, inattention, or repetitive behavior patterns.\n", 'Section::::Management.:Education.\n', 'Educational interventions often used include applied behavior analysis (ABA), developmental models, structured teaching, speech and language therapy, social skills therapy, and occupational therapy. Among these approaches, interventions either treat autistic features comprehensively, or focalize treatment on a specific area of deficit. The quality of research for early intensive behavioral intervention (EIBI)—a treatment procedure carried out with very young children that incorporates over thirty hours per week of the structured type of ABA—is currently low, and more vigorous research designs with larger sample sizes are needed. Two theoretical frameworks outlined for early childhood intervention include structured and naturalistic ABA interventions, and developmental social pragmatic models (DSP). One interventional strategy utilizes a parent training model, which teaches parents how to implement various ABA and DSP techniques, allowing for parents to disseminate interventions themselves. Various DSP programs have been developed to explicitly deliver intervention systems through at-home parent implementation. Despite the recent development of parent training models, these interventions have demonstrated effectiveness in numerous studies, being evaluated as a probable efficacious mode of treatment.\n', 'Early, intensive ABA therapy has demonstrated effectiveness in enhancing communication, as well as adaptive and global functioning in preschool children; it is well-established for improving the intellectual performance of that age group. Similarly, a teacher-implemented intervention that utilizes a more naturalistic form of ABA combined with a developmental social pragmatic approach has been found to be beneficial in improving social-communication skills in young children, although there is less evidence in its treatment of global symptoms. Neuropsychological reports are often poorly communicated to educators, resulting in a gap between what a report recommends and what education is provided. It is not known whether treatment programs for children lead to significant improvements after the children grow up, and the limited research on the effectiveness of adult residential programs shows mixed results. The appropriateness of including children with varying severity of autism spectrum disorders in the general education population is a subject of current debate among educators and researchers.\n', 'Section::::Management.:Medication.\n', "Medications may be used to treat ASD symptoms that interfere with integrating a child into home or school when behavioral treatment fails. They may also be used for associated health problems, such as ADHD or anxiety. More than half of US children diagnosed with ASD are prescribed psychoactive drugs or anticonvulsants, with the most common drug classes being antidepressants, stimulants, and antipsychotics. The atypical antipsychotic drugs risperidone and aripiprazole are FDA-approved for treating associated aggressive and self-injurious behaviors. However, their side effects must be weighed against their potential benefits, and people with autism may respond atypically. Side effects, for example, may include weight gain, tiredness, drooling, and aggression. SSRI antidepressants, such as fluoxetine and fluvoxamine, have been shown to be effective in reducing repetitive and ritualistic behaviors, while the stimulant medication methylphenidate is beneficial for some children with co-morbid inattentiveness or hyperactivity. There is scant reliable research about the effectiveness or safety of drug treatments for adolescents and adults with ASD. No known medication relieves autism's core symptoms of social and communication impairments. Experiments in mice have reversed or reduced some symptoms related to autism by replacing or modulating gene function, suggesting the possibility of targeting therapies to specific rare mutations known to cause autism.\n", 'Section::::Management.:Alternative medicine.\n', "Although many alternative therapies and interventions are available, few are supported by scientific studies. Treatment approaches have little empirical support in quality-of-life contexts, and many programs focus on success measures that lack predictive validity and real-world relevance. Some alternative treatments may place the child at risk. The preference that children with autism have for unconventional foods can lead to reduction in bone cortical thickness with this being greater in those on casein-free diets, as a consequence of the low intake of calcium and vitamin D; however, suboptimal bone development in ASD has also been associated with lack of exercise and gastrointestinal disorders. In 2005, botched chelation therapy killed a five-year-old child with autism. Chelation is not recommended for people with ASD since the associated risks outweigh any potential benefits. Another alternative medicine practice with no evidence is CEASE therapy, a mixture of homeopathy, supplements, and 'vaccine detoxing'.\n", 'Although popularly used as an alternative treatment for people with autism, as of 2018 there is no good evidence to recommend a gluten- and casein-free diet as a standard treatment. A 2018 review concluded that it may be a therapeutic option for specific groups of children with autism, such as those with known food intolerances or allergies, or with food intolerance markers. The authors analyzed the prospective trials conducted to date that studied the efficacy of the gluten- and casein-free diet in children with ASD (4 in total). All of them compared gluten- and casein-free diet versus normal diet with a control group (2 double blind randomized controlled trials, 1 double blind crossover trial, 1 single blind trial). In two of the studies, whose duration was 12 and 24 months, a significant improvement in ASD symptoms (efficacy rate 50%) was identified. In the other two studies, whose duration was 3 months, no significant effect was observed. The authors concluded that a longer duration of the diet may be necessary to achieve the improvement of the ASD symptoms. Other problems documented in the trials carried out include transgressions of the diet, small sample size, the heterogeneity of the participants and the possibility of a placebo effect.\n', 'In the subset of people who have gluten sensitivity there is limited evidence that suggests that a gluten-free diet may improve some autistic behaviors.\n', 'There is tentative evidence that music therapy may improve social interactions, verbal communication, and non-verbal communication skills. There has been early research looking at hyperbaric treatments in children with autism.\n', 'Section::::Prognosis.\n', 'There is no known cure. Children recover occasionally, so that they lose their diagnosis of ASD; this occurs sometimes after intensive treatment and sometimes not. It is not known how often recovery happens; reported rates in unselected samples have ranged from 3% to 25%. Most children with autism acquire language by age five or younger, though a few have developed communication skills in later years. Most children with autism lack social support, meaningful relationships, future employment opportunities or self-determination. Although core difficulties tend to persist, symptoms often become less severe with age.\n', 'Few high-quality studies address long-term prognosis. Some adults show modest improvement in communication skills, but a few decline; no study has focused on autism after midlife. Acquiring language before age six, having an IQ above 50, and having a marketable skill all predict better outcomes; independent living is unlikely with severe autism.\n', 'Many individuals with autism face significant obstacles in transitioning to adulthood. Compared to the general population individuals with autism are more likely to be unemployed and to have never had a job. People in their 20s with autism have an employment rate of 58%.\n', 'Section::::Epidemiology.\n', "Most recent reviews tend to estimate a prevalence of 1–2 per 1,000 for autism and close to 6 per 1,000 for ASD, and 11 per 1,000 children in the United States for ASD as of 2008; because of inadequate data, these numbers may underestimate ASD's true rate. Globally, autism affects an estimated 24.8 million people , while Asperger syndrome affects a further 37.2 million. In 2012, the NHS estimated that the overall prevalence of autism among adults aged 18 years and over in the UK was 1.1%. Rates of PDD-NOS's has been estimated at 3.7 per 1,000, Asperger syndrome at roughly 0.6 per 1,000, and childhood disintegrative disorder at 0.02 per 1,000. CDC estimates about 1 out of 59 (1.7%) for 2014, an increase from 1 out of every 68 children (1.5%) for 2010.\n", "The number of reported cases of autism increased dramatically in the 1990s and early 2000s. This increase is largely attributable to changes in diagnostic practices, referral patterns, availability of services, age at diagnosis, and public awareness, though unidentified environmental risk factors cannot be ruled out. The available evidence does not rule out the possibility that autism's true prevalence has increased; a real increase would suggest directing more attention and funding toward changing environmental factors instead of continuing to focus on genetics.\n", 'Boys are at higher risk for ASD than girls. The sex ratio averages 4.3:1 and is greatly modified by cognitive impairment: it may be close to 2:1 with intellectual disability and more than 5.5:1 without. Several theories about the higher prevalence in males have been investigated, but the cause of the difference is unconfirmed; one theory is that females are underdiagnosed.\n', 'Although the evidence does not implicate any single pregnancy-related risk factor as a cause of autism, the risk of autism is associated with advanced age in either parent, and with diabetes, bleeding, and use of psychiatric drugs in the mother during pregnancy. The risk is greater with older fathers than with older mothers; two potential explanations are the known increase in mutation burden in older sperm, and the hypothesis that men marry later if they carry genetic liability and show some signs of autism. Most professionals believe that race, ethnicity, and socioeconomic background do not affect the occurrence of autism.\n', 'Several other conditions are common in children with autism. They include:\n', 'BULLET::::- Genetic disorders. About 10–15% of autism cases have an identifiable Mendelian (single-gene) condition, chromosome abnormality, or other genetic syndrome, and ASD is associated with several genetic disorders.\n', "BULLET::::- Intellectual disability. The percentage of autistic individuals who also meet criteria for intellectual disability has been reported as anywhere from 25% to 70%, a wide variation illustrating the difficulty of assessing intelligence of individuals on the autism spectrum. In comparison, for PDD-NOS the association with intellectual disability is much weaker, and by definition, the diagnosis of Asperger's excludes intellectual disability.\n", "BULLET::::- Anxiety disorders are common among children with ASD; there are no firm data, but studies have reported prevalences ranging from 11% to 84%. Many anxiety disorders have symptoms that are better explained by ASD itself, or are hard to distinguish from ASD's symptoms.\n", 'BULLET::::- Epilepsy, with variations in risk of epilepsy due to age, cognitive level, and type of language disorder.\n', 'BULLET::::- Several metabolic defects, such as phenylketonuria, are associated with autistic symptoms.\n', 'BULLET::::- Minor physical anomalies are significantly increased in the autistic population.\n', 'BULLET::::- Preempted diagnoses. Although the DSM-IV rules out concurrent diagnosis of many other conditions along with autism, the full criteria for Attention deficit hyperactivity disorder (ADHD), Tourette syndrome, and other of these conditions are often present and these comorbid diagnoses are increasingly accepted.\n', 'BULLET::::- Sleep problems affect about two-thirds of individuals with ASD at some point in childhood. These most commonly include symptoms of insomnia such as difficulty in falling asleep, frequent nocturnal awakenings, and early morning awakenings. Sleep problems are associated with difficult behaviors and family stress, and are often a focus of clinical attention over and above the primary ASD diagnosis.\n', 'Section::::History.\n', 'A few examples of autistic symptoms and treatments were described long before autism was named. The "Table Talk" of Martin Luther, compiled by his notetaker, Mathesius, contains the story of a 12-year-old boy who may have been severely autistic. Luther reportedly thought the boy was a soulless mass of flesh possessed by the devil, and suggested that he be suffocated, although a later critic has cast doubt on the veracity of this report. The earliest well-documented case of autism is that of Hugh Blair of Borgue, as detailed in a 1747 court case in which his brother successfully petitioned to annul Blair\'s marriage to gain Blair\'s inheritance. The Wild Boy of Aveyron, a feral child caught in 1798, showed several signs of autism; the medical student Jean Itard treated him with a behavioral program designed to help him form social attachments and to induce speech via imitation.\n', 'The New Latin word "autismus" (English translation "autism") was coined by the Swiss psychiatrist Eugen Bleuler in 1910 as he was defining symptoms of schizophrenia. He derived it from the Greek word "autós" (αὐτός, meaning "self"), and used it to mean morbid self-admiration, referring to "autistic withdrawal of the patient to his fantasies, against which any influence from outside becomes an intolerable disturbance". A Soviet child psychiatrist, Grunya Sukhareva, described a similar syndrome that was published in Russian in 1925, and in German in 1926.\n', 'Section::::History.:Clinical development and diagnoses.\n', 'The word "autism" first took its modern sense in 1938 when Hans Asperger of the Vienna University Hospital adopted Bleuler\'s terminology "autistic psychopaths" in a lecture in German about child psychology. Asperger was investigating an ASD now known as Asperger syndrome, though for various reasons it was not widely recognized as a separate diagnosis until 1981. Leo Kanner of the Johns Hopkins Hospital first used "autism" in its modern sense in English when he introduced the label "early infantile autism" in a 1943 report of 11 children with striking behavioral similarities. Almost all the characteristics described in Kanner\'s first paper on the subject, notably "autistic aloneness" and "insistence on sameness", are still regarded as typical of the autistic spectrum of disorders. It is not known whether Kanner derived the term independently of Asperger.\n', 'Donald Triplett was the first person diagnosed with autism. He was diagnosed by Kanner after being first examined in 1938, and was labeled as "case 1". Triplett was noted for his savant abilities, particularly being able to name musical notes played on a piano and to mentally multiply numbers. His father, Oliver, described him as socially withdrawn but interested in number patterns, music notes, letters of the alphabet, and U.S. president pictures. By the age of 2, he had the ability to recite the 23rd Psalm and memorized 25 questions and answers from the Presbyterian catechism. He was also interested in creating musical chords.\n', 'Kanner\'s reuse of "autism" led to decades of confused terminology like "infantile schizophrenia", and child psychiatry\'s focus on maternal deprivation led to misconceptions of autism as an infant\'s response to "refrigerator mothers". Starting in the late 1960s autism was established as a separate syndrome.\n', 'Section::::History.:Terminology and distinction from schizophrenia.\n', "As late as the mid-1970s there was little evidence of a genetic role in autism; while in 2007 it was believed to be one of the most heritable psychiatric conditions. Although the rise of parent organizations and the destigmatization of childhood ASD have affected how ASD is viewed, parents continue to feel social stigma in situations where their child's autistic behavior is perceived negatively, and many primary care physicians and medical specialists express some beliefs consistent with outdated autism research.\n", 'It took until 1980 for the DSM-III to differentiate autism from childhood schizophrenia. In 1987, the DSM-III-R provided a checklist for diagnosing autism. In May 2013, the DSM-5 was released, updating the classification for pervasive developmental disorders. The grouping of disorders, including PDD-NOS, autism, Asperger syndrome, Rett syndrome, and CDD, has been removed and replaced with the general term of Autism Spectrum Disorders. The two categories that exist are impaired social communication and/or interaction, and restricted and/or repetitive behaviors.\n', 'The Internet has helped autistic individuals bypass nonverbal cues and emotional sharing that they find difficult to deal with, and has given them a way to form online communities and work remotely. Societal and cultural aspects of autism have developed: some in the community seek a cure, while others believe that autism is simply another way of being.\n', 'Section::::Society and culture.\n', 'An autistic culture has emerged, accompanied by the autistic rights and neurodiversity movements. Events include World Autism Awareness Day, Autism Sunday, Autistic Pride Day, Autreat, and others. Organizations dedicated to promoting awareness of autism include Autism Speaks, Autism National Committee, and Autism Society of America. Social-science scholars study those with autism in hopes to learn more about "autism as a culture, transcultural comparisons... and research on social movements." While most autistic individuals do not have savant skills, many have been successful in their fields.\n', 'Section::::Society and culture.:Autism rights movement.\n', 'The autism rights movement is a social movement within the context of disability rights that emphasizes the concept of neurodiversity, viewing the autism spectrum as a result of natural variations in the human brain rather than a disorder to be cured. The autism rights movement advocates for including greater acceptance of autistic behaviors; therapies that focus on coping skills rather than imitating the behaviors those without autism; and the recognition of the autistic community as a minority group. Autism rights or neurodiversity advocates believe that the autism spectrum is genetic and should be accepted as a natural expression of the human genome. This perspective is distinct from two other likewise distinct views: the medical perspective, that autism is caused by a genetic defect and should be addressed by targeting the autism gene(s), and fringe theories that autism is caused by environmental factors such as vaccines. A common criticism against autistic activists is that the majority of them are "high-functioning" or have Asperger syndrome and do not represent the views of "low-functioning" autistic people.\n', 'Section::::Society and culture.:Employment.\n', 'About half of autistics are unemployed, and one third of those with graduate degrees may be unemployed. Among autistics who find work, most are employed in sheltered settings working for wages below the national minimum. While employers state hiring concerns about productivity and supervision, experienced employers of autistics give positive reports of above average memory and detail orientation as well as a high regard for rules and procedure in autistic employees. A majority of the economic burden of autism if caused by decreased earnings in the job market. Some studies also find decreased earning among parents who care for autistic children.\n'), (KiltDocAnchor(text='developmental disorder', href='developmental%20disorder', paragraph_id=1, start=12, end=34), KiltDocAnchor(text='developmental milestones', href='developmental%20milestones', paragraph_id=1, start=314, end=338), KiltDocAnchor(text='worsening', href='Regressive%20autism', paragraph_id=1, start=363, end=372), KiltDocAnchor(text='genetic', href='Heritability%20of%20autism', paragraph_id=2, start=43, end=50), KiltDocAnchor(text='environmental factors', href='environmental%20factors', paragraph_id=2, start=55, end=76), KiltDocAnchor(text='rubella', href='rubella', paragraph_id=2, start=144, end=151), KiltDocAnchor(text='valproic acid', href='valproic%20acid', paragraph_id=2, start=170, end=183), KiltDocAnchor(text='cocaine', href='cocaine', paragraph_id=2, start=194, end=201), KiltDocAnchor(text='pesticides', href='pesticides', paragraph_id=2, start=203, end=213), KiltDocAnchor(text='air pollution', href='air%20pollution', paragraph_id=2, start=218, end=231), KiltDocAnchor(text='fetal growth restriction', href='fetal%20growth%20restriction', paragraph_id=2, start=233, end=257), KiltDocAnchor(text='autoimmune disease', href='autoimmune%20disease', paragraph_id=2, start=263, end=281), KiltDocAnchor(text='Controversies', href='Controversies%20in%20autism', paragraph_id=2, start=284, end=297), KiltDocAnchor(text='causes', href='Causes%20of%20autism', paragraph_id=2, start=336, end=342), KiltDocAnchor(text='vaccine hypothesis', href='MMR%20vaccine%20controversy', paragraph_id=2, start=361, end=379), KiltDocAnchor(text='nerve cell', href='nerve%20cell', paragraph_id=2, start=502, end=512), KiltDocAnchor(text='synapse', href='synapse', paragraph_id=2, start=524, end=531), KiltDocAnchor(text='DSM-5', href='DSM-5', paragraph_id=2, start=581, end=586), KiltDocAnchor(text='Asperger syndrome', href='Asperger%20syndrome', paragraph_id=2, start=645, end=662), KiltDocAnchor(text='pervasive developmental disorder not otherwise specified', href='pervasive%20developmental%20disorder%20not%20otherwise%20specified', paragraph_id=2, start=667, end=723), KiltDocAnchor(text='autism spectrum disorder', href='autism%20spectrum%20disorder', paragraph_id=2, start=776, end=800), KiltDocAnchor(text='behavioral interventions', href='Applied%20behavior%20analysis', paragraph_id=3, start=6, end=30), KiltDocAnchor(text='speech therapy', href='speech%20therapy', paragraph_id=3, start=34, end=48), KiltDocAnchor(text='self-care', href='self-care', paragraph_id=3, start=84, end=93), KiltDocAnchor(text='autistic culture', href='Societal%20and%20cultural%20aspects%20of%20autism', paragraph_id=3, start=317, end=333), KiltDocAnchor(text='accepted as a difference and not treated as a disorder', href='Autism%20rights%20movement', paragraph_id=3, start=424, end=478), KiltDocAnchor(text='neurodevelopmental disorder', href='neurodevelopmental%20disorder', paragraph_id=6, start=29, end=56), KiltDocAnchor(text='remission', href='Remission%20%28medicine%29', paragraph_id=6, start=161, end=170), KiltDocAnchor(text='autism spectrum disorder', href='autism%20spectrum%20disorder', paragraph_id=8, start=51, end=75), KiltDocAnchor(text='Temple Grandin', href='Temple%20Grandin', paragraph_id=8, start=274, end=288), KiltDocAnchor(text='social communication', href='social%20communication', paragraph_id=8, start=331, end=351), KiltDocAnchor(text='neurotypical', href='neurotypical', paragraph_id=8, start=355, end=367), KiltDocAnchor(text='neural development', href='neural%20development', paragraph_id=8, start=392, end=410), KiltDocAnchor(text='toddler', href='toddler', paragraph_id=9, start=202, end=209), KiltDocAnchor(text='social norms', href='social%20norms', paragraph_id=9, start=239, end=251), KiltDocAnchor(text='eye contact', href='eye%20contact', paragraph_id=9, start=281, end=292), KiltDocAnchor(text='turn-taking', href='turn-taking', paragraph_id=9, start=297, end=308), KiltDocAnchor(text='nonverbal', href='nonverbal%20autism', paragraph_id=9, start=583, end=592), KiltDocAnchor(text='attachments', href='Attachment%20%28psychology%29', paragraph_id=9, start=646, end=657), KiltDocAnchor(text='attachment security', href='Attachment%20in%20children%23Secure%20attachment', paragraph_id=9, start=737, end=756), KiltDocAnchor(text='perform worse on tests of face and emotion recognition', href='Face%20perception%23Face%20perception%20in%20individuals%20with%20autism', paragraph_id=9, start=919, end=973), KiltDocAnchor(text='babbling', href='babbling', paragraph_id=13, start=235, end=243), KiltDocAnchor(text='echolalia', href='echolalia', paragraph_id=13, start=676, end=685), KiltDocAnchor(text='reverse pronouns', href='Pronoun%20reversal', paragraph_id=13, start=690, end=706), KiltDocAnchor(text='Joint attention', href='Joint%20attention', paragraph_id=13, start=708, end=723), KiltDocAnchor(text='Stereotyped behaviors', href='Stereotypy', paragraph_id=17, start=12, end=33), KiltDocAnchor(text='Compulsive behavior', href='Compulsive%20behavior', paragraph_id=18, start=12, end=31), KiltDocAnchor(text='Ritualistic behavior', href='Ritual%23Psychology', paragraph_id=20, start=12, end=32), KiltDocAnchor(text='Self-injury', href='Self-injury', paragraph_id=22, start=12, end=23), KiltDocAnchor(text='skin-picking', href='Dermatillomania', paragraph_id=22, start=55, end=67), KiltDocAnchor(text='splinter skill', href='splinter%20skill', paragraph_id=26, start=86, end=100), KiltDocAnchor(text='autistic savants', href='Savant%20syndrome', paragraph_id=26, start=187, end=203), KiltDocAnchor(text='Sensory', href='Sensory%20system', paragraph_id=26, start=317, end=324), KiltDocAnchor(text='poor muscle tone', href='Hypotonia', paragraph_id=26, start=818, end=834), KiltDocAnchor(text='poor motor planning', href='Apraxia', paragraph_id=26, start=836, end=855), KiltDocAnchor(text='toe walking', href='toe%20walking', paragraph_id=26, start=861, end=872), KiltDocAnchor(text='stress', href='stress%20%28psychological%29', paragraph_id=27, start=51, end=57), KiltDocAnchor(text='Down syndrome', href='Down%20syndrome', paragraph_id=27, start=245, end=258), KiltDocAnchor(text='Down syndrome', href='Down%20syndrome', paragraph_id=27, start=398, end=411), KiltDocAnchor(text='gender dysphoria', href='gender%20dysphoria', paragraph_id=27, start=609, end=625), KiltDocAnchor(text='Gastrointestinal problems', href='Gastrointestinal%20diseases', paragraph_id=28, start=0, end=25), KiltDocAnchor(text='associated medical disorders', href='comorbidity', paragraph_id=28, start=55, end=83), KiltDocAnchor(text='genetics of autism', href='Heritability%20of%20autism', paragraph_id=31, start=48, end=66), KiltDocAnchor(text='mutation', href='mutation', paragraph_id=31, start=135, end=143), KiltDocAnchor(text='epigenetic', href='epigenetic', paragraph_id=31, start=308, end=318), KiltDocAnchor(text='DNA', href='DNA', paragraph_id=31, start=347, end=350), KiltDocAnchor(text='gene expression', href='gene%20expression', paragraph_id=31, start=394, end=409), KiltDocAnchor(text='heritability', href='heritability', paragraph_id=31, start=559, end=571), KiltDocAnchor(text='Mendelian', href='Mendelian', paragraph_id=31, start=850, end=859), KiltDocAnchor(text='chromosome abnormality', href='chromosome%20abnormality', paragraph_id=31, start=898, end=920), KiltDocAnchor(text='structural variation', href='structural%20variation', paragraph_id=31, start=1288, end=1308), KiltDocAnchor(text='deletions', href='Deletion%20%28genetics%29', paragraph_id=31, start=1319, end=1328), KiltDocAnchor(text='duplications', href='Gene%20duplication', paragraph_id=31, start=1330, end=1342), KiltDocAnchor(text='inversions', href='Chromosomal%20inversion', paragraph_id=31, start=1346, end=1356), KiltDocAnchor(text='meiosis', href='meiosis', paragraph_id=31, start=1384, end=1391), KiltDocAnchor(text='Intrauterine growth restriction', href='Intrauterine%20growth%20restriction', paragraph_id=32, start=106, end=137), KiltDocAnchor(text='autoimmune disease', href='autoimmune%20disease', paragraph_id=32, start=222, end=240), KiltDocAnchor(text='air pollution', href='air%20pollution', paragraph_id=33, start=12, end=25), KiltDocAnchor(text='heavy metals', href='heavy%20metal%20%28chemistry%29', paragraph_id=33, start=55, end=67), KiltDocAnchor(text='Environmental factor', href='Environmental%20factor', paragraph_id=33, start=119, end=139), KiltDocAnchor(text='infectious disease', href='infectious%20disease', paragraph_id=33, start=242, end=260), KiltDocAnchor(text='solvent', href='solvent', paragraph_id=33, start=263, end=270), KiltDocAnchor(text='PCBs', href='Polychlorinated%20biphenyl', paragraph_id=33, start=273, end=277), KiltDocAnchor(text='phthalates', href='phthalates', paragraph_id=33, start=279, end=289), KiltDocAnchor(text='phenols', href='phenols', paragraph_id=33, start=294, end=301), KiltDocAnchor(text='pesticide', href='pesticide', paragraph_id=33, start=328, end=337), KiltDocAnchor(text='brominated flame retardant', href='brominated%20flame%20retardant', paragraph_id=33, start=340, end=366), KiltDocAnchor(text='alcohol', href='Ethanol', paragraph_id=33, start=369, end=376), KiltDocAnchor(text='illicit drug', href='illicit%20drug', paragraph_id=33, start=387, end=399), KiltDocAnchor(text='vaccine', href='vaccine', paragraph_id=33, start=402, end=409), KiltDocAnchor(text='prenatal stress', href='prenatal%20stress', paragraph_id=33, start=416, end=431), KiltDocAnchor(text='vaccine "overload"', href='Vaccine%20controversy%23Vaccine%20overload', paragraph_id=34, start=154, end=172), KiltDocAnchor(text='vaccine preservative', href='Thiomersal%20controversy', paragraph_id=34, start=176, end=196), KiltDocAnchor(text='MMR vaccine', href='MMR%20vaccine%20controversy', paragraph_id=34, start=205, end=216), KiltDocAnchor(text='childhood immunizations', href='childhood%20immunizations', paragraph_id=34, start=539, end=562), KiltDocAnchor(text='outbreaks of previously controlled childhood diseases', href='MMR%20vaccine%20controversy%23Disease%20outbreaks', paragraph_id=34, start=564, end=617), KiltDocAnchor(text='pathophysiology', href='pathophysiology', paragraph_id=36, start=181, end=196), KiltDocAnchor(text='neuropsychological', href='neuropsychological', paragraph_id=36, start=263, end=281), KiltDocAnchor(text='gut–brain axis', href='gut%E2%80%93brain%20axis', paragraph_id=37, start=23, end=37), KiltDocAnchor(text='gastrointestinal', href='gastrointestinal%20tract', paragraph_id=37, start=119, end=135), KiltDocAnchor(text='autonomic nervous system', href='autonomic%20nervous%20system', paragraph_id=37, start=169, end=193), KiltDocAnchor(text='gut flora', href='gut%20flora', paragraph_id=37, start=195, end=204), KiltDocAnchor(text='metabolite', href='metabolite', paragraph_id=37, start=227, end=237), KiltDocAnchor(text='enteric nervous system', href='enteric%20nervous%20system', paragraph_id=37, start=319, end=341), KiltDocAnchor(text='synaptic', href='Synapse', paragraph_id=38, start=35, end=43), KiltDocAnchor(text='cell adhesion', href='cell%20adhesion', paragraph_id=38, start=183, end=196), KiltDocAnchor(text='teratogen', href='teratogen', paragraph_id=38, start=392, end=401), KiltDocAnchor(text='birth defect', href='birth%20defect', paragraph_id=38, start=422, end=434), KiltDocAnchor(text='conception', href='Human%20fertilization', paragraph_id=38, start=515, end=525), KiltDocAnchor(text='Diagnosis', href='Medical%20diagnosis', paragraph_id=40, start=0, end=9), KiltDocAnchor(text='DSM-5', href='DSM-5', paragraph_id=40, start=66, end=71), KiltDocAnchor(text='idiosyncratic language', href='Idiosyncrasy%23Psychiatry%20and%20psychology', paragraph_id=40, start=512, end=534), KiltDocAnchor(text='Rett syndrome', href='Rett%20syndrome', paragraph_id=40, start=639, end=652), KiltDocAnchor(text='intellectual disability', href='intellectual%20disability', paragraph_id=40, start=654, end=677), KiltDocAnchor(text='ICD-10', href='ICD-10', paragraph_id=40, start=709, end=715), KiltDocAnchor(text='Autism Diagnostic Interview-Revised', href='Autism%20Diagnostic%20Interview-Revised', paragraph_id=41, start=92, end=127), KiltDocAnchor(text='Autism Diagnostic Observation Schedule', href='Autism%20Diagnostic%20Observation%20Schedule', paragraph_id=41, start=182, end=220), KiltDocAnchor(text='Childhood Autism Rating Scale', href='Childhood%20Autism%20Rating%20Scale', paragraph_id=41, start=281, end=310), KiltDocAnchor(text='pediatrician', href='pediatrician', paragraph_id=42, start=2, end=14), KiltDocAnchor(text='medical conditions', href='medical%20conditions', paragraph_id=42, start=356, end=374), KiltDocAnchor(text='neuropsychologist', href='neuropsychologist', paragraph_id=42, start=388, end=405), KiltDocAnchor(text='differential diagnosis', href='differential%20diagnosis', paragraph_id=42, start=535, end=557), KiltDocAnchor(text='intellectual disability', href='intellectual%20disability', paragraph_id=42, start=600, end=623), KiltDocAnchor(text='hearing impairment', href='hearing%20impairment', paragraph_id=42, start=625, end=643), KiltDocAnchor(text='specific language impairment', href='specific%20language%20impairment', paragraph_id=42, start=651, end=679), KiltDocAnchor(text='Landau–Kleffner syndrome', href='Landau%E2%80%93Kleffner%20syndrome', paragraph_id=42, start=688, end=712), KiltDocAnchor(text='depression', href='Major%20depressive%20disorder', paragraph_id=42, start=809, end=819), KiltDocAnchor(text='Clinical genetics', href='Clinical%20genetics', paragraph_id=43, start=0, end=17), KiltDocAnchor(text='fragile X', href='fragile%20X', paragraph_id=43, start=327, end=336), KiltDocAnchor(text='genotype-first', href='Genotype-first%20approach', paragraph_id=43, start=348, end=362), KiltDocAnchor(text='Metabolic', href='Metabolic', paragraph_id=43, start=696, end=705), KiltDocAnchor(text='neuroimaging', href='neuroimaging', paragraph_id=43, start=710, end=722), KiltDocAnchor(text='visually impaired', href='visually%20impaired', paragraph_id=45, start=554, end=571), KiltDocAnchor(text='blindism', href='blindism', paragraph_id=45, start=727, end=735), KiltDocAnchor(text='pervasive developmental disorder', href='pervasive%20developmental%20disorder', paragraph_id=47, start=26, end=58), KiltDocAnchor(text='Asperger syndrome', href='Asperger%20syndrome', paragraph_id=48, start=23, end=40), KiltDocAnchor(text='Rett syndrome', href='Rett%20syndrome', paragraph_id=48, start=90, end=103), KiltDocAnchor(text='childhood disintegrative disorder', href='childhood%20disintegrative%20disorder', paragraph_id=48, start=108, end=141), KiltDocAnchor(text='PDD not otherwise specified', href='PDD%20not%20otherwise%20specified', paragraph_id=48, start=206, end=233), KiltDocAnchor(text='language development', href='language%20development', paragraph_id=48, start=427, end=447), KiltDocAnchor(text='phenotype', href='phenotype', paragraph_id=48, start=934, end=943), KiltDocAnchor(text='traits', href='Trait%20%28biology%29', paragraph_id=48, start=1020, end=1026), KiltDocAnchor(text='spectrum', href='Spectrum%20disorder', paragraph_id=49, start=42, end=50), KiltDocAnchor(text='developmentally disabled', href='developmentally%20disabled', paragraph_id=49, start=120, end=144), KiltDocAnchor(text='pedantic', href='pedantic', paragraph_id=49, start=319, end=327), KiltDocAnchor(text='high-functioning autism', href='high-functioning%20autism', paragraph_id=49, start=521, end=544), KiltDocAnchor(text='IQ', href='IQ', paragraph_id=49, start=575, end=577), KiltDocAnchor(text='syndromal', href='Syndrome', paragraph_id=49, start=747, end=756), KiltDocAnchor(text='intellectual disability', href='intellectual%20disability', paragraph_id=49, start=842, end=865), KiltDocAnchor(text='tuberous sclerosis', href='tuberous%20sclerosis', paragraph_id=49, start=923, end=941), KiltDocAnchor(text='overlap between Asperger syndrome, HFA, and non-syndromal autism', href='Diagnosis%20of%20Asperger%20syndrome%23Differences%20from%20high-functioning%20autism', paragraph_id=49, start=1064, end=1128), KiltDocAnchor(text='regressive autism', href='regressive%20autism', paragraph_id=50, start=260, end=277), KiltDocAnchor(text='psychiatry', href='psychiatry', paragraph_id=51, start=194, end=204), KiltDocAnchor(text='psychology', href='psychology', paragraph_id=51, start=206, end=216), KiltDocAnchor(text='neurology', href='neurology', paragraph_id=51, start=218, end=227), KiltDocAnchor(text='pediatrics', href='pediatrics', paragraph_id=51, start=232, end=242), KiltDocAnchor(text='fMRI', href='fMRI', paragraph_id=51, start=271, end=275), KiltDocAnchor(text='diffusion tensor imaging', href='diffusion%20tensor%20imaging', paragraph_id=51, start=280, end=304), KiltDocAnchor(text='phenotype', href='phenotype', paragraph_id=51, start=345, end=354), KiltDocAnchor(text='brain scan', href='brain%20scan', paragraph_id=51, start=398, end=408), KiltDocAnchor(text='neurogenetic', href='neurogenetic', paragraph_id=51, start=427, end=439), KiltDocAnchor(text='fusiform face area', href='fusiform%20face%20area', paragraph_id=51, start=498, end=516), KiltDocAnchor(text='babbling', href='babbling', paragraph_id=54, start=15, end=23), KiltDocAnchor(text='gesturing', href='Gesture', paragraph_id=55, start=15, end=24), KiltDocAnchor(text='echolalic', href='echolalia', paragraph_id=57, start=47, end=56), KiltDocAnchor(text='United States Preventive Services Task Force', href='United%20States%20Preventive%20Services%20Task%20Force', paragraph_id=59, start=4, end=48), KiltDocAnchor(text='screen', href='Screening%20%28medicine%29', paragraph_id=59, start=190, end=196), KiltDocAnchor(text='Modified Checklist for Autism in Toddlers', href='Modified%20Checklist%20for%20Autism%20in%20Toddlers', paragraph_id=59, start=471, end=512), KiltDocAnchor(text='M-CHAT', href='Modified%20Checklist%20for%20Autism%20in%20Toddlers', paragraph_id=59, start=623, end=629), KiltDocAnchor(text='Checklist for Autism in Toddlers', href='Checklist%20for%20Autism%20in%20Toddlers', paragraph_id=59, start=655, end=687), KiltDocAnchor(text='sensitivity', href='Sensitivity%20%28tests%29', paragraph_id=59, start=798, end=809), KiltDocAnchor(text='specificity', href='Specificity%20%28tests%29', paragraph_id=59, start=842, end=853), KiltDocAnchor(text='genetic screening', href='genetic%20screening', paragraph_id=59, start=1151, end=1168), KiltDocAnchor(text='dysmorphic feature', href='dysmorphic%20feature', paragraph_id=59, start=1296, end=1314), KiltDocAnchor(text='rubella', href='rubella', paragraph_id=61, start=21, end=28), KiltDocAnchor(text='pregnancy', href='pregnancy', paragraph_id=61, start=36, end=45), KiltDocAnchor(text='vaccination against rubella', href='rubella%20vaccine', paragraph_id=61, start=87, end=114), KiltDocAnchor(text='behavior analysts', href='Professional%20practice%20of%20behavior%20analysis', paragraph_id=63, start=472, end=489), KiltDocAnchor(text='special education', href='special%20education', paragraph_id=63, start=491, end=508), KiltDocAnchor(text='teachers', href='teachers', paragraph_id=63, start=509, end=517), KiltDocAnchor(text='speech pathologists', href='speech-language%20pathology', paragraph_id=63, start=519, end=538), KiltDocAnchor(text='psychologists', href='psychologists', paragraph_id=63, start=553, end=566), KiltDocAnchor(text='efficacy', href='efficacy', paragraph_id=63, start=664, end=672), KiltDocAnchor(text='psychosocial', href='psychosocial', paragraph_id=63, start=775, end=787), KiltDocAnchor(text='systematic review', href='systematic%20review', paragraph_id=63, start=931, end=948), KiltDocAnchor(text='special education', href='special%20education', paragraph_id=63, start=1140, end=1157), KiltDocAnchor(text='applied behavior analysis', href='applied%20behavior%20analysis', paragraph_id=65, start=45, end=70), KiltDocAnchor(text='speech and language therapy', href='speech%20and%20language%20therapy', paragraph_id=65, start=121, end=148), KiltDocAnchor(text='social skills', href='social%20skills', paragraph_id=65, start=150, end=163), KiltDocAnchor(text='occupational therapy', href='occupational%20therapy', paragraph_id=65, start=177, end=197), KiltDocAnchor(text='structured type of ABA', href='Discrete%20trial%20training', paragraph_id=65, start=524, end=546), KiltDocAnchor(text='structured', href='Discrete%20trial%20training', paragraph_id=65, start=714, end=724), KiltDocAnchor(text='naturalistic', href='Pivotal%20response%20treatment', paragraph_id=65, start=729, end=741), KiltDocAnchor(text='Early, intensive ABA therapy', href='Discrete%20trial%20training', paragraph_id=66, start=0, end=28), KiltDocAnchor(text='naturalistic form of ABA', href='Pivotal%20response%20treatment', paragraph_id=66, start=306, end=330), KiltDocAnchor(text='ADHD', href='ADHD', paragraph_id=68, start=201, end=205), KiltDocAnchor(text='anxiety', href='anxiety%20disorder', paragraph_id=68, start=209, end=216), KiltDocAnchor(text='psychoactive drug', href='psychoactive%20drug', paragraph_id=68, start=282, end=299), KiltDocAnchor(text='anticonvulsant', href='anticonvulsant', paragraph_id=68, start=304, end=318), KiltDocAnchor(text='antidepressant', href='antidepressant', paragraph_id=68, start=361, end=375), KiltDocAnchor(text='stimulant', href='stimulant', paragraph_id=68, start=378, end=387), KiltDocAnchor(text='antipsychotic', href='antipsychotic', paragraph_id=68, start=394, end=407), KiltDocAnchor(text='atypical antipsychotic', href='atypical%20antipsychotic', paragraph_id=68, start=414, end=436), KiltDocAnchor(text='risperidone', href='risperidone', paragraph_id=68, start=443, end=454), KiltDocAnchor(text='aripiprazole', href='aripiprazole', paragraph_id=68, start=459, end=471), KiltDocAnchor(text='FDA', href='Food%20and%20drug%20administration', paragraph_id=68, start=476, end=479), KiltDocAnchor(text='SSRI antidepressants', href='SSRI%20antidepressants', paragraph_id=68, start=768, end=788), KiltDocAnchor(text='fluoxetine', href='fluoxetine', paragraph_id=68, start=798, end=808), KiltDocAnchor(text='fluvoxamine', href='fluvoxamine', paragraph_id=68, start=813, end=824), KiltDocAnchor(text='methylphenidate', href='methylphenidate', paragraph_id=68, start=939, end=954), KiltDocAnchor(text='alternative therapies and interventions', href='Alternative%20therapies%20for%20developmental%20and%20learning%20disabilities', paragraph_id=70, start=14, end=53), KiltDocAnchor(text='quality-of-life', href='Quality%20of%20life', paragraph_id=70, start=164, end=179), KiltDocAnchor(text='casein-free diet', href='casein-free%20diet', paragraph_id=70, start=503, end=519), KiltDocAnchor(text='calcium', href='calcium', paragraph_id=70, start=560, end=567), KiltDocAnchor(text='vitamin D', href='vitamin%20D', paragraph_id=70, start=572, end=581), KiltDocAnchor(text='gastrointestinal disorders', href='gastrointestinal%20disease', paragraph_id=70, start=678, end=704), KiltDocAnchor(text='chelation therapy', href='chelation%20therapy', paragraph_id=70, start=723, end=740), KiltDocAnchor(text='CEASE therapy', href='CEASE%20therapy', paragraph_id=70, start=950, end=963), KiltDocAnchor(text='homeopathy', href='homeopathy', paragraph_id=70, start=978, end=988), KiltDocAnchor(text='alternative treatment', href='complementary%20and%20alternative%20medicine', paragraph_id=71, start=30, end=51), KiltDocAnchor(text='gluten- and casein-free diet', href='gluten-free%2C%20casein-free%20diet', paragraph_id=71, start=128, end=156), KiltDocAnchor(text='food intolerance', href='food%20intolerance', paragraph_id=71, start=312, end=328), KiltDocAnchor(text='allergies', href='food%20allergy', paragraph_id=71, start=333, end=342), KiltDocAnchor(text='gluten sensitivity', href='non-celiac%20gluten%20sensitivity', paragraph_id=72, start=33, end=51), KiltDocAnchor(text='gluten-free diet', href='gluten-free%20diet', paragraph_id=72, start=99, end=115), KiltDocAnchor(text='music therapy', href='music%20therapy', paragraph_id=73, start=33, end=46), KiltDocAnchor(text='hyperbaric treatment', href='Hyperbaric%20medicine', paragraph_id=73, start=180, end=200), KiltDocAnchor(text='social support', href='social%20support', paragraph_id=75, start=436, end=450), KiltDocAnchor(text='self-determination', href='Self-determination%20theory', paragraph_id=75, start=513, end=531), KiltDocAnchor(text='prognosis', href='prognosis', paragraph_id=76, start=43, end=52), KiltDocAnchor(text='IQ', href='IQ', paragraph_id=76, start=225, end=227), KiltDocAnchor(text='independent living', href='independent%20living', paragraph_id=76, start=297, end=315), KiltDocAnchor(text='review', href='review', paragraph_id=79, start=12, end=18), KiltDocAnchor(text='NHS', href='National%20Health%20Service', paragraph_id=79, start=385, end=388), KiltDocAnchor(text='PDD-NOS', href='PDD-NOS', paragraph_id=79, start=502, end=509), KiltDocAnchor(text='childhood disintegrative disorder', href='childhood%20disintegrative%20disorder', paragraph_id=79, start=597, end=630), KiltDocAnchor(text='Genetic disorder', href='Genetic%20disorder', paragraph_id=84, start=12, end=28), KiltDocAnchor(text='Mendelian', href='Mendelian', paragraph_id=84, start=81, end=90), KiltDocAnchor(text='chromosome abnormality', href='chromosome%20abnormality', paragraph_id=84, start=116, end=138), KiltDocAnchor(text='Intellectual disability', href='Intellectual%20disability', paragraph_id=85, start=12, end=35), KiltDocAnchor(text='assessing', href='Intelligence%20assessment', paragraph_id=85, start=222, end=231), KiltDocAnchor(text='intelligence', href='Controversies%20in%20autism%23Intelligence', paragraph_id=85, start=232, end=244), KiltDocAnchor(text='Anxiety disorder', href='Anxiety%20disorder', paragraph_id=86, start=12, end=28), KiltDocAnchor(text='Epilepsy', href='Epilepsy', paragraph_id=87, start=12, end=20), KiltDocAnchor(text='language disorder', href='language%20disorder', paragraph_id=87, start=99, end=116), KiltDocAnchor(text='metabolic defect', href='metabolic%20defect', paragraph_id=88, start=20, end=36), KiltDocAnchor(text='phenylketonuria', href='phenylketonuria', paragraph_id=88, start=47, end=62), KiltDocAnchor(text='Minor physical anomalies', href='Minor%20physical%20anomalies', paragraph_id=89, start=12, end=36), KiltDocAnchor(text='Attention deficit hyperactivity disorder (ADHD)', href='Attention%20deficit%20hyperactivity%20disorder', paragraph_id=90, start=150, end=197), KiltDocAnchor(text='Tourette syndrome', href='Tourette%20syndrome', paragraph_id=90, start=199, end=216), KiltDocAnchor(text='comorbid diagnoses', href='Conditions%20comorbid%20to%20autism%20spectrum%20disorders', paragraph_id=90, start=276, end=294), KiltDocAnchor(text='insomnia', href='insomnia', paragraph_id=91, start=143, end=151), KiltDocAnchor(text='nocturnal awakenings', href='middle-of-the-night%20insomnia', paragraph_id=91, start=199, end=219), KiltDocAnchor(text='Table Talk', href='Table%20Talk%20%28Luther%29', paragraph_id=93, start=101, end=111), KiltDocAnchor(text='Martin Luther', href='Martin%20Luther', paragraph_id=93, start=116, end=129), KiltDocAnchor(text='Wild Boy of Aveyron', href='Wild%20Boy%20of%20Aveyron', paragraph_id=93, start=655, end=674), KiltDocAnchor(text='feral child', href='feral%20child', paragraph_id=93, start=678, end=689), KiltDocAnchor(text='Jean Itard', href='Jean%20Marc%20Gaspard%20Itard', paragraph_id=93, start=758, end=768), KiltDocAnchor(text='New Latin', href='New%20Latin', paragraph_id=94, start=4, end=13), KiltDocAnchor(text='Swiss', href='Swiss%20people', paragraph_id=94, start=79, end=84), KiltDocAnchor(text='Eugen Bleuler', href='Eugen%20Bleuler', paragraph_id=94, start=98, end=111), KiltDocAnchor(text='schizophrenia', href='schizophrenia', paragraph_id=94, start=151, end=164), KiltDocAnchor(text='Grunya Sukhareva', href='Grunya%20Sukhareva', paragraph_id=94, start=451, end=467), KiltDocAnchor(text='Hans Asperger', href='Hans%20Asperger', paragraph_id=96, start=59, end=72), KiltDocAnchor(text='Vienna University Hospital', href='Vienna%20General%20Hospital', paragraph_id=96, start=80, end=106), KiltDocAnchor(text='child psychology', href='child%20psychology', paragraph_id=96, start=189, end=205), KiltDocAnchor(text='Asperger syndrome', href='Asperger%20syndrome', paragraph_id=96, start=254, end=271), KiltDocAnchor(text='Leo Kanner', href='Leo%20Kanner', paragraph_id=96, start=365, end=375), KiltDocAnchor(text='Johns Hopkins Hospital', href='Johns%20Hopkins%20Hospital', paragraph_id=96, start=383, end=405), KiltDocAnchor(text='Donald Triplett', href='Donald%20Triplett', paragraph_id=97, start=0, end=15), KiltDocAnchor(text='refrigerator mother', href='refrigerator%20mother', paragraph_id=98, start=211, end=230), KiltDocAnchor(text='social stigma', href='social%20stigma', paragraph_id=100, start=308, end=321), KiltDocAnchor(text='primary care physician', href='primary%20care%20physician', paragraph_id=100, start=408, end=430), KiltDocAnchor(text='medical specialist', href='medical%20specialist', paragraph_id=100, start=436, end=454), KiltDocAnchor(text='DSM-III', href='DSM-III', paragraph_id=101, start=27, end=34), KiltDocAnchor(text='DSM-III-R', href='DSM-III-R', paragraph_id=101, start=102, end=111), KiltDocAnchor(text='DSM-5', href='DSM-5', paragraph_id=101, start=173, end=178), KiltDocAnchor(text='PDD-NOS', href='PDD-NOS', paragraph_id=101, start=297, end=304), KiltDocAnchor(text='Asperger syndrome', href='Asperger%20syndrome', paragraph_id=101, start=314, end=331), KiltDocAnchor(text='Rett syndrome', href='Rett%20syndrome', paragraph_id=101, start=333, end=346), KiltDocAnchor(text='CDD', href='Childhood%20disintegrative%20disorder', paragraph_id=101, start=352, end=355), KiltDocAnchor(text='Societal and cultural aspects of autism', href='Societal%20and%20cultural%20aspects%20of%20autism', paragraph_id=102, start=199, end=238), KiltDocAnchor(text='autism is simply another way of being', href='Neurodiversity', paragraph_id=102, start=316, end=353), KiltDocAnchor(text='autistic rights', href='autistic%20rights', paragraph_id=104, start=52, end=67), KiltDocAnchor(text='neurodiversity', href='neurodiversity', paragraph_id=104, start=72, end=86), KiltDocAnchor(text='World Autism Awareness Day', href='World%20Autism%20Awareness%20Day', paragraph_id=104, start=113, end=139), KiltDocAnchor(text='Autism Sunday', href='Autism%20Sunday', paragraph_id=104, start=141, end=154), KiltDocAnchor(text='Autistic Pride Day', href='Autistic%20Pride%20Day', paragraph_id=104, start=156, end=174), KiltDocAnchor(text='Autreat', href='Autreat', paragraph_id=104, start=176, end=183), KiltDocAnchor(text='Autism Speaks', href='Autism%20Speaks', paragraph_id=104, start=262, end=275), KiltDocAnchor(text='Autism National Committee', href='Autism%20National%20Committee', paragraph_id=104, start=277, end=302), KiltDocAnchor(text='Autism Society of America', href='Autism%20Society%20of%20America', paragraph_id=104, start=308, end=333), KiltDocAnchor(text='autism rights movement', href='autism%20rights%20movement', paragraph_id=106, start=4, end=26), KiltDocAnchor(text='social movement', href='social%20movement', paragraph_id=106, start=32, end=47), KiltDocAnchor(text='disability right', href='disability%20rights%20movement', paragraph_id=106, start=70, end=86), KiltDocAnchor(text='neurodiversity', href='neurodiversity', paragraph_id=106, start=119, end=133), KiltDocAnchor(text='human brain', href='human%20brain', paragraph_id=106, start=204, end=215), KiltDocAnchor(text='minority group', href='minority%20group', paragraph_id=106, start=492, end=506), KiltDocAnchor(text='human genome', href='human%20genome', paragraph_id=106, start=648, end=660), KiltDocAnchor(text='fringe theories', href='fringe%20theories', paragraph_id=106, start=859, end=874), KiltDocAnchor(text='vaccines', href='Vaccine', paragraph_id=106, start=930, end=938), KiltDocAnchor(text='high-functioning', href='High-functioning%20autism', paragraph_id=106, start=1020, end=1036), KiltDocAnchor(text='Asperger syndrome', href='Asperger%20syndrome', paragraph_id=106, start=1046, end=1063), KiltDocAnchor(text='low-functioning', href='Low-functioning%20autism', paragraph_id=106, start=1099, end=1114)), ('Neurological disorders in children', 'Autism', 'Articles containing video clips', 'Neurological disorders', 'Communication disorders', 'Pervasive developmental disorders', 'Psychiatric diagnosis', 'Mental and behavioural disorders'), 'Q38404', '908372970', '2019-07-29T09:08:56Z', '908206160', '25', 'https://en.wikipedia.org/w/index.php?title=Autism&oldid=908372970'),
            5903529: KiltDoc('5141410', 'Origin of the domestic dog', re.compile("^Origin of the domestic dog\nThe origin of the domestic dog includes the dog's evolutionary divergence.{71155} the Holarctic temperate zone hunting dogs were a widespread adaptation to forest ungulate hunting\\.\n$", flags=48), ('Origin of the domestic dog\n', 'The origin of the domestic dog includes the dog\'s evolutionary divergence from the wolf, its domestication, and its development into dog types and dog breeds. The dog is a member of the genus "Canis", which forms part of the wolf-like canids, and was the first species and the only large carnivore to have been domesticated. The dog and the extant gray wolf are sister taxa, as modern wolves are not closely related to the population of wolves that was first domesticated.\n', 'The genetic divergence between dogs and wolves occurred between 40,000–20,000 years ago, just before or during the Last Glacial Maximum. This timespan represents the upper time-limit for the commencement of domestication because it is the time of divergence and not the time of domestication, which occurred later. The domestication of animals commenced over 15,000 years ago, beginning with the grey wolf ("Canis lupus") by nomadic hunter-gatherers. The archaeological record and genetic analysis show the remains of the Bonn–Oberkassel dog buried beside humans 14,200 years ago to be the first undisputed dog, with disputed remains occurring 36,000 years ago. It was not until 11,000 years ago that people living in the Near East entered into relationships with wild populations of aurochs, boar, sheep, and goats.\n', 'Where the domestication of the dog took place remains debated, with the most plausible proposals spanning Western Europe, Central Asia and East Asia. This has been made more complicated by the recent proposal that an initial wolf population split into East and West Eurasian groups. These two groups, before going extinct, were domesticated independently into two distinct dog populations between 14,000 and 6,400 years ago. The Western Eurasian dog population was gradually and partially replaced by East Asian dogs introduced by humans at least 6,400 years ago. This proposal is also debated.\n', 'Section::::Canid and human evolution.\n', "Six million years ago, towards the close of the Miocene era, the earth's climate gradually cooled. This would lead to the glaciations of the Pliocene and the Pleistocene, which are commonly referred to as the Ice Age. In many areas, forests and savannahs were replaced with steppes or grasslands, and only those species of creature that adapted to these changes would survive.\n", 'In southern North America, small woodland foxes grew bigger and better adapted to running, and by the late Miocene the first of the genus "Canis" had arisen - the ancestors of coyotes, wolves and the domestic dog. In eastern Africa, a split occurred among the large primates. Some remained in the trees, while others came down from the trees, learned to walk upright, developed larger brains, and in the more open country learned to avoid predators while becoming predators themselves. The ancestors of humans and dogs would ultimately meet in Eurasia.\n', "Human hunter-gatherers did not live in fear of nature and knew that they posed a formidable risk to any potential predators. Today, the Ju'wasi people of Namibia share their land with prides of lions. Both species coexist with respect and without fear or hostility in a relationship that may go back to the dawn of modern humans. The lion is a much larger and far more dangerous predator than the wolf. Early modern humans entering Eurasia and first encountering packs of wolves may have been assisted in living among them because of the traditional beliefs of their African ancestors. In historical times, mutual respect and cooperation with canids can be found in the stories and traditions of the indigenous peoples of Siberia, East Asia, North America, and Australia.\n", 'Section::::Divergence from wolves.\n', 'The domestication of animals commenced over 15,000 years before present (YBP), beginning with the grey wolf ("Canis lupus") by nomadic hunter-gatherers. It was not until 11,000 YBP that people living in the Near East entered into relationships with wild populations of aurochs, boar, sheep, and goats. A domestication process then began to develop. The grey wolf most likely followed the commensal pathway to domestication. When, where, and how many times wolves may have been domesticated remains debated because only a small number of ancient specimens have been found, and both archaeology and genetics continue to provide conflicting evidence. The most widely accepted, earliest dog remains date back 15,000 YBP to the Bonn–Oberkassel dog. Earlier remains dating back to 30,000 YBP have been described as Paleolithic dogs, however their status as dogs or wolves remains debated. Recent studies indicate that a genetic divergence occurred between dogs and wolves 20,000-40,000 YBP, however this is the upper time-limit for domestication because it represents the time of divergence and not the time of domestication.\n', 'Section::::Divergence from wolves.:Time of genetic divergence.\n', "The date estimated for the evolutionary divergence of a domestic lineage from a wild one does not necessarily indicate the start of the domestication process but it does provide an upper boundary. The divergence of the lineage that led to the domestic horse from the lineage that led to the modern Przewalski's horse is estimated to have occurred around 45,000 YBP but the archaeological record indicates 5,500 YBP. The variance can be due to modern wild populations not being the direct ancestor of the domestic ones, or to a divergence caused by changes in the climate, topography, or other environmental influences. The evolutionary divergence time for the wolf and dog is indicated to have occurred somewhere between 20,000-60,000 YBP but this does not imply that domestication occurred during this period.\n", 'Section::::Divergence from wolves.:Time of genetic divergence.:Paleobiogeography.\n', 'During the Late Pleistocene glaciation, a vast mammoth steppe stretched from Spain eastwards across Eurasia and over the Bering land bridge into Alaska and the Yukon. The Late Pleistocene was characterized by a series of severe and rapid climate oscillations with regional temperature changes of up to , which has been correlated with megafaunal extinctions. There is no evidence of megafaunal extinctions at the height of the Last Glacial Maximum, indicating that increasing cold and glaciation were not factors. Multiple events appear to have caused the rapid replacement of one species by another one within the same genus, or one population by another within the same species, across a broad area. As some species became extinct, so too did the predators that depended on them.\n', 'The origin of dogs is couched in the paleobiogeography of wolf populations during the Late Pleistocene. The earliest fossils of "Canis lupus" were found in what was once eastern Beringia at Old Crow, Yukon, Canada and at Cripple Creek Sump, Fairbanks, Alaska. The age is not agreed but could date 1 million YBP. Considerable morphological diversity existed among grey wolves by the Late Pleistocene. These are regarded as having been more cranio-dentally robust than modern grey wolves, often with a shortened rostrum, the pronounced development of the temporalis muscle, and robust premolars. It is proposed that these features were specialized adaptations for the processing of carcass and bone associated with the hunting and scavenging of Pleistocene megafauna. Compared with modern wolves, some Pleistocene wolves showed an increase in tooth breakage that is similar to that seen in the extinct dire wolf. This suggests that these either often processed carcasses, or that they competed with other carnivores and needed to quickly consume their prey. The frequency and location of tooth fractures found in these wolves compared with the modern spotted hyena indicates that these wolves were habitual bone crackers.\n', 'Section::::Divergence from wolves.:Time of genetic divergence.:Timespan.\n', "Genetic studies indicate that the gray wolf is the closest living relative of the dog, with no evidence of any other canine species having contributed. Attempting to reconstruct the dog's lineage through the phylogenetic analysis of DNA sequences from modern dogs and wolves has given conflicting results for several reasons. Firstly, studies indicate that an extinct Late Pleistocene wolf is the nearest common ancestor to the dog, with modern wolves not being the dog's direct ancestor. Secondly, the genetic divergence between the dog and modern wolves occurred over a short period of time, so that the time of the divergence is difficult to date (referred to as incomplete lineage sorting). This is complicated further by the cross-breeding that has occurred between dogs and wolves since domestication (referred to as post-domestication gene flow). Finally, there have been only tens of thousands of generations of dogs since domestication, so that the number of mutations between the dog and the wolf are few and this makes the timing of domestication difficult to date.\n", "In 2013, the whole genome sequencing of modern dogs and wolves indicated a divergence time of 32,000 YBP. In 2014, another study indicated 16,000-11,000 YBP. The first draft genome sequence of a Pleistocene canid was published in 2015. This Taymyr Peninsula wolf belonged to a population that had diverged from the ancestors of both modern wolves and dogs. Radiocarbon dating indicates its age to be 35,000 YBP, and this age could then be used to re-calibrate the wolf's mutation rate, indicating that the genetic divergence between dogs and wolves occurred before the Last Glacial Maximum, between 40,000–27,000 YBP. When this mutation rate was applied to the timing of the 2014 study, that study gave the same result of 40,000–27,000 YBP.\n", 'Section::::Divergence from wolves.:Place of genetic divergence.\n', 'Most genetic studies conducted over the last two decades were based on modern dog breeds and extant wolf populations, with their findings dependent on a number of assumptions. These studies assumed that the extant wolf was the ancestor of the dog, did not consider genetic admixture between wolves and dogs, nor the impact of incomplete lineage sorting. These pre-genomic studies have suggested an origin of dogs in Southeast Asia, East Asia, Central Asia, the Middle East, or Europe. More recently, the field of Paleogenomics applies the latest molecular technologies to fossil remains that still contain useful DNA. \n', 'Section::::Divergence from wolves.:Place of genetic divergence.:Europe.\n', 'In 2013, a study sequenced the complete mitochondrial genomes of 18 fossil canids and these were then compared with the mitochondrial genomes from modern wolves and dogs in a phylogenetic tree. The study found that there exists more genetic variation between the 18 fossil canids than exists between all modern wolves and dogs. The analyses included the oldest fossils proposed as early dogs dating back as far as 36,000 YBP. However, these Goyet Cave canids were found to have formed an ancient and extinct sister group to modern dogs and wolves. The authors propose that these dog-like fossils were either an early domestication attempt that left no descendants among modern dogs, or that they were a specialized wolf ecomorph whose morphological features were part of the Late Pleistocene wolf diversity.\n', 'An earlier study of the Razboinichya Cave canid that was based on a segment of its mitochondrial DNA (mDNA) had concluded that it was an early dog. This fossil was included for the analysis of its complete mitochondrial genome and on the phylogenetic tree was assigned a much more basal position. The study inferred from the tree that dogs and wolves split 32,000-19,000 YBP and therefore the beginning of domestication occurred in the time of hunter-gatherers rather than in the time of farmers. The tree also confirmed that the ancient dogs of the Americas originated in Eurasia.\n', 'The phylogenetic analyses revealed that three of the four major mDNA clades of dogs relate most closely to the ancient canids from Europe rather than those from China or the Middle East, which supports a European origin of modern dogs. No modern wolf population related closer to dogs than the ancient canids from Europe, indicating that the wolf population that was the ancestor of the dog is extinct.\n', 'Section::::Divergence from wolves.:Place of genetic divergence.:Arctic northeastern Siberia.\n', 'In 2015, a study recovered mDNA from ancient canid specimens that were discovered in arctic northeastern Siberia (which was once western Beringia). These specimens included the mandible of a 360,000-400,000 YBP "Canis c.f. variabilis" (where c.f. is a Latin term meaning uncertain). Phylogenetic analyses of these canids revealed nine mDNA haplotypes not detected before. The "Canis c.f. variabilis" specimen clustered with other wolf samples from across Russia and Asia. The mDNA haplotypes of one 8,750 YBP specimen and some 28,000 YBP specimens matched with those of geographically widely-spread modern dogs. One 47,000 YBP canid was distinct from wolves but was only a few mutations away from those haplotypes found in modern dogs. The authors concluded that the structure of the modern dog gene pool was contributed to from ancient Siberian wolves and possibly from "Canis c.f. variabilis".\n', 'Section::::Divergence from wolves.:Place of genetic divergence.:Two origins.\n', 'Dogs show both ancient and modern lineages. The ancient lineages appear most in Asia but least in Europe because the Victorian era development of modern dog breeds used little of the ancient lineages. All dog populations (breed, village, and feral) show some evidence of genetic admixture between modern and ancient dogs. Some ancient dog populations that once occupied Europe and the New World no longer exist. This implies that some ancient dog populations were entirely replaced and others admixed over a long period of time. European dog populations have undergone extensive turnover during the last 15,000 years which has erased the genomic signature of early European dogs, the genetic heritage of the modern breeds has become blurred due to admixture, and there was the possibility of past domestication events that had gone extinct or had been largely replaced by more modern dog populations.\n', 'Siberian huskies and other northern breeds can trace at least some of their ancestry (1.4–27.3%) back to the Taimyr wolf, which indicates the possibility of more than one domestication event.\n', 'In 2016, a study compared the mitochondrial DNA and whole-genome sequences of a worldwide panel of modern dogs, the mDNA sequences of 59 ancient European dog specimens dated 14,000-3,000 YBP, and the nuclear genome sequence of a dog specimen that was found in the Late Neolithic passage grave at Newgrange, Ireland and radiocarbon dated at 4,800 YBP. A genetic analysis of the Newgrange dog showed that it was male, did not possess genetic variants associated with modern coat length nor color, was not as able to process starch as efficiently as modern dogs but more efficiently than wolves, and showed ancestry from a population of wolves that could not be found in other dogs nor wolves today. As the taxonomic classification of the "proto-dog" Paleolithic dogs as being either dogs or wolves remains controversial, they were excluded from the study. The phylogenetic tree generated from mDNA sequences found a deep division between the Sarloos wolfdog and all other dogs, indicating that breed\'s recent deriving from the German Shepherd and captive gray wolves. The next largest division was between eastern Asian dogs and western Eurasian (Europe and the Middle East) dogs that had occurred between 14,000-6,400 YBP, with the Newgrange dog clustering with the western Eurasian dogs.\n', 'The Newgrange and ancient European dog mDNA sequences could be largely assigned to mDNA haplogroups C and D but modern European dog sequences could be largely assigned to mDNA haplogroups A and B, indicating a turnover of dogs in the past from a place other than Europe. As this split dates older than the Newgrange dog this suggests that the replacement was only partial. The analysis showed that most modern European dogs had undergone a population bottleneck (reduction) which can be an indicator of travel. The archaeological record shows dog remains dating over 15,000 YBP in western Eurasia, over 12,500 YBP in eastern Eurasia, but none older than 8,000 YBP in Central Asia. The study proposes that dogs may have been domesticated separately in both eastern and western Eurasia from two genetically distinct and now extinct wolf populations. East Eurasian dogs then made their way with migrating people to western Europe between 14,000-6,400 YBP where they partially replaced the dogs of Europe. Two domestication events in western Eurasia and eastern Eurasia has recently been found for the domestic pig.\n', "The hypothesis is that two genetically different, and possibly now extinct, wolf populations were domesticated independently in eastern and western Eurasia to produce paleolithic dogs. The eastern Eurasian dogs then dispersed westward alongside humans, reaching western Europe 6,400–14,000 years ago where they partially replaced the western paleolithic dogs. A single domestication is thought to be due to chance, however dual domestication on different sides of the world is unlikely to have happened randomly and it suggests that external factors - an environmental driver - may have forced wolves to work together with humans for survival. It is possible that wolves took advantage of resources that humans had, or humans may have been introduced to wolves in an area in which they didn't previously live.\n", 'The study indicates that the western Eurasian wolf and dog populations genetically diverged 20,000-60,000 YBP. Immediately after this divergence, the dog population outnumbered the wolf population, and later the dog population underwent a population reduction to be much lower.\n', 'Section::::Divergence from wolves.:Place of genetic divergence.:Two origins disputed.\n', 'In 2017, a study compared the nuclear genome sequences of three ancient dog specimens from Germany and Ireland with sequences from over 5,000 dogs and wolves. These Neolithic dog specimens included a dog sample from the Early Neolithic site in Herxheim, Germany dated 7,000 YBP, one from the Late Neolithic site of Kirschbaum (Cherry Tree) Cave near Forchheim, Germany dated 4,700 YBP, and a dog from Newgrange, Ireland dated 4,800 YBP. The study found that modern European dogs descended from their Neolithic ancestors with no evidence of a population turnover. There was evidence of a single dog-wolf divergence occurring between 36,900-41,500 YBP, followed by a divergence between Southeast Asian and Western Eurasian dogs 17,500-23,900 YBP and this indicates a single dog domestication event occurring between 20,000-40,000 YBP. The 3 dogs indicated ancestry that could be found in South East Asian dogs. Additionally, the Cherry Tree Cave dog showed ancestry that could be found in the Middle East, India and Central Asia. The study did not support a dual domestication event, and detected admixture between the ancestors of modern European and Southeast Asian dogs.\n', 'A 2018 study of mDNA sequences shows that the pre-Neolithic dogs of Europe all fell under haplogroup C. The Neolithic and Post-Neolithic dogs from Southeastern Europe that are associated with farmers fell under haplogroup D. In Western and Northern Europe, haplogroup D became diluted into the native dog population. This implies that haplogroup D arrived in Europe 9,000 years ago from the Near East along with pigs, cows, sheep, and goats. Later in 2018, another study looked at the y-chromosome male lineage of the ancient fossils of the Herxheim, Kirschbaum, and Newgrange dogs along with other canines. The study identified six major dog yDNA haplogroups, of which two of these include the majority of modern dogs. The Newgrange dog fell into the most commonly occurring of these haplogroups. The two ancient German dogs fell into a haplogroup commonly found among dogs from the Middle East and Asia, with the Kirschbaum dog sharing a common male lineage with the extant Indian wolf. The study concluded that at least 2 different male haplogroups existed in ancient Europe, and that the dog male lineage diverged from its nearest common ancestor shared with the gray wolf sometime between 68,000-151,000 YBP.\n', 'Section::::Divergence from wolves.:Morphological divergence.\n', 'The questions of when and where dogs were first domesticated have taxed geneticists and archaeologists for decades. Identifying the earliest dogs is difficult because the key morphological characters that are used by zooarchaeologists to differentiate domestic dogs from their wild wolf ancestors (size and position of teeth, dental pathologies, and size and proportion of cranial and postcranial elements) were not yet fixed during the initial phases of the domestication process. The range of natural variation among these characters that may have existed in ancient wolf populations, and the time it took for these traits to appear in dogs, are unknown.\n', 'Section::::Divergence from wolves.:Morphological divergence.:Early dog specimens.\n', 'There are a number of recently discovered specimens which are proposed as being Paleolithic dogs, however their taxonomy is debated. These have been found in either Europe or Siberia and date 40,000-17,000 YBP. They include Hohle Fels in Germany, Goyet Caves in Belgium, Predmosti in the Czech Republic, and four sites in Russia: Razboinichya Cave in the Altai Republic, Kostyonki-8, Ulakhan Sular in the Sakha Republic, and Eliseevichi 1 on the Russian plain. Paw-prints from Chauvet Cave in France dated 26,000 YBP are suggested as being those of a dog, however these have been challenged as being left by a wolf.\n', 'There are also a number of later proposed Paleolithic dogs whose taxonomy has not been confirmed. These include a number of specimens from Germany (Kniegrotte, Oelknitz, Teufelsbrucke), Switzerland (Monruz, Kesslerloch, Champre-veyres-Hauterive), and Ukraine (Mezin, Mezhirich). A set of specimens dating 15,000-13,500 YBP have been confidently identified as domesticated dogs, based on their morphology and the archaeological sites in which they have been found. These include Spain (Erralla), France (Montespan, Le Morin, Le Closeau, Pont d’Ambon), and Germany (Bonn-Oberkassel). After this period, the remains of domesticated dogs have been identified from archaeological sites across Eurasia.\n', 'Possible dog domestication between 40,000-15,000 years ago is not clear due to the debate over what the Paleolithic dog specimens represent. This is due to the flexibility of genus "Canis" morphology, and the close morphological similarities between "Canis lupus" and "Canis familiaris". It is also due to the scarcity of Pleistocene wolf specimens available for analyses and so their morphological variation is unknown. Habitat type, climate, and prey specialization greatly modify the morphological plasticity of grey wolf populations, resulting in a range of morphologically, genetically, and ecologically distinct wolf morphotypes. With no baseline to work from, zooarchaeologists find it difficult to be able to differentiate between the initial indicators of dog domestication and various types of Late Pleistocene wolf ecomorphs, which can lead to the mis-identification of both early dogs and wolves. Additionally, the ongoing prehistoric admixture with local wolf populations during the domestication process may have led to canids that were domesticated in their behavior but wolflike in their morphology. Attempting to identify early tamed wolves, wolfdogs, or proto-dogs through morphological analysis alone may be impossible without the inclusion of genetic analyses.\n', 'A domestication study looked at the reasons why the archeological record that is based on the dating of fossil remains often differed from the genetic record contained within the cells of living species. The study concluded that our inability to date domestication is because domestication is a continuum and there is no single point where we can say that a species was clearly domesticated using these two techniques. The study proposes that changes in morphology across time and how humans were interacting with the species in the past needs to be considered in addition to these two techniques.\n', 'Section::::Dog domestication.\n', 'The earlier association of dogs with humans may have allowed dogs to have a profound influence on the course of early human history and the development of civilization. However, the timing, geographic locations, and ecological conditions that led to dog domestication are not agreed.\n', "There is clear evidence that dogs were derived from gray wolves during the initial phases of domestication and that no other canine species was involved. The wolf population(s) that were involved are likely to be extinct. Despite numerous genetic studies of both modern dogs and ancient dog remains, there is no firm consensus regarding either the timing or location(s) of domestication, the number of wolf populations that were involved, or the long-term effects domestication has had on the dog's genome.\n", "Genetic studies suggest a domestication process commencing over 25,000 YBP, in one or several wolf populations in either Europe, the high Arctic, or eastern Asia. The remains of large carcasses left by human hunter-gatherers may have led some wolves into entering a migratory relationship with humans. This could have led to their divergence from those wolves that remained in the one territory. A closer relationship between these wolves — or proto-dogs — and humans may have then developed, such as hunting together and mutual defence from other carnivores and other humans. Around 10,000 YBP agriculture was developed resulting in a sedentary lifestyle, along with phenotype divergence of the dog from its wolf ancestors, including variance in size. In the Victorian era, directed human selection developed the modern dog breeds, which resulted in a vast range of phenotypes. Each of these domestication phases have left their mark on the dog's genome.\n", 'Genetic studies support two population bottlenecks having occurred to the dog lineage, one due to the initial domestication and one due to the formation of dog breeds.\n', 'Section::::Dog domestication.:Time of domestication.\n', "An apex predator is a predator that sits on the top trophic level of the food chain, while a mesopredator sits further down the food chain and is dependent on smaller animals. Towards the end of the Pleistocene era, most of today's apex predators were mesopredators and this included the wolf. During the ecological upheaval associated with the close of the Late Pleistocene, one type of wolf population rose to become today's apex predator and another joined with humans to become an apex consumer.\n", 'In August 2015, a study undertook an analysis of the complete mitogenome sequences of 555 modern and ancient dogs. The sequences showed an increase in the population size approximately 23,500 YBP, which broadly coincides with the proposed separation of the ancestors of dogs and present-day wolves before the Last Glacial Maximum (refer first divergence). A ten-fold increase in the population size occurred after 15,000 YBP, which may be attributable to domestication events and is consistent with the demographic dependence of dogs on the human population.\n', 'Section::::Dog domestication.:Socialization.\n', 'Humans and wolves both exist in complex social groups. How humans and wolves got together remains unknown. One view holds that domestication as a process that is difficult to define. The term was developed by anthropologists with a human-centric view in which humans took wild animals (ungulates) and bred them to be "domestic", usually in order to provide improved food or materials for human consumption. That term may not be appropriate for a large carnivore such as the dog. This alternate view regards dogs as being either socialized and able to live among humans, or unsocialized. There exists today dogs that live with their human families but are unsocialized and will threaten strangers defensively and aggressively no different from a wild wolf. There also exists a number of cases where wild wolves have approached people in remote places, attempting to initiate play and to form companionship. One such notable wolf was Romeo, a gentle black wolf that formed relationships with the people and dogs of Juneau, Alaska. This view holds that before there could have been domestication of the wolf, there had to have been its socialization.\n', 'Section::::Dog domestication.:Commensal pathway.\n', 'Animal domestication is a coevolutionary process in which a population responds to selective pressure while adapting to a novel niche that included another species with evolving behaviors.\n', 'The dog is a classic example of a domestic animal that likely traveled a commensal pathway into domestication. The dog was the first domesticant, and was domesticated and widely established across Eurasia before the end of the Pleistocene, well before cultivation or the domestication of other animals. It may have been inevitable that the first domesticated animal came from the order of carnivores as these are less afraid when approaching other species. Within the carnivores, the first domesticated animal would need to exist without an all-meat diet, possess a running and hunting ability to provide its own food, and be of a controllable size to coexist with humans, indicating the family "Canidae", and the right temperament with wolves being among the most gregarious and cooperative animals on the planet.\n', 'Ancient DNA supports the hypothesis that dog domestication preceded the emergence of agriculture and was initiated close to the Last Glacial Maximum 27,000 YBP when hunter-gatherers preyed on megafauna, and when proto-dogs might have taken advantage of carcasses left on site by early hunters, assisted in the capture of prey, or provided defense from large competing predators at kill-sites. Wolves were probably attracted to human campfires by the smell of meat being cooked and discarded refuse in the vicinity, first loosely attaching themselves and then considering these as part of their home territory where their warning growls would alert humans to the approach of outsiders. The wolves most likely drawn to human camps were the less-aggressive, subdominant pack members with lowered flight response, higher stress thresholds, less wary around humans, and therefore better candidates for domestication. The earliest sign of domestication in dogs was the neotenization of skull morphology and the shortening of snout length that results in tooth crowding, reduction in tooth size, and a reduction in the number of teeth, which has been attributed to the strong selection for reduced aggression. This process may have begun during the initial commensal stage of dog domestication, even before humans began to be active partners in the process.\n', 'A maternal mitochondrial, paternal Y chromosome, and microsatellite assessment of two wolf populations in North America and combined with satellite telemetry data revealed significant genetic and morphological differences between one population that migrated with and preyed upon caribou, and another territorial ecotype population that remained in a boreal coniferous forest. Though these two populations spend a period of the year in the same place, and though there was evidence of gene flow between them, the difference in prey–habitat specialization has been sufficient to maintain genetic and even coloration divergence. A study has identified the remains of a population of extinct Pleistocene Beringian wolves with unique mitochondrial signatures. The skull shape, tooth wear, and isotopic signatures suggested these were specialist megafauna hunters and scavengers that became extinct while less specialized wolf ecotypes survived. Analogous to the modern wolf ecotype that has evolved to track and prey upon caribou, a Pleistocene wolf population could have begun following mobile hunter-gatherers, thus slowly acquiring genetic and phenotypic differences that would have allowed them to more successfully adapt to the human habitat.\n', 'Even today, the wolves on Ellesmere Island do not fear humans, which is thought to be due to them seeing humans so little, and they will approach humans cautiously, curiously and closely.\n', 'Section::::Dog domestication.:Post-domestication gene flow.\n', 'Since domestication, dogs have traveled alongside humans across most of the planet, often hybridizing\n', 'with local wild canids. This has resulted in complex patterns of ancient and recent admixture among both the wild and the domestic canids.\n', 'Some studies have found greater diversity in the genetic markers of dogs from East and Central Asia compared to Europe and have concluded that dogs originated from these regions, despite no archaeological evidence to support the conclusions. One reason for these discrepancies is the sustained admixture between different dog and wolf populations across the Old and New Worlds over at least the last 10,000 years, which has blurred the genetic signatures and confounded efforts of researchers at pinpointing the origins of dogs. Another reason is that none of the modern wolf populations are related to the Pleistocene wolves that were first domesticated. In other words, the extinction of the wolves that were the direct ancestors of dogs has muddied efforts to pinpoint the time and place of dog domestication.\n', 'Section::::Dog domestication.:Post-domestication gene flow.:Dog-Wolf admixture.\n', 'There is evidence of admixture between dog and regional wolf populations, except on the Tibetan Plateau and in the New World wolves. This admixture has occurred throughout history and as dogs expanded across the landscape. There are some dog populations that show recent admixture with wolves.\n', 'Phylogenetic analysis shows that modern dog mDNA haplotypes resolve into four monophyletic clades with strong statistical support, and these have been designated by researchers as clades A-D. Other studies that included a wider sample of specimens have reported two rare East Asian clades E-F with weaker statistical support. In 2009, a study found that haplogroups A, B and C included 98% of dogs and are found universally distributed across Eurasia, indicating that they were the result of a single domestication event, and that haplogroups D, E, and F were rare and appeared to be the result of regional hybridization with local wolves post-domestication. Haplogroups A and B contained subclades that appeared to be the result of hybridization with wolves post-domestication, because each haplotype within each of these subclades was the result of a female wolf/male dog pairing.\n', 'Haplogroup A: Includes 64-65% of dogs. Haplotypes of subclades a2–a6 are derived from post-domestication wolf–dog hybridization.\n', 'Haplogroup B: Includes 22-23% of dogs. haplotypes of subclade b2 are derived from post-domestication wolf–dog hybridization.\n', 'Haplogroup C: Includes 10-12% of dogs.\n', 'Haplogroup D: Derived from post-domestication wolf–dog hybridization in subclade d1 (Scandinavia) and d2 (South-West Asia). The northern Scandinavian subclade d1 hybrid haplotypes originated 480-3,000 YBP and are found in all Sami-related breeds: Finnish Lapphund, Swedish Lapphund, Lapponian Herder, Jamthund, Norwegian Elkhound and Hällefors Elkhound. The maternal wolf sequence that contributed to them has not been matched across Eurasia and its branch is phylogenetically rooted in the same sequence as the Altai dog (not a direct ancestor). The subclade d2 hybrid haplotypes are found in 2.6% of South-West Asian dogs.\n', 'Haplogroup E: Derived from post-domestication wolf–dog hybridization in East Asia, (rare distribution in South-East Asia, Korea and Japan).\n', 'Haplogroup F: Derived from post-domestication wolf–dog hybridization in Japan. A study of 600 dog specimens found only one dog whose sequence indicated hybridization with the extinct Japanese wolf.\n', 'It is not known whether this hybridization was the result of humans selecting for phenotypic traits from local wolf populations or the result of natural introgression as the dog expanded across Eurasia.\n', 'In 2018, a study found a small amount of dog ancestry in 62% of Eurasian wolf specimens looked at, that hybridization had occurred across a wide number of timescales and not just recently, however in contrast there was almost no admixture detected in the North American specimens. There was introgression of the male dog into the wolf, but also one hybrid detected which was the result of a male wolf crossed with a female dog. Wolves have maintained their phenotype differences from the dog, which indicates low-frequency hybridization. The conclusion is that phenotype is no indication of "purity" and the definition of pure wolves is ambiguous. Free-ranging dogs across Eurasia show introgression from wolves. Another study found that the β-defensin gene responsible for the black coat of North American wolves was the result of a single introgression from dogs in the Yukon dated between 1,600-7,200 years ago. The study proposes that early Native American dogs were the source.\n', 'Section::::Dog domestication.:Post-domestication gene flow.:Taimyr wolf admixture.\n', 'In May 2015, a study compared the ancestry of the Taimyr-1 wolf lineage to that of dogs and gray wolves.\n', 'Comparison to the gray wolf lineage indicated that Taimyr-1 was basal to gray wolves from the Middle East, China, Europe and North America but shared a substantial amount of history with the present-day gray wolves after their divergence from the coyote. This implies that the ancestry of the majority of gray wolf populations today stems from an ancestral population that lived less than 35,000 years ago but before the inundation of the Bering Land Bridge with the subsequent isolation of Eurasian and North American wolves.\n', 'A comparison of the ancestry of the Taimyr-1 lineage to the dog lineage indicated that some modern dog breeds have a closer association with either the gray wolf or Taimyr-1 due to admixture. The Saarloos wolfdog showed more association with the gray wolf, which is in agreement with the documented historical crossbreeding with gray wolves in this breed. Taimyr-1 shared more alleles (i.e. gene expressions) with those breeds that are associated with high latitudes - the Siberian husky and Greenland dog that are also associated with arctic human populations, and to a lesser extent the Shar Pei and Finnish spitz. An admixture graph of the Greenland dog indicates a best-fit of 3.5% shared material, although an ancestry proportion ranging between 1.4% and 27.3% is consistent with the data. This indicates admixture between the Taimyr-1 population and the ancestral dog population of these four high-latitude breeds. These results can be explained either by a very early presence of dogs in northern Eurasia or by the genetic legacy of Taimyr-1 being preserved in northern wolf populations until the arrival of dogs at high latitudes. This introgression could have provided early dogs living in high latitudes with phenotypic variation beneficial for adaption to a new and challenging environment. It also indicates that the ancestry of present-day dog breeds descends from more than one region.\n', 'An attempt to explore admixture between Taimyr-1 and gray wolves produced unreliable results.\n', 'As the Taimyr wolf had contributed to the genetic makeup of the Arctic breeds, a later study suggested that descendants of the Taimyr wolf survived until dogs were domesticated in Europe and arrived at high latitudes where they mixed with local wolves, and these both contributed to the modern Arctic breeds. Based on the most widely accepted oldest zooarchaeological dog remains, domestic dogs most likely arrived at high latitudes within the last 15,000 years. The mutation rates calibrated from both the Taimyr wolf and the Newgrange dog genomes suggest that modern wolf and dog populations diverged from a common ancestor between 20,000 and 60,000 YBP. This indicates that either dogs were domesticated much earlier than their first appearance in the archaeological record, or they arrived in the Arctic early, or both.\n', 'Section::::Dog domestication.:Positive selection.\n', 'Charles Darwin recognized the small number of traits that made domestic species different from their wild ancestors. He was also the first to recognize the difference between conscious selective breeding in which humans directly select for desirable traits, and unconscious selection where traits evolve as a by-product of natural selection or from selection on other traits. Domestic animals have variations in coat color as well as texture, dwarf and giant varieties, and changes in their reproductive cycle, and many others have tooth crowding and floppy ears.\n', 'Although it is easy to assume that each of these traits was uniquely selected for by hunter-gatherers and early farmers, beginning in 1959 Dmitry Belyayev tested the reactions of silver foxes to a hand placed in their cage and selected the tamest, least aggressive individuals to breed. His hypothesis was that, by selecting a behavioral trait, he could also influence the phenotype of subsequent generations, making them more domestic in appearance. Over the next 40 years, he succeeded in producing foxes with traits that were never directly selected for, including piebald coats floppy ears, upturned tails, shortened snouts, and shifts in developmental timing. In the 1980s, a researcher used a set of behavioral, cognitive, and visible phenotypic markers, such as coat colour, to produce domesticated fallow deer within a few generations. Similar results for tameness and fear have been found for mink and Japanese quail. In addition to demonstrating that domestic phenotypic traits could arise through selection for a behavioral trait, and domestic behavioral traits could arise through the selection for a phenotypic trait, these experiments provided a mechanism to explain how the animal domestication process could have begun without deliberate human forethought and action.\n', 'The genetic difference between domestic and wild populations can be framed within two considerations. The first distinguishes between domestication traits that are presumed to have been essential at the early stages of domestication, and improvement traits that have appeared since the split between wild and domestic populations. Domestication traits are generally fixed within all domesticates and were selected during the initial episode of domestication, whereas improvement traits are present only in a proportion of domesticates, though they may be fixed in individual breeds or regional populations. A second issue is whether traits associated with the domestication syndrome resulted from a relaxation of selection as animals exited the wild environment or from positive selection resulting from intentional and unintentional human preference. Some recent genomic studies on the genetic basis of traits associated with the domestication syndrome have shed light on both of these issues. A study published in 2016 suggested that there have been negative genetic consequences of the domestication process as well, that enrichment of disease-related gene variants accompanied positively selected traits.\n', 'In 2010, a study identified 51 regions of the dog genome that were associated with phenotypic variation among breeds in 57 traits studied, which included body, cranial, dental, and long bone shape and size. There were 3 quantitative trait loci that explained most of the phenotypic variation. Indicators of recent selection were shown by many of the 51 genomic regions that were associated with traits that define a breed, which include body size, coat characteristics, and ear floppiness. Geneticists have identified more than 300 genetic loci and 150 genes associated with coat color variability. Knowing the mutations associated with different colors has allowed the correlation between the timing of the appearance of variable coat colors in horses with the timing of their domestication. Other studies have shown how human-induced selection is responsible for the allelic variation in pigs. Together, these insights suggest that, although natural selection has kept variation to a minimum before domestication, humans have actively selected for novel coat colors as soon as they appeared in managed populations.\n', 'In 2015, a study looked at over 100 pig genome sequences to ascertain their process of domestication. A model that fitted the data included admixture with a now extinct ghost population of wild pigs during the Pleistocene. The study also found that despite back-crossing with wild pigs, the genomes of domestic pigs have strong signatures of selection at genetic loci that affect behavior and morphology. The study concluded that human selection for domestic traits likely counteracted the homogenizing effect of gene flow from wild boars and created domestication islands in the genome. The same process may also apply to other domesticated animals.\n', 'In 2014, a whole genome study of the DNA differences between wolves and dogs found that dogs did not show a reduced fear response but did show greater synaptic plasticity. Synaptic plasticity is widely believed to be the cellular correlate of learning and memory, and this change may have altered the learning and memory abilities of dogs in comparison to wolves.\n', 'Section::::Dog domestication.:Positive selection.:Behavior.\n', 'Unlike other domestic species which were primarily selected for production-related traits, dogs were initially selected for their behaviors. In 2016, a study found that there were only 11 fixed genes that showed variation between wolves and dogs. These gene variations were unlikely to have been the result of natural evolution, and indicate selection on both morphology and behavior during dog domestication. There was evidence of selection during dog domestication of genes that affect the adrenaline and noradrenaline biosynthesis pathway. These genes are involved in the synthesis, transport and degradation of a variety of neurotransmitters, particularly the catecholamines, which include dopamine and noradrenaline. Recurrent selection on this pathway and its role in emotional processing and the fight-or-flight response suggests that the behavioral changes we see in dogs compared to wolves may be due to changes in this pathway, leading to tameness and an emotional processing ability. Dogs generally show reduced fear and aggression compared to wolves. Some of these genes have been associated with aggression in some dog breeds, indicating their importance in both the initial domestication and then later in breed formation.\n', 'In 2018, a study identified 429 genes that differed between modern dogs and modern wolves. As the differences in these genes could also be found in ancient dog fossils, these were regarded as being the result of the initial domestication and not from recent breed formation. These genes are linked to neural crest and central nervous system development. These genes affect embryogenesis and can confer tameness, smaller jaws, floppy ears, and diminished craniofacial development, which distinguish domesticated dogs from wolves and are considered to reflect domestication syndrome. The study proposes that domestication syndrome is caused by alterations in the migration or activity of neural crest cells during their development. The study concluded that during early dog domestication, the initial selection was for behavior. This trait is influenced by those genes which act in the neural crest, which led to the phenotypes observed in modern dogs.\n', 'Section::::Dog domestication.:Positive selection.:Dietary adaption.\n', "AMY2B (Alpha-Amylase 2B) is a gene that codes a protein that assists with the first step in the digestion of dietary starch and glycogen. An expansion of this gene in dogs would enable early dogs to exploit a starch-rich diet as they fed on refuse from agriculture. In a study in 2014, the data indicated that the wolves and dingo had just two copies of the gene and the Siberian Husky that is associated with hunter-gatherers had just three or four copies, whereas the Saluki that is associated with the Fertile Crescent where agriculture originated had 29 copies. The results show that on average, modern dogs have a high copy number of the gene, whereas wolves and dingoes do not. The high copy number of AMY2B variants likely already existed as a standing variation in early domestic dogs, but expanded more recently with the development of large agriculturally based civilizations. This suggests that at the beginning of the domestication process, dogs may have been characterized by a more carnivorous diet than their modern-day counterparts, a diet held in common with early hunter-gatherers. A later study indicated that because most dogs had a high copy number of the AMY2B gene but the arctic breeds and the dingo did not, that the dog's dietary change may not have been caused by initial domestication but by the subsequent spread of agriculture to most - but not all - regions of the planet.\n", 'In 2016, a study of the dog genome compared to the wolf genome looked for genes that showed signs of having undergone positive selection. The study identified genes relating to brain function and behavior, and to lipid metabolism. This ability to process lipids indicates a dietary target of selection that was important when proto-dogs hunted and fed alongside hunter-gatherers. The evolution of the dietary metabolism genes may have helped process the increased lipid content of early dog diets as they scavenged on the remains of carcasses left by hunter-gatherers. Prey capture rates may have increased in comparison to wolves and with it the amount of lipid consumed by the assisting proto-dogs. A unique dietary selection pressure may have evolved both from the amount consumed, and the shifting composition of, tissues that were available to proto-dogs once humans had removed the most desirable parts of the carcass for themselves. A study of the mammal biomass during modern human expansion into the northern Mammoth steppe found that it had occurred under conditions of unlimited resources, and that many of the animals were killed with only a small part consumed or left unused.\n', 'Section::::Dog domestication.:Natural selection.\n', 'Dogs can infer the name of an object and have been shown to learn the names of over 1,000 objects. Dogs can follow the human pointing gesture; even nine-week-old puppies can follow a basic human pointing gesture without being taught. New Guinea singing dogs, a half-wild proto-dog endemic to the remote alpine regions of New Guinea, as well as dingoes in the remote Outback of Australia are also capable of this. These examples demonstrate an ability to read human gestures that arose early in domestication and did not require human selection. "Humans did not develop dogs, we only fine-tuned them down the road."\n', "A dog's cranium is 15% smaller than an equally heavy wolf's, and the dog is less aggressive and more playful. Other species pairs show similar differences. Bonobos, like chimpanzees, are a close genetic cousin to humans, but unlike the chimpanzees, bonobos are not aggressive and do not participate in lethal inter-group aggression or kill within their own group. The most distinctive features of a bonobo are its cranium, which is 15% smaller than a chimpanzee's, and its less aggressive and more playful behavior. In other examples, the guinea pig's cranium is 13% smaller than its wild cousin the cavy, and domestic fowl show a similar reduction to their wild cousins. Possession of a smaller cranium for holding a smaller brain is a telltale sign of domestication. Bonobos appear to have domesticated themselves. In the farm fox experiment, humans selectively bred foxes against aggression, causing domestication syndrome. The foxes were not selectively bred for smaller craniums and teeth, floppy ears, or skills at using human gestures, but these traits were demonstrated in the friendly foxes. Natural selection favors those that are the most successful at reproducing, not the most aggressive. Selection against aggression made possible the ability to cooperate and communicate among foxes, dogs and bonobos. Perhaps it did the same thing for humans. The more docile animals have been found to have less testosterone than their more aggressive counterparts, and testosterone controls aggression and brain size. One researcher has argued that in becoming more social, we humans have developed a smaller brain than those of humans 20,000 years ago.\n", 'Section::::Dog domestication.:Dog and human convergent evolution.\n', 'As a result of the domestication process there is also evidence of convergent evolution having occurred between dogs and humans. The history of the two is forever intertwined. Dogs suffer from the same diseases as humans, which include cancer, diabetes, heart disease, and neurological disorders. The underlying disease pathology is similar to humans, as is their responses and outcomes to treatment.\n', 'Section::::Dog domestication.:Dog and human convergent evolution.:Parallel evolution.\n', 'There are patterns of genes which are related by their function and these patterns can be found in both dogs and humans. This fact can be used to study the coevolution of gene function. Dogs accompanied humans when they first migrated into new environments. Both dogs and humans have adapted to different environmental conditions, with their genomes showing parallel evolution. These include adaptation to high altitude, low oxygen hypoxia conditions, and genes that play a role in digestion, metabolism, neurological processes, and some related to cancer. It can be inferred from those genes which act on the serotonin system in the brain that these have given rise to less aggressive behavior when living in a crowded environment.\n', 'In 2007, a study found that dog domestication was accompanied by selection at three genes with key roles in starch digestion: AMY2B, MGAMand SGLT1, and was a striking case of parallel evolution when coping with an increasingly starch-rich diet caused similar adaptive responses in dogs and humans.\n', 'Section::::Dog domestication.:Dog and human convergent evolution.:Behavioral evidence.\n', 'Convergent evolution is when distantly related species independently evolve similar solutions to the same problem. For example, fish, penguins and dolphins have each separately evolved flippers as a solution to the problem of moving through the water. What has been found between dogs and humans is something less frequently demonstrated: psychological convergence. Dogs have independently evolved to be cognitively more similar to humans than we are to our closest genetic relatives. Dogs have evolved specialized skills for reading human social and communicative behavior. These skills seem more flexible – and possibly more human-like – than those of other animals more closely related to humans phylogenetically, such as chimpanzees, bonobos and other great apes. This raises the possibility that convergent evolution has occurred: both "Canis familiaris" and "Homo sapiens" might have evolved some similar (although obviously not identical) social-communicative skills – in both cases adapted for certain kinds of social and communicative interactions with human beings.\n', "The pointing gesture is a human-specific signal, is referential in its nature, and is a foundation building-block of human communication. Human infants acquire it weeks before the first spoken word. In 2009, a study compared the responses to a range of pointing gestures by dogs and human infants. The study showed little difference in the performance of 2-year-old children and dogs, while 3-year-old children's performance was higher. The results also showed that all subjects were able to generalize from their previous experience to respond to relatively novel pointing gestures. These findings suggest that dogs demonstrating a similar level of performance as 2-year-old children can be explained as a joint outcome of their evolutionary history as well as their socialization in a human environment.\n", 'Later studies support coevolution in that dogs can discriminate the emotional expressions of human faces, and that most people can tell from a bark whether a dog is alone, being approached by a stranger, playing, or being aggressive, and can tell from a growl how big the dog is.\n', 'In 2015, a study found that when dogs and their owners interact, extended eye contact (mutual gaze) increases oxytocin levels in both the dog and its owner. As oxytocin is known for its role in maternal bonding, it is considered likely that this effect has supported the coevolution of human-dog bonding. One observer has stated, "The dog could have arisen only from animals predisposed to human society by lack of fear, attentiveness, curiosity, necessity, and recognition of advantage gained through collaboration...the humans and wolves involved in the conversion were sentient, observant beings constantly making decisions about how they lived and what they did, based on the perceived ability to obtain at a given time and place what they needed to survive and thrive. They were social animals willing, even eager, to join forces with another animal to merge their sense of group with the others\' sense and create an expanded super-group that was beneficial to both in multiple ways. They were individual animals and people involved, from our perspective, in a biological and cultural process that involved linking not only their lives but the evolutionary fate of their heirs in ways, we must assume, they could never have imagined. Powerful emotions were in play that many observers today refer to as love – boundless, unquestioning love."\n', 'Section::::Dog domestication.:Dog and human convergent evolution.:Human adoption of some wolf behaviors.\n', 'In 2002, a study proposed that immediate human ancestors and wolves may have domesticated each other through a strategic alliance that would change both respectively into humans and dogs. The effects of human psychology, hunting practices, territoriality and social behavior would have been profound. Early humans moved from scavenging and small-game hunting to big-game hunting by living in larger, socially more-complex groups, learning to hunt in packs, and developing powers of cooperation and negotiation in complex situations. As these are characteristics of wolves, dogs and humans, it can be argued that these behaviors were enhanced once wolves and humans began to cohabit. Communal hunting led to communal defense. Wolves actively patrol and defend their scent-marked territory, and perhaps humans had their sense of territoriality enhanced by living with wolves. One of the keys to recent human survival has been the forming of partnerships. Strong bonds exist between same-sex wolves, dogs and humans and these bonds are stronger than exist between other same-sex animal pairs. Today, the most widespread form of inter-species bonding occurs between humans and dogs. The concept of friendship has ancient origins but it may have been enhanced through the inter-species relationship to give a survival advantage.\n', 'In 2003, a study compared the behavior and ethics of chimpanzees, wolves and humans. Cooperation among humans\' closest genetic relative is limited to occasional hunting episodes or the persecution of a competitor for personal advantage, which had to be tempered if humans were to become domesticated. The closest approximation to human morality that can be found in nature is that of the gray wolf, "Canis lupus". Wolves are among the most gregarious and cooperative of animals on the planet, and their ability to cooperate in well-coordinated drives to hunt prey, carry items too heavy for an individual, provisioning not only their own young but also the other pack members, babysitting etc. are rivaled only by that of human societies. Similar forms of cooperation are observed in two closely related canids, the African wild dog and the Asian dhole, therefore it is reasonable to assume that canid sociality and cooperation are old traits that in terms of evolution predate human sociality and cooperation. Today\'s wolves may even be less social than their ancestors, as they have lost access to big herds of ungulates and now tend more toward a lifestyle similar to coyotes, jackals, and even foxes. Social sharing within families may be a trait that early humans learned from wolves, and with wolves digging dens long before humans constructed huts it is not clear who domesticated whom.\n', 'On the mammoth steppe the wolf\'s ability to hunt in packs, to share risk fairly among pack members, and to cooperate moved them to the top of the food chain above lions, hyenas and bears. Some wolves followed the great reindeer herds, eliminating the unfit, the weaklings, the sick and the aged, and therefore improved the herd. These wolves had become the first pastoralists hundreds of thousands of years before humans also took to this role. The wolves\' advantage over their competitors was that they were able to keep pace with the herds, move fast and enduringly, and make the most efficient use of their kill by their ability to "wolf down" a large part of their quarry before other predators had detected the kill. The study proposed that during the Last Glacial Maximum, some of our ancestors teamed up with those pastoralist wolves and learned their techniques. Many of our ancestors remained gatherers and scavengers, or specialized as fish-hunters, hunter-gatherers, and hunter-gardeners. However, some ancestors adopted the pastoralist wolves\' lifestyle as herd followers and herders of reindeer, horses, and other hoofed animals. They harvested the best stock for themselves while the wolves kept the herd strong, and this group of humans was to become the first herders and this group of wolves was to become the first dogs.\n', 'Section::::First dogs.\n', "The dog was the first species and the only large carnivore to have been domesticated. Over the past 200 years, dogs have undergone rapid phenotypic change and were formed into today's modern dog breeds due to artificial selection imposed by humans. These breeds can vary in size and weight from a teacup poodle to a giant mastiff. The skull, body, and limb proportions vary significantly between breeds, with dogs displaying more phenotypic diversity than can be found within the entire order of carnivores. Some breeds demonstrate outstanding skills in herding, retrieving, scent detection, and guarding, which demonstrates the functional and behavioral diversity of dogs. There have been major advances in understanding the genes that gave rise to the phenotypic traits of dogs. The first dogs were certainly wolflike, however the phenotypic changes that coincided with the dog–wolf genetic divergence are not known.\n", 'Section::::First dogs.:Bonn–Oberkassel dog.\n', 'In 1914, on the eve of the First World War, two human skeletons were discovered during basalt quarrying at Oberkassel, Bonn in Germany. With them were found a right mandible of a "wolf" and other animal bones. After the end of the First World War, in 1919 a full study was made of these remains. The mandible was recorded as ""Canis lupus", the wolf" and some of the other animal bones were assigned to it. The remains were then stored and forgotten for fifty years. In the late 1970s there was renewed interest in the Oberkassel remains and the mandible was re-examined and reclassified as belonging to a domesticated dog. The mitochondrial DNA sequence of the mandible was matched to "Canis lupus familiaris" - dog, and confirms that the Oberkassel dog is a direct ancestor of today\'s dogs. The bodies were dated to 14,223 YBP. This implies that in Western Europe there were morphologically and genetically "modern" dogs in existence around 14,500 years ago.\n', 'Later studies assigned more of the other animal bones to the dog until most of a skeleton could be assembled. The humans were a man aged 40 years and a woman aged 25 years. All three skeletal remains were found covered with large 20\xa0cm thick basalt blocks and were sprayed with red hematite powder. The consensus is that a dog was buried along with two humans. A tooth belonging to a smaller and older dog was also identified but it had not been sprayed with red powder. The cause of the death of the two humans is not known. A pathology study of the dog remains suggests that it had died young after suffering from canine distemper between ages 19 and 23 weeks. The dog could not have survived during this period without intensive human care. During this period the dog was of no utilitarian use to humans, and suggests the existence of emotional or symbolic ties between these humans and this dog. In conclusion, near the end of the Late Pleistocene at least some humans regarded dogs not just materialistically, but had developed emotional and caring bonds for their dogs.\n', 'Section::::First dogs.:First dogs as a hunting technology.\n', 'During the Upper Paleolithic (50,000-10,000 YBP), the increase in human population density, advances in blade and hunting technology, and climate change may have altered prey densities and made scavenging crucial to the survival of some wolf populations. Adaptations to scavenging such as tameness, small body size, and a decreased age of reproduction would reduce their hunting efficiency further, eventually leading to obligated scavenging. Whether these earliest dogs were simply human-commensal scavengers or they played some role as companions or hunters that hastened their spread is unknown.\n', 'Researchers have proposed that in the past a hunting partnership existed between humans and dogs that was the basis for dog domestication. \n', "Petroglyph rock art dating to 8,000 YBP at the sites of Shuwaymis and Jubbah, in northwestern Saudi Arabia, depict large numbers of dogs participating in hunting scenes with some being controlled on leashes. The transition from the Late Pleistocene into the early Holocene was marked by climatic change from cold and dry to warmer, wetter conditions and rapid shifts in flora and fauna, with much of the open habitat of large herbivores being replaced by forests. In the early Holocene, it is proposed that along with changes in arrow-head technology that hunting dogs were used by hunters to track and retrieve wounded game in thick forests. The dog's ability to chase, track, sniff out and hold prey can significantly increase the success of hunters in forests, where human senses and location skills are not as sharp as in more open habitats. Dogs are still used for hunting in forests today.\n", 'Section::::First dogs.:Dogs enter North America from Siberia.\n', 'In North America, the earliest dog remains were found in Illinois and radiocarbon dating indicates 9,900 YBP. These include three isolated burials at the Koster Site near the lower Illinois River in Greene County, and one burial 35 km away at the Stilwell II site in Pike County. These dogs were medium-sized adults around in height and around in weight, with very active lifestyles and varied morphologies. Isotope analysis can be used to identify some chemical elements, allowing researchers to make inferences about the diet of a species. An isotope analysis of bone collagen indicates a diet consisting largely of freshwater fish. Similar dog burials across Eurasia are thought to be due to the dog’s importance in hunting to people who were trying to adapt to the changing environments and prey species during the Pleistocene-Holocene transition. In these places, the dog had gained an elevated social status. \n', 'In 2018, a study compared sequences of North American dog fossils with Siberian dog fossils and modern dogs. The nearest relative to the North American fossils was a 9,000 YBP fossil discovered on Zhokhov Island, arctic north-eastern Siberia, which was connected to the mainland at that time. The study inferred from mDNA that all of the North American dogs shared a common ancestor dated 14,600 YBP, and this ancestor had diverged along with the ancestor of the Zhokhov dog from their common ancestor 15,600 YBP. The timing of the Koster dogs shows that dogs entered North America from Siberia 4,500 years after humans did, were isolated for the next 9,000 years, and after contact with Europeans these no longer exist because they were replaced by Eurasian dogs. The pre-contact dogs exhibit a unique genetic signature that is now gone, with nDNA indicating that their nearest genetic relatives today are the arctic breed dogs - Alaskan malamutes, Greenland dogs, and Alaskan huskies and Siberian huskies.\n', 'Section::::First dogs.:First dog breeds developed in Siberia.\n', 'In 2017, a study showed that 9,000 YBP the domestic dog was present at what is now Zhokhov Island. The dogs were selectively bred as either sled dogs or as hunting dogs, which implies that a sled dog standard and a hunting dog standard existed at that time. The optimal maximum size for a sled dog is 20–25\xa0kg based on thermo-regulation, and the ancient sled dogs were between 16–25\xa0kg. The same standard has been found in the remains of sled dogs from this region 2,000 YBP and in the modern Siberian husky breed standard. Other dogs were more massive at 30\xa0kg and appear to be dogs that had been crossed with wolves and used for polar bear hunting. At death, the heads of the dogs had been carefully separated from their bodies by humans, probably for ceremonial reasons.\n', 'The study proposes that after having diverged from the common ancestor along with the grey wolf, the evolution of "Canis familiaris" proceeded in three stages. The first was natural selection based on feeding behavior within the ecological niche that had been formed through human activity. The second was artificial selection based on tamability. The third was directed selection based on forming breeds that possessed qualities to help with specific tasks within the human economy. The process commenced 40,000-30,000 YBP with its speed increasing with each stage until domestication became complete.\n', 'Section::::First dogs.:Dogs enter Japan.\n', "In Japan, temperate deciduous forests rapidly spread onto the main island of Honshu and caused an adaption away from hunting megafauna (Naumann's elephant and Yabe's giant deer) to hunting the quicker sika deer and wild boar in dense forest. With this came a change in hunting technology, including a shift to smaller, triangular points for arrows. A study of the Jōmon people that lived on the Pacific coast of Honshu during the early Holocene shows that they were conducting individual dog burials and were probably using dogs as tools for hunting sika deer and wild boar, as hunters in Japan still do today.\n", 'Hunting dogs make major contributions to forager societies and the ethnographic record shows them being given proper names, treated as family members, and considered separate to other types of dogs. This special treatment includes separate burials with markers and grave-goods, with those that were exceptional hunters or that were killed on the hunt often venerated. A dog\'s value as a hunting partner gives them status as a living weapon and the most skilled elevated to taking on a "personhood", with their social position in life and in death similar to that of the skilled hunters.\n', 'Intentional dog burials together with ungulate hunting is also found in other early Holocene deciduous forest forager societies in Europe and North America, indicating that across the Holarctic temperate zone hunting dogs were a widespread adaptation to forest ungulate hunting.\n'), (KiltDocAnchor(text='domestic dog', href='Dog', paragraph_id=1, start=18, end=30), KiltDocAnchor(text='evolutionary divergence', href='evolutionary%20divergence', paragraph_id=1, start=50, end=73), KiltDocAnchor(text='domestication', href='domestication', paragraph_id=1, start=93, end=106), KiltDocAnchor(text='dog types', href='dog%20types', paragraph_id=1, start=133, end=142), KiltDocAnchor(text='dog breeds', href='dog%20breeds', paragraph_id=1, start=147, end=157), KiltDocAnchor(text='genus', href='genus', paragraph_id=1, start=186, end=191), KiltDocAnchor(text='Canis', href='Canis', paragraph_id=1, start=193, end=198), KiltDocAnchor(text='wolf-like canids', href='Evolution%20of%20the%20wolf%23Wolf-like%20canids', paragraph_id=1, start=225, end=241), KiltDocAnchor(text='carnivore', href='carnivore', paragraph_id=1, start=288, end=297), KiltDocAnchor(text='sister taxa', href='sister%20taxa', paragraph_id=1, start=362, end=373), KiltDocAnchor(text='domesticated', href='Domestication', paragraph_id=1, start=459, end=471), KiltDocAnchor(text='genetic divergence', href='genetic%20divergence', paragraph_id=2, start=4, end=22), KiltDocAnchor(text='Last Glacial Maximum', href='Last%20Glacial%20Maximum', paragraph_id=2, start=115, end=135), KiltDocAnchor(text='domestication of animals', href='domestication%20of%20animals', paragraph_id=2, start=319, end=343), KiltDocAnchor(text='grey wolf', href='grey%20wolf', paragraph_id=2, start=396, end=405), KiltDocAnchor(text='hunter-gatherers', href='hunter-gatherers', paragraph_id=2, start=433, end=449), KiltDocAnchor(text='Bonn–Oberkassel dog', href='%23Bonn%E2%80%93Oberkassel%20dog', paragraph_id=2, start=522, end=541), KiltDocAnchor(text='Near East', href='Ancient%20Near%20East', paragraph_id=2, start=722, end=731), KiltDocAnchor(text='aurochs', href='aurochs', paragraph_id=2, start=784, end=791), KiltDocAnchor(text='Western Europe', href='Western%20Europe', paragraph_id=3, start=106, end=120), KiltDocAnchor(text='Central Asia', href='Central%20Asia', paragraph_id=3, start=122, end=134), KiltDocAnchor(text='East Asia', href='East%20Asia', paragraph_id=3, start=139, end=148), KiltDocAnchor(text='Eurasian', href='Eurasian', paragraph_id=3, start=266, end=274), KiltDocAnchor(text='extinct', href='Extinction', paragraph_id=3, start=314, end=321), KiltDocAnchor(text='Miocene', href='Miocene', paragraph_id=5, start=48, end=55), KiltDocAnchor(text='glaciations', href='glaciations', paragraph_id=5, start=122, end=133), KiltDocAnchor(text='Pliocene', href='Pliocene', paragraph_id=5, start=141, end=149), KiltDocAnchor(text='Pleistocene', href='Pleistocene', paragraph_id=5, start=158, end=169), KiltDocAnchor(text='Ice Age', href='Ice%20Age', paragraph_id=5, start=209, end=216), KiltDocAnchor(text='forests', href='forests', paragraph_id=5, start=233, end=240), KiltDocAnchor(text='savannahs', href='savannahs', paragraph_id=5, start=245, end=254), KiltDocAnchor(text='steppes', href='steppes', paragraph_id=5, start=274, end=281), KiltDocAnchor(text='grasslands', href='grasslands', paragraph_id=5, start=285, end=295), KiltDocAnchor(text='North America', href='North%20America', paragraph_id=6, start=12, end=25), KiltDocAnchor(text='fox', href='fox', paragraph_id=6, start=42, end=45), KiltDocAnchor(text='Canis', href='Canis', paragraph_id=6, start=139, end=144), KiltDocAnchor(text='coyotes', href='coyotes', paragraph_id=6, start=176, end=183), KiltDocAnchor(text='wolves', href='wolves', paragraph_id=6, start=185, end=191), KiltDocAnchor(text='domestic dog', href='domestic%20dog', paragraph_id=6, start=200, end=212), KiltDocAnchor(text='eastern Africa', href='eastern%20Africa', paragraph_id=6, start=217, end=231), KiltDocAnchor(text='primates', href='primates', paragraph_id=6, start=266, end=274), KiltDocAnchor(text='Eurasia', href='Eurasia', paragraph_id=6, start=544, end=551), KiltDocAnchor(text="Ju'wasi", href='%C7%83Kung%20people', paragraph_id=7, start=136, end=143), KiltDocAnchor(text='Namibia', href='Namibia', paragraph_id=7, start=154, end=161), KiltDocAnchor(text='canids', href='canids', paragraph_id=7, start=643, end=649), KiltDocAnchor(text='domestication of animals', href='domestication%20of%20animals', paragraph_id=9, start=4, end=28), KiltDocAnchor(text='years before present', href='years%20before%20present', paragraph_id=9, start=51, end=71), KiltDocAnchor(text='grey wolf', href='grey%20wolf', paragraph_id=9, start=98, end=107), KiltDocAnchor(text='hunter-gatherers', href='hunter-gatherers', paragraph_id=9, start=135, end=151), KiltDocAnchor(text='Near East', href='Ancient%20Near%20East', paragraph_id=9, start=207, end=216), KiltDocAnchor(text='aurochs', href='aurochs', paragraph_id=9, start=269, end=276), KiltDocAnchor(text='commensal pathway', href='Domestication%20of%20animals%23Commensal%20pathway', paragraph_id=9, start=388, end=405), KiltDocAnchor(text='Bonn–Oberkassel dog', href='%23Bonn%E2%80%93Oberkassel%20dog', paragraph_id=9, start=723, end=742), KiltDocAnchor(text='Paleolithic dog', href='Paleolithic%20dog', paragraph_id=9, start=809, end=824), KiltDocAnchor(text='genetic divergence', href='genetic%20divergence', paragraph_id=9, start=914, end=932), KiltDocAnchor(text='evolutionary divergence', href='Divergent%20evolution', paragraph_id=11, start=27, end=50), KiltDocAnchor(text="Przewalski's horse", href='Przewalski%27s%20horse', paragraph_id=11, start=298, end=316), KiltDocAnchor(text='Late Pleistocene glaciation', href='Quaternary%20glaciation', paragraph_id=13, start=11, end=38), KiltDocAnchor(text='mammoth steppe', href='mammoth%20steppe', paragraph_id=13, start=47, end=61), KiltDocAnchor(text='Spain', href='Spain', paragraph_id=13, start=77, end=82), KiltDocAnchor(text='Eurasia', href='Eurasia', paragraph_id=13, start=100, end=107), KiltDocAnchor(text='Bering land bridge', href='Beringia', paragraph_id=13, start=121, end=139), KiltDocAnchor(text='Alaska', href='Alaska', paragraph_id=13, start=145, end=151), KiltDocAnchor(text='Yukon', href='Yukon', paragraph_id=13, start=160, end=165), KiltDocAnchor(text='megafaunal', href='Pleistocene%20megafauna', paragraph_id=13, start=335, end=345), KiltDocAnchor(text='extinction', href='Quaternary%20extinction%20event', paragraph_id=13, start=346, end=356), KiltDocAnchor(text='Last Glacial Maximum', href='Last%20Glacial%20Maximum', paragraph_id=13, start=427, end=447), KiltDocAnchor(text='genus', href='genus', paragraph_id=13, start=620, end=625), KiltDocAnchor(text='biogeography', href='biogeography', paragraph_id=14, start=42, end=54), KiltDocAnchor(text='Beringia', href='Beringia', paragraph_id=14, start=178, end=186), KiltDocAnchor(text='Old Crow, Yukon', href='Old%20Crow%2C%20Yukon', paragraph_id=14, start=190, end=205), KiltDocAnchor(text='Fairbanks', href='Fairbanks', paragraph_id=14, start=241, end=250), KiltDocAnchor(text='rostrum', href='Rostrum%20%28anatomy%29%23Vertebrates', paragraph_id=14, start=510, end=517), KiltDocAnchor(text='temporalis', href='temporalis', paragraph_id=14, start=553, end=563), KiltDocAnchor(text='premolars', href='premolars', paragraph_id=14, start=583, end=592), KiltDocAnchor(text='Pleistocene megafauna', href='Pleistocene%20megafauna', paragraph_id=14, start=743, end=764), KiltDocAnchor(text='dire wolf', href='dire%20wolf', paragraph_id=14, start=900, end=909), KiltDocAnchor(text='spotted hyena', href='spotted%20hyena', paragraph_id=14, start=1149, end=1162), KiltDocAnchor(text='gray wolf', href='gray%20wolf', paragraph_id=16, start=34, end=43), KiltDocAnchor(text='canine', href='Canis', paragraph_id=16, start=117, end=123), KiltDocAnchor(text='phylogenetic analysis', href='phylogenetic%20analysis', paragraph_id=16, start=208, end=229), KiltDocAnchor(text='DNA sequences', href='DNA%20sequences', paragraph_id=16, start=233, end=246), KiltDocAnchor(text='Late Pleistocene', href='Late%20Pleistocene', paragraph_id=16, start=368, end=384), KiltDocAnchor(text='genetic divergence', href='genetic%20divergence', paragraph_id=16, start=503, end=521), KiltDocAnchor(text='incomplete lineage sorting', href='incomplete%20lineage%20sorting', paragraph_id=16, start=666, end=692), KiltDocAnchor(text='gene flow', href='gene%20flow', paragraph_id=16, start=842, end=851), KiltDocAnchor(text='mutations', href='mutations', paragraph_id=16, start=968, end=977), KiltDocAnchor(text='whole genome sequencing', href='whole%20genome%20sequencing', paragraph_id=17, start=13, end=36), KiltDocAnchor(text='genome sequence', href='genome%20sequence', paragraph_id=17, start=174, end=189), KiltDocAnchor(text='Taymyr Peninsula', href='Taymyr%20Peninsula', paragraph_id=17, start=241, end=257), KiltDocAnchor(text='Radiocarbon dating', href='Radiocarbon%20dating', paragraph_id=17, start=357, end=375), KiltDocAnchor(text='mutation rate', href='mutation%20rate', paragraph_id=17, start=471, end=484), KiltDocAnchor(text='genetic admixture', href='genetic%20admixture', paragraph_id=19, start=265, end=282), KiltDocAnchor(text='incomplete lineage sorting', href='incomplete%20lineage%20sorting', paragraph_id=19, start=326, end=352), KiltDocAnchor(text='Paleogenomics', href='Paleogenomics', paragraph_id=19, start=513, end=526), KiltDocAnchor(text='fossil', href='fossil', paragraph_id=19, start=572, end=578), KiltDocAnchor(text='mitochondrial genome', href='Nuclear%20DNA%23Mitochondrial%20DNA', paragraph_id=21, start=40, end=60), KiltDocAnchor(text='phylogenetic tree', href='phylogenetic%20tree', paragraph_id=21, start=175, end=192), KiltDocAnchor(text='genetic variation', href='genetic%20variation', paragraph_id=21, start=233, end=250), KiltDocAnchor(text='Goyet Cave canids', href='Paleolithic%20dog%23Goyet%20dog', paragraph_id=21, start=441, end=458), KiltDocAnchor(text='ecomorph', href='Ecomorphology', paragraph_id=21, start=720, end=728), KiltDocAnchor(text='Razboinichya Cave canid', href='Paleolithic%20dog%23Altai%20dog', paragraph_id=22, start=24, end=47), KiltDocAnchor(text='mitochondrial DNA', href='mitochondrial%20DNA', paragraph_id=22, start=83, end=100), KiltDocAnchor(text='basal', href='Basal%20%28biology%29', paragraph_id=22, start=281, end=286), KiltDocAnchor(text='phylogenetic', href='phylogenetic', paragraph_id=23, start=4, end=16), KiltDocAnchor(text='clades', href='clades', paragraph_id=23, start=69, end=75), KiltDocAnchor(text='mandible', href='mandible', paragraph_id=25, start=177, end=185), KiltDocAnchor(text='"Canis c.f. variabilis"', href='Canis%20mosbachensis%23Canis%20variabilis', paragraph_id=25, start=211, end=234), KiltDocAnchor(text='c.f.', href='Open%20nomenclature%23Usage%20of%20open%20nomenclature', paragraph_id=25, start=242, end=246), KiltDocAnchor(text='Latin', href='Latin', paragraph_id=25, start=252, end=257), KiltDocAnchor(text='haplotypes', href='haplotypes', paragraph_id=25, start=340, end=350), KiltDocAnchor(text='mutations', href='mutations', paragraph_id=25, start=677, end=686), KiltDocAnchor(text='gene pool', href='gene%20pool', paragraph_id=25, start=795, end=804), KiltDocAnchor(text='Victorian era', href='Victorian%20era', paragraph_id=27, start=117, end=130), KiltDocAnchor(text='genetic admixture', href='genetic%20admixture', paragraph_id=27, start=271, end=288), KiltDocAnchor(text='Siberian huskies', href='Siberian%20Husky', paragraph_id=28, start=0, end=16), KiltDocAnchor(text='mitochondrial DNA', href='mitochondrial%20DNA', paragraph_id=29, start=30, end=47), KiltDocAnchor(text='whole-genome sequences', href='Whole%20genome%20sequencing', paragraph_id=29, start=52, end=74), KiltDocAnchor(text='nuclear genome', href='nuclear%20genome', paragraph_id=29, start=200, end=214), KiltDocAnchor(text='Late Neolithic', href='Late%20Neolithic', paragraph_id=29, start=264, end=278), KiltDocAnchor(text='Newgrange', href='Newgrange', paragraph_id=29, start=296, end=305), KiltDocAnchor(text='Ireland', href='Ireland', paragraph_id=29, start=307, end=314), KiltDocAnchor(text='radiocarbon dated', href='radiocarbon%20dated', paragraph_id=29, start=319, end=336), KiltDocAnchor(text='Paleolithic dog', href='Paleolithic%20dog', paragraph_id=29, start=748, end=763), KiltDocAnchor(text='phylogenetic tree', href='phylogenetic%20tree', paragraph_id=29, start=858, end=875), KiltDocAnchor(text='Sarloos wolfdog', href='Sarloos%20wolfdog', paragraph_id=29, start=940, end=955), KiltDocAnchor(text='German Shepherd', href='German%20Shepherd', paragraph_id=29, start=1025, end=1040), KiltDocAnchor(text='C and D', href='%23Dog-Wolf%20admixture', paragraph_id=30, start=100, end=107), KiltDocAnchor(text='population bottleneck', href='population%20bottleneck', paragraph_id=30, start=440, end=461), KiltDocAnchor(text='Central Asia', href='Central%20Asia', paragraph_id=30, start=667, end=679), KiltDocAnchor(text='Early Neolithic', href='Early%20Neolithic', paragraph_id=34, start=220, end=235), KiltDocAnchor(text='Herxheim', href='Herxheim%20%28archaeological%20site%29', paragraph_id=34, start=244, end=252), KiltDocAnchor(text='Late Neolithic', href='Late%20Neolithic', paragraph_id=34, start=292, end=306), KiltDocAnchor(text='Forchheim', href='Forchheim', paragraph_id=34, start=350, end=359), KiltDocAnchor(text='Near East', href='Near%20East', paragraph_id=35, start=391, end=400), KiltDocAnchor(text='y-chromosome', href='y-chromosome', paragraph_id=35, start=485, end=497), KiltDocAnchor(text='Indian wolf', href='Indian%20wolf', paragraph_id=35, start=976, end=987), KiltDocAnchor(text='morphological', href='Morphology%20%28biology%29', paragraph_id=37, start=175, end=188), KiltDocAnchor(text='zooarchaeologists', href='Zooarchaeology', paragraph_id=37, start=217, end=234), KiltDocAnchor(text='postcranial', href='postcranial', paragraph_id=37, start=385, end=396), KiltDocAnchor(text='Hohle Fels', href='Hohle%20Fels', paragraph_id=39, start=224, end=234), KiltDocAnchor(text='Goyet Caves', href='Goyet%20Caves', paragraph_id=39, start=247, end=258), KiltDocAnchor(text='Predmosti', href='P%C5%99edmost%C3%AD%20u%20P%C5%99erova%20%28archeology%29', paragraph_id=39, start=271, end=280), KiltDocAnchor(text='Altai Republic', href='Altai%20Republic', paragraph_id=39, start=355, end=369), KiltDocAnchor(text='Kostyonki-8', href='Kostyonki-Borshchyovo%20archaeological%20complex', paragraph_id=39, start=371, end=382), KiltDocAnchor(text='Sakha Republic', href='Sakha%20Republic', paragraph_id=39, start=405, end=419), KiltDocAnchor(text='Chauvet Cave', href='Chauvet%20Cave', paragraph_id=39, start=477, end=489), KiltDocAnchor(text='Teufelsbrucke', href='Devil%27s%20Bridge', paragraph_id=40, start=170, end=183), KiltDocAnchor(text='Mezin', href='Mezine', paragraph_id=40, start=260, end=265), KiltDocAnchor(text='Mezhirich', href='Mezhyrich', paragraph_id=40, start=267, end=276), KiltDocAnchor(text='Montespan', href='Montespan', paragraph_id=40, start=503, end=512), KiltDocAnchor(text='Bonn-Oberkassel', href='Oberkassel%2C%20Bonn', paragraph_id=40, start=564, end=579), KiltDocAnchor(text='ecomorphs', href='Ecomorphology', paragraph_id=41, start=826, end=835), KiltDocAnchor(text='wolfdogs', href='wolfdogs', paragraph_id=41, start=1159, end=1167), KiltDocAnchor(text='Victorian era', href='Victorian%20era', paragraph_id=46, start=760, end=773), KiltDocAnchor(text='selection', href='Selection%20%28biology%29', paragraph_id=46, start=790, end=799), KiltDocAnchor(text='dog breeds', href='dog%20breeds', paragraph_id=46, start=821, end=831), KiltDocAnchor(text='population bottlenecks', href='population%20bottlenecks', paragraph_id=47, start=28, end=50), KiltDocAnchor(text='dog breeds', href='dog%20breeds', paragraph_id=47, start=156, end=166), KiltDocAnchor(text='apex predator', href='apex%20predator', paragraph_id=49, start=3, end=16), KiltDocAnchor(text='trophic level', href='trophic%20level', paragraph_id=49, start=52, end=65), KiltDocAnchor(text='mesopredator', href='mesopredator', paragraph_id=49, start=93, end=105), KiltDocAnchor(text='Late Pleistocene', href='Late%20Pleistocene', paragraph_id=49, start=358, end=374), KiltDocAnchor(text='mitogenome', href='mitogenome', paragraph_id=50, start=62, end=72), KiltDocAnchor(text='Last Glacial Maximum', href='Last%20Glacial%20Maximum', paragraph_id=50, start=309, end=329), KiltDocAnchor(text='first divergence', href='Origin%20of%20the%20domestic%20dog%23Time%20of%20divergence', paragraph_id=50, start=337, end=353), KiltDocAnchor(text='anthropologists', href='anthropologists', paragraph_id=52, start=209, end=224), KiltDocAnchor(text='ungulates', href='ungulates', paragraph_id=52, start=286, end=295), KiltDocAnchor(text='socialized', href='Socialization', paragraph_id=52, start=528, end=538), KiltDocAnchor(text='Romeo', href='Romeo%20%28wolf%29', paragraph_id=52, start=932, end=937), KiltDocAnchor(text='coevolution', href='coevolution', paragraph_id=54, start=26, end=37), KiltDocAnchor(text='niche', href='Ecological%20niche', paragraph_id=54, start=128, end=133), KiltDocAnchor(text='commensal', href='Commensalism', paragraph_id=55, start=73, end=82), KiltDocAnchor(text='Pleistocene', href='Pleistocene', paragraph_id=55, start=227, end=238), KiltDocAnchor(text='Ancient DNA', href='Ancient%20DNA', paragraph_id=56, start=0, end=11), KiltDocAnchor(text='Last Glacial Maximum', href='Last%20Glacial%20Maximum', paragraph_id=56, start=128, end=148), KiltDocAnchor(text='megafauna', href='megafauna', paragraph_id=56, start=192, end=201), KiltDocAnchor(text='mitochondrial', href='mtDNA%20control%20region', paragraph_id=57, start=11, end=24), KiltDocAnchor(text='Y chromosome', href='Y%20chromosome', paragraph_id=57, start=35, end=47), KiltDocAnchor(text='microsatellite', href='Microsatellite%23Analysis%20of%20microsatellites', paragraph_id=57, start=53, end=67), KiltDocAnchor(text='ecotype', href='ecotype', paragraph_id=57, start=313, end=320), KiltDocAnchor(text='boreal', href='Taiga', paragraph_id=57, start=351, end=357), KiltDocAnchor(text='Pleistocene', href='Pleistocene', paragraph_id=57, start=689, end=700), KiltDocAnchor(text='Beringian wolves', href='Beringian%20wolf', paragraph_id=57, start=701, end=717), KiltDocAnchor(text='megafauna', href='megafauna', paragraph_id=57, start=841, end=850), KiltDocAnchor(text='Ellesmere Island', href='Ellesmere%20Island', paragraph_id=58, start=26, end=42), KiltDocAnchor(text='Pleistocene', href='Pleistocene', paragraph_id=62, start=607, end=618), KiltDocAnchor(text='Tibetan Plateau', href='Tibetan%20Plateau', paragraph_id=64, start=88, end=103), KiltDocAnchor(text='New World', href='New%20World', paragraph_id=64, start=115, end=124), KiltDocAnchor(text='Phylogenetic', href='Phylogenetic', paragraph_id=65, start=0, end=12), KiltDocAnchor(text='mDNA', href='mitochondrial%20DNA', paragraph_id=65, start=44, end=48), KiltDocAnchor(text='haplotype', href='haplotype', paragraph_id=65, start=49, end=58), KiltDocAnchor(text='monophyletic', href='Monophyly', paragraph_id=65, start=78, end=90), KiltDocAnchor(text='clades', href='clades', paragraph_id=65, start=91, end=97), KiltDocAnchor(text='haplogroups', href='haplogroups', paragraph_id=65, start=354, end=365), KiltDocAnchor(text='Sami', href='Sami%20people', paragraph_id=69, start=226, end=230), KiltDocAnchor(text='Finnish Lapphund', href='Finnish%20Lapphund', paragraph_id=69, start=247, end=263), KiltDocAnchor(text='Swedish Lapphund', href='Swedish%20Lapphund', paragraph_id=69, start=265, end=281), KiltDocAnchor(text='Lapponian Herder', href='Lapponian%20Herder', paragraph_id=69, start=283, end=299), KiltDocAnchor(text='Jamthund', href='Jamthund', paragraph_id=69, start=301, end=309), KiltDocAnchor(text='Norwegian Elkhound', href='Norwegian%20Elkhound', paragraph_id=69, start=311, end=329), KiltDocAnchor(text='Hällefors Elkhound', href='H%C3%A4llefors%20Elkhound', paragraph_id=69, start=334, end=352), KiltDocAnchor(text='Altai dog', href='Origin%20of%20the%20domestic%20dog%23Altai%20dog%20%26amp%3Bndash%3B%2033%2C000%20BP', paragraph_id=69, start=512, end=521), KiltDocAnchor(text='Japanese wolf', href='Honshu%20Wolf', paragraph_id=71, start=183, end=196), KiltDocAnchor(text='phenotypic', href='phenotype', paragraph_id=72, start=82, end=92), KiltDocAnchor(text='introgression', href='introgression', paragraph_id=72, start=153, end=166), KiltDocAnchor(text='β-defensin', href='Beta%20defensin%23genes', paragraph_id=73, start=742, end=752), KiltDocAnchor(text='Bering Land Bridge', href='Beringia', paragraph_id=76, start=439, end=457), KiltDocAnchor(text='admixture', href='Genetic%20admixture', paragraph_id=77, start=181, end=190), KiltDocAnchor(text='Saarloos wolfdog', href='Saarloos%20wolfdog', paragraph_id=77, start=196, end=212), KiltDocAnchor(text='Siberian husky', href='Siberian%20husky', paragraph_id=77, start=473, end=487), KiltDocAnchor(text='Greenland dog', href='Greenland%20dog', paragraph_id=77, start=492, end=505), KiltDocAnchor(text='Shar Pei', href='Shar%20Pei', paragraph_id=77, start=589, end=597), KiltDocAnchor(text='Finnish spitz', href='Finnish%20spitz', paragraph_id=77, start=602, end=615), KiltDocAnchor(text='introgression', href='introgression', paragraph_id=77, start=1144, end=1157), KiltDocAnchor(text='Newgrange dog', href='Origin%20of%20the%20domestic%20dog%23Two%20domestication%20events', paragraph_id=79, start=527, end=540), KiltDocAnchor(text='Charles Darwin', href='Charles%20Darwin', paragraph_id=81, start=0, end=14), KiltDocAnchor(text='selective breeding', href='selective%20breeding', paragraph_id=81, start=185, end=203), KiltDocAnchor(text='natural selection', href='natural%20selection', paragraph_id=81, start=323, end=340), KiltDocAnchor(text='Dmitry Belyayev', href='Dmitry%20Belyayev%20%28zoologist%29', paragraph_id=82, start=139, end=154), KiltDocAnchor(text='mink', href='mink', paragraph_id=82, start=902, end=906), KiltDocAnchor(text='Japanese quail', href='Japanese%20quail', paragraph_id=82, start=911, end=925), KiltDocAnchor(text='positive selection', href='positive%20selection', paragraph_id=83, start=770, end=788), KiltDocAnchor(text='quantitative trait loci', href='Quantitative%20trait%20locus', paragraph_id=84, start=220, end=243), KiltDocAnchor(text='ghost population', href='ghost%20population', paragraph_id=85, start=169, end=185), KiltDocAnchor(text='Pleistocene', href='Pleistocene', paragraph_id=85, start=210, end=221), KiltDocAnchor(text='genetic loci', href='Locus%20%28genetics%29', paragraph_id=85, start=355, end=367), KiltDocAnchor(text='domestication islands', href='domestication%20islands', paragraph_id=85, start=551, end=572), KiltDocAnchor(text='synaptic plasticity', href='synaptic%20plasticity', paragraph_id=86, start=151, end=170), KiltDocAnchor(text='adrenaline', href='Epinephrine%23Mechanism%20of%20action', paragraph_id=88, start=492, end=502), KiltDocAnchor(text='noradrenaline', href='Neuromodulation', paragraph_id=88, start=507, end=520), KiltDocAnchor(text='biosynthesis', href='biosynthesis', paragraph_id=88, start=521, end=533), KiltDocAnchor(text='catecholamine', href='catecholamine', paragraph_id=88, start=664, end=677), KiltDocAnchor(text='dopamine', href='dopamine', paragraph_id=88, start=694, end=702), KiltDocAnchor(text='noradrenaline', href='noradrenaline', paragraph_id=88, start=707, end=720), KiltDocAnchor(text='neural crest', href='neural%20crest', paragraph_id=89, start=301, end=313), KiltDocAnchor(text='central nervous system', href='central%20nervous%20system', paragraph_id=89, start=318, end=340), KiltDocAnchor(text='embryogenesis', href='embryogenesis', paragraph_id=89, start=373, end=386), KiltDocAnchor(text='domestication syndrome', href='domestication%20syndrome', paragraph_id=89, start=558, end=580), KiltDocAnchor(text='AMY2B', href='AMY2B', paragraph_id=91, start=0, end=5), KiltDocAnchor(text='starch', href='starch', paragraph_id=91, start=117, end=123), KiltDocAnchor(text='glycogen', href='glycogen', paragraph_id=91, start=128, end=136), KiltDocAnchor(text='Saluki', href='Saluki', paragraph_id=91, start=470, end=476), KiltDocAnchor(text='Fertile Crescent', href='Fertile%20Crescent', paragraph_id=91, start=505, end=521), KiltDocAnchor(text='carnivorous', href='carnivorous', paragraph_id=91, start=996, end=1007), KiltDocAnchor(text='dingo', href='dingo', paragraph_id=91, start=1218, end=1223), KiltDocAnchor(text='genome', href='genome', paragraph_id=92, start=28, end=34), KiltDocAnchor(text='lipid', href='lipid', paragraph_id=92, start=213, end=218), KiltDocAnchor(text='Mammoth steppe', href='Mammoth%20steppe', paragraph_id=92, start=1018, end=1032), KiltDocAnchor(text='New Guinea singing dog', href='New%20Guinea%20singing%20dog', paragraph_id=94, start=234, end=256), KiltDocAnchor(text='New Guinea', href='New%20Guinea', paragraph_id=94, start=321, end=331), KiltDocAnchor(text='dingo', href='dingo', paragraph_id=94, start=344, end=349), KiltDocAnchor(text='Outback', href='Outback', paragraph_id=94, start=366, end=373), KiltDocAnchor(text='Bonobo', href='Bonobo', paragraph_id=95, start=156, end=162), KiltDocAnchor(text='chimpanzee', href='Common%20chimpanzee', paragraph_id=95, start=170, end=180), KiltDocAnchor(text='guinea pig', href='guinea%20pig', paragraph_id=95, start=539, end=549), KiltDocAnchor(text='cavy', href='cavy', paragraph_id=95, start=600, end=604), KiltDocAnchor(text='convergent evolution', href='convergent%20evolution', paragraph_id=97, start=67, end=87), KiltDocAnchor(text='pathology', href='pathology', paragraph_id=97, start=320, end=329), KiltDocAnchor(text='genes', href='genes', paragraph_id=99, start=22, end=27), KiltDocAnchor(text='parallel evolution', href='parallel%20evolution', paragraph_id=99, start=358, end=376), KiltDocAnchor(text='hypoxia', href='Hypoxia%20%28environmental%29', paragraph_id=99, start=432, end=439), KiltDocAnchor(text='serotonin', href='serotonin', paragraph_id=99, start=610, end=619), KiltDocAnchor(text='Convergent evolution', href='Convergent%20evolution', paragraph_id=102, start=0, end=20), KiltDocAnchor(text='penguin', href='penguin', paragraph_id=102, start=134, end=141), KiltDocAnchor(text='dolphin', href='dolphin', paragraph_id=102, start=147, end=154), KiltDocAnchor(text='flippers', href='flipper%20%28anatomy%29', paragraph_id=102, start=185, end=193), KiltDocAnchor(text='great ape', href='great%20ape', paragraph_id=102, start=756, end=765), KiltDocAnchor(text='human communication', href='human%20communication', paragraph_id=103, start=117, end=136), KiltDocAnchor(text='coevolution', href='coevolution', paragraph_id=104, start=22, end=33), KiltDocAnchor(text='eye contact', href='eye%20contact', paragraph_id=105, start=74, end=85), KiltDocAnchor(text='gaze', href='gaze', paragraph_id=105, start=94, end=98), KiltDocAnchor(text='oxytocin', href='oxytocin', paragraph_id=105, start=110, end=118), KiltDocAnchor(text='maternal bond', href='maternal%20bond', paragraph_id=105, start=194, end=207), KiltDocAnchor(text='sentient', href='sentient', paragraph_id=105, start=572, end=580), KiltDocAnchor(text='love', href='love', paragraph_id=105, start=1308, end=1312), KiltDocAnchor(text='territoriality', href='territoriality', paragraph_id=107, start=240, end=254), KiltDocAnchor(text='African wild dog', href='African%20wild%20dog', paragraph_id=108, start=816, end=832), KiltDocAnchor(text='dhole', href='dhole', paragraph_id=108, start=847, end=852), KiltDocAnchor(text='ungulate', href='ungulate', paragraph_id=108, start=1113, end=1121), KiltDocAnchor(text='mammoth steppe', href='mammoth%20steppe', paragraph_id=109, start=7, end=21), KiltDocAnchor(text='food chain', href='food%20chain', paragraph_id=109, start=146, end=156), KiltDocAnchor(text='reindeer', href='reindeer', paragraph_id=109, start=219, end=227), KiltDocAnchor(text='Last Glacial Maximum', href='Last%20Glacial%20Maximum', paragraph_id=109, start=757, end=777), KiltDocAnchor(text='carnivore', href='carnivore', paragraph_id=111, start=49, end=58), KiltDocAnchor(text='phenotypic', href='Phenotype', paragraph_id=111, start=137, end=147), KiltDocAnchor(text='dog breeds', href='dog%20breeds', paragraph_id=111, start=191, end=201), KiltDocAnchor(text='artificial selection', href='artificial%20selection', paragraph_id=111, start=209, end=229), KiltDocAnchor(text='poodle', href='poodle', paragraph_id=111, start=304, end=310), KiltDocAnchor(text='mastiff', href='mastiff', paragraph_id=111, start=322, end=329), KiltDocAnchor(text='genetic divergence', href='genetic%20divergence', paragraph_id=111, start=885, end=903), KiltDocAnchor(text='First World War', href='World%20War%20I', paragraph_id=113, start=27, end=42), KiltDocAnchor(text='Oberkassel, Bonn', href='Oberkassel%2C%20Bonn', paragraph_id=113, start=107, end=123), KiltDocAnchor(text='mitochondrial DNA', href='mitochondrial%20DNA', paragraph_id=113, start=628, end=645), KiltDocAnchor(text='pathology', href='pathology', paragraph_id=114, start=528, end=537), KiltDocAnchor(text='canine distemper', href='canine%20distemper', paragraph_id=114, start=616, end=632), KiltDocAnchor(text='Upper Paleolithic', href='Upper%20Paleolithic', paragraph_id=116, start=11, end=28), KiltDocAnchor(text='Petroglyph', href='Petroglyph', paragraph_id=118, start=0, end=10), KiltDocAnchor(text='Shuwaymis', href='Rock%20Art%20in%20the%20Ha%27il%20Region', paragraph_id=118, start=56, end=65), KiltDocAnchor(text='Jubbah', href='Jubbah%2C%20Saudi%20Arabia', paragraph_id=118, start=70, end=76), KiltDocAnchor(text='Late Pleistocene', href='Late%20Pleistocene', paragraph_id=118, start=232, end=248), KiltDocAnchor(text='Holocene', href='Holocene', paragraph_id=118, start=264, end=272), KiltDocAnchor(text='Holocene', href='Holocene', paragraph_id=118, start=477, end=485), KiltDocAnchor(text='Illinois', href='Illinois', paragraph_id=120, start=57, end=65), KiltDocAnchor(text='radiocarbon dating', href='radiocarbon%20dating', paragraph_id=120, start=70, end=88), KiltDocAnchor(text='Koster Site', href='Koster%20Site', paragraph_id=120, start=154, end=165), KiltDocAnchor(text='Illinois River', href='Illinois%20River', paragraph_id=120, start=181, end=195), KiltDocAnchor(text='Greene County', href='Greene%20County%2C%20Illinois', paragraph_id=120, start=199, end=212), KiltDocAnchor(text='Pike County', href='Pike%20County%2C%20Illinois', paragraph_id=120, start=267, end=278), KiltDocAnchor(text='Isotope analysis', href='Isotope%20analysis', paragraph_id=120, start=408, end=424), KiltDocAnchor(text='collagen', href='collagen', paragraph_id=120, start=570, end=578), KiltDocAnchor(text='Zhokhov Island', href='Zhokhov%20Island', paragraph_id=121, start=197, end=211), KiltDocAnchor(text='Siberian husky', href='Siberian%20husky', paragraph_id=123, start=493, end=507), KiltDocAnchor(text="Naumann's elephant", href='Palaeoloxodon%20naumanni', paragraph_id=126, start=136, end=154), KiltDocAnchor(text='sika deer', href='sika%20deer', paragraph_id=126, start=201, end=210), KiltDocAnchor(text='wild boar', href='wild%20boar', paragraph_id=126, start=215, end=224), KiltDocAnchor(text='Jōmon', href='J%C5%8Dmon', paragraph_id=126, start=364, end=369), KiltDocAnchor(text='Honshu', href='Honshu', paragraph_id=126, start=412, end=418), KiltDocAnchor(text='Holarctic', href='Holarctic', paragraph_id=128, start=184, end=193)), ('Origins', 'Dogs'), 'Q39110', '908221312', '2019-07-28T08:49:25Z', '908221228', '5141410', 'https://en.wikipedia.org/w/index.php?title=Origin%20of%20the%20domestic%20dog&oldid=908221312'),
        })

    def test_queries(self):
        self._test_queries('kilt/codec', count=42, items={
            0: CodecQuery('economics-1', "How has the UK's Open Banking Regulation benefited challenger banks?", 'finance', 'UK’s Open Banking regulation, which has parallels to the EU’s second payment service directive (PSD2), went live in January 2018. This piece of legislation “will require banks to open their payments infrastructure and customer data assets to third parties”. As a result, banks no longer have a monopoly on user data if clients grant permission. \n\nChallenger banks are small, recently created retail banks that compete directly with the longer-established banks in the UK. Specifically, seeking market share from the "big four" UK retail banks (Barclays, HSBC, Lloyds Banking Group, and NatWest Group). The banks distinguish themselves from the historic banks by modern financial technology practices, such as online-only operations, that avoid the costs and complexities of traditional banking. The largest UK-operating challenger banks include Atom Bank, Revolut, Starling, N26, and Tide.\n\nRelevant documents and entities will discuss how challenger banks have used open banking to develop new products or capture market share from traditional retail banks in the UK.'),
            9: CodecQuery('economics-18', 'Was the crash that followed the dot-com bubble an overreaction considering the ultimate success of the internet?', 'finance', 'The dot-com buddle from 1995-2000 saw incredible growth in stocks that were considered to have anything to do with the internet. NASDAQ rose 400% only to fall 78% from its peak by 2002. Several high-profile failures included Pets.com, Boo.com, Woldcom, and Global Crossing. However, many internet-based companies survived and went on to thrive, i.e. eBay, Amazon, Qualcomm, Cisco Systems. Venture Capital pulled back from the internet space for a period.\n\nHowever, with FANNG stocks and incredible software/internet-based companies performance from the mid-2000s until the present day, it could be argued that the direction of the dot-com bubble was absolutely correct. Nonetheless, the magnitude of equity growth and capital allocation to companies with limited commercial value was irrational and required a market correction.'),
            41: CodecQuery('politics-23', 'Is the rise of European populism a threat to the European Union?', 'politics', '"Populist" is a broad term that describes, typically a politician, who targets people who feel that established elite groups disregard their concerns. Some critics highlight negative connotations, including criticising foreign migration or minorities.\n\nIn recent years, populism has been stronger in Eastern Europe, i.e. Bulgaria, Hungary, Austrian, and Poland, etc. have seen the rise of populist politicians. Right-wing populist movements have also gained momentum in France, Spain, the United Kingdom and other parts of Europe. In Hungary and Poland, some critics argue this has led to an erosion of the rule of law, increased persecution, and authoritarianism.\n\nEuropean Union is a political union of democratic nations. However, radical right-wing politics reject what the EU stands for and how it works, i.e. against European supranational integration and push for national policies. Populists also criticise the EU\'s perceived bureaucracy and failures - common arguments during the Brexit Leave campaign. The EU is founded based on shared democratic values that countries need to be relatively ideologically aligned to function within a political union. There is also the threat that disillusioned Eastern European countries will turn away from the EU and toward Russia.'),
        })
        self._test_queries('kilt/codec/economics', count=14, items={
            0: CodecQuery('economics-1', "How has the UK's Open Banking Regulation benefited challenger banks?", 'finance', 'UK’s Open Banking regulation, which has parallels to the EU’s second payment service directive (PSD2), went live in January 2018. This piece of legislation “will require banks to open their payments infrastructure and customer data assets to third parties”. As a result, banks no longer have a monopoly on user data if clients grant permission. \n\nChallenger banks are small, recently created retail banks that compete directly with the longer-established banks in the UK. Specifically, seeking market share from the "big four" UK retail banks (Barclays, HSBC, Lloyds Banking Group, and NatWest Group). The banks distinguish themselves from the historic banks by modern financial technology practices, such as online-only operations, that avoid the costs and complexities of traditional banking. The largest UK-operating challenger banks include Atom Bank, Revolut, Starling, N26, and Tide.\n\nRelevant documents and entities will discuss how challenger banks have used open banking to develop new products or capture market share from traditional retail banks in the UK.'),
            9: CodecQuery('economics-18', 'Was the crash that followed the dot-com bubble an overreaction considering the ultimate success of the internet?', 'finance', 'The dot-com buddle from 1995-2000 saw incredible growth in stocks that were considered to have anything to do with the internet. NASDAQ rose 400% only to fall 78% from its peak by 2002. Several high-profile failures included Pets.com, Boo.com, Woldcom, and Global Crossing. However, many internet-based companies survived and went on to thrive, i.e. eBay, Amazon, Qualcomm, Cisco Systems. Venture Capital pulled back from the internet space for a period.\n\nHowever, with FANNG stocks and incredible software/internet-based companies performance from the mid-2000s until the present day, it could be argued that the direction of the dot-com bubble was absolutely correct. Nonetheless, the magnitude of equity growth and capital allocation to companies with limited commercial value was irrational and required a market correction.'),
            13: CodecQuery('economics-23', 'Offering non-accounting services arguably creates a conflict of interest for the Big Four. Is this the reason for their inability to uncover recent financial scandals?', 'finance', 'The Big Four are the four largest global accounting firms that dominate corporate accounting, i.e. Deloitte, Ernst & Young (EY), PricewaterhouseCoopers (PwC), and Klynveld Peat Marwick Goerdeler (KPMG). As well as offering accounting services, these firms also over other many higher-margin services such as tax, consultancy, and technology services (~80% revenue). \n\nInternal controls (firewalls, departments, etc.) are meant to prohibit any cooperation between audit and non-audit services in winning customer contracts or favour. However, critics would argue that this does not go far enough and can lead to less rigorous audits, calling for the Big Four to be broken up. Critics highlight poor practices in recent accounting scandals, including  Wirecard, Carillion, Satyam Computer Services, South Africa examples, etc. \n\nHowever, it should be highlighted that even if the Big Four were separated, this would not necessarily lead to no accounting scandals. Some fraudulent practices may be hard to catch even if objective and following best practices. Also, there are other areas of possible conflict of interest that non-accounting work, including how the corporate hires the auditor.'),
        })
        self._test_queries('kilt/codec/history', count=14, items={
            0: CodecQuery('history-1', 'Would the United Kingdom have been ready for WWII without the time gained through Appeasement?', 'history', "Many argue Britain's army was depleted in the early 1930s and stretched across the globe. UK defence spending had fallen significantly during the 1920s, from over £700 million in 1919 to 100 million in 1931.\n\nBetween 1934 and 1939, the UK launched a substantial programme of re-arming, recognising that war with Hitler was becoming increasingly likely. Although Appeasement was also motivated by Chamberlain's desire to end war, some argue this meant that the UK was more prepared in 1939 when war eventually broke out.  \n\nDespite these efforts, Germany was still better prepared for war under Hilter's single-minded preparation since he came to power in 1933. However, without Appeasement, the differential might have been much worse."),
            9: CodecQuery('history-19', 'How close did the world come to nuclear war during the Cuban Missile Crisis?', 'history', 'During the Cuban Missile Crisis, leaders of the United States and the Soviet Union engaged in a 13-day political and military standoff in October 1962 over the installation of nuclear-armed Soviet missiles on Cuba. This was the peak of the Cold War and a high-stakes political and military situation, given the potential devastation of nuclear weapons. However, exactly how close we came to nuclear armageddon is still debated. \n\nThe political leaders within this crisis were JFK for the United States, Nikita Khrushchev of the Soviet Union, and Fidel Casto of Cuba. Many highlights that JFK and Khrushchev were measured in their leadership styles and understood nuclear war meant mutual destruction. Some highlight exchanging of letters and other communications to prevent a nuclear war. Nonetheless, many highlight the mistrust and fear between both sides and how a single false move could have led to a disaster. Both sides were actively preparing for a nuclear war, and some within each camp through nuclear strikes was likely.'),
            13: CodecQuery('history-25', 'How responsible was Rasputin for the fall of the Romanov dynasty?', 'history', "The Russian Tsar, Nicholas II, abdicated from power in 1917, bringing the 300-year-old Romanov dynasty to an end. Some historians suggest that Grigori Rasputin's scandalous reputation helped discredit the Tsarist government and helped to lay the foundation for the Russian Revolution. \n\nHowever, many historians argue that although Rasputin was a useful propaganda tool against the Tsar, much larger factors were at play. For example, Nicholas II was viewed as a weak leader, the Russo-Japanese War, Bloody Sunday, Tsarina unpopularity, and WWI. There was also significant economic issues, including inflation and food shortages."),
        })
        self._test_queries('kilt/codec/politics', count=14, items={
            0: CodecQuery('politics-1', 'Is Scottish Independence inevitable?', 'politics', "This questions focuses on the long-term political, economic and social reasoning behind whether Scotland will likely become independent. Short-term facts and opinions are less central to this question.\n\nSome argue that Scottish independence is inevitable given the surge of support towards SNP in recent decades. Labour has lost political weight in Scotland since the Blair era, and Conservatives historically struggle to penetrate a more left-wing Scottish demographic. Brexit further exacerbated this political unease, i.e. right-leaning Britain and left-leaning Scotland. While the younger demographic is more likely to be independence supporters and the older demographic is more likely to be pro-union.\n\nThere are several arguments that Scotland independence is not inevitable. Historically there has been a union for 300+ years covering a full range of circumstances (world wars, successes). Economically, Britain funds lots of Scottish spending through Barnett-based funding, Scotland's oil is less valuable than previously, and there is much economic uncertainly around currency and debt. Some also argue that Scotland has large political independence due to devolution; thus, independence is unnecessary."),
            9: CodecQuery('politics-16', 'Why did Hilary Clinton lose the 2016 US presidential election?', 'politics', 'Hillary Clinton lost the 2016 US presidential election to Donald Trump in 2016. Political commentators highlight many reasons for Clinton\'s loss. \n\nFor example, Donald Trump managed to craft a strong populist message that resonated with many voters who were disenfranchised with current politics, particularly with the "political elite" who some felt Clinton represented. The Democratats were also divided, specifically far-left factions led by Bernie Sanders. Political gridlock under an Obama Administration that, rightly or wrongly, some felt the public wanting change. Hilary also had relatively low personal approval ratings, which were not helped by the FBI investigation into her use of email. Some also point to external factors, including Russian interference.'),
            13: CodecQuery('politics-23', 'Is the rise of European populism a threat to the European Union?', 'politics', '"Populist" is a broad term that describes, typically a politician, who targets people who feel that established elite groups disregard their concerns. Some critics highlight negative connotations, including criticising foreign migration or minorities.\n\nIn recent years, populism has been stronger in Eastern Europe, i.e. Bulgaria, Hungary, Austrian, and Poland, etc. have seen the rise of populist politicians. Right-wing populist movements have also gained momentum in France, Spain, the United Kingdom and other parts of Europe. In Hungary and Poland, some critics argue this has led to an erosion of the rule of law, increased persecution, and authoritarianism.\n\nEuropean Union is a political union of democratic nations. However, radical right-wing politics reject what the EU stands for and how it works, i.e. against European supranational integration and push for national policies. Populists also criticise the EU\'s perceived bureaucracy and failures - common arguments during the Brexit Leave campaign. The EU is founded based on shared democratic values that countries need to be relatively ideologically aligned to function within a political union. There is also the threat that disillusioned Eastern European countries will turn away from the EU and toward Russia.'),
        })

    def test_qrels(self):
        self._test_qrels('kilt/codec', count=11323, items={
            0: TrecQrel('economics-8', '10489969', 0, 'Q0'),
            9: TrecQrel('economics-8', '1380940', 1, 'Q0'),
            11322: TrecQrel('politics-23', '9800598', 1, 'Q0'),
        })
        self._test_qrels('kilt/codec/economics', count=1970, items={
            0: TrecQrel('economics-8', '089a22846f6ba15fb4ef4cca0a884dd4', 2, 'Q0'),
            9: TrecQrel('economics-8', '24de81ea95c7df32941e8bd200d3528a', 2, 'Q0'),
            1969: TrecQrel('economics-23', 'ebd36155b9808933bbbfc26af6d18dec', 1, 'Q0'),
        })
        self._test_qrels('kilt/codec/history', count=2024, items={
            0: TrecQrel('history-20', '00aa648a657bdf73369bcb093030cc41', 0, 'Q0'),
            9: TrecQrel('history-20', '0d239d8dea605cd079d1a0144aa6ed46', 1, 'Q0'),
            2023: TrecQrel('history-25', 'dba9433750c2505f2a6a69661d4eb2fd', 0, 'Q0'),
        })
        self._test_qrels('kilt/codec/politics', count=2192, items={
            0: TrecQrel('politics-12', '02d8176599da0bfc15caaf7e0b3bba6b', 3, 'Q0'),
            9: TrecQrel('politics-12', '0e23e45de303e5f440a5a17ccd7974ec', 1, 'Q0'),
            2191: TrecQrel('politics-23', 'f7975664f7fc45416c7256d12d06fbdf', 1, 'Q0'),
        })

if __name__ == '__main__':
    unittest.main()
